@@ -28,13 +28,14 @@ import os
 import copy
 from PyQt5 import QtWidgets, QtCore
 import numpy as np
+
 from pygmi.raster.datatypes import Data
 import pygmi.clust.var_ratio as vr
 
 
 class CrispClust(QtWidgets.QDialog):
     """
-    Crisp Cluster Class
+    Crisp Cluster Class.
 
     Attributes
     ----------
@@ -56,13 +57,11 @@ class CrispClust(QtWidgets.QDialog):
 
         self.indata = {}
         self.outdata = {}
+        self.parent = parent
 
         if parent is not None:
-            self.parent = parent
-            self.pbar = parent.pbar
             self.piter = parent.pbar.iter
         else:
-            self.pbar = None
             self.piter = iter
 
         self.spinbox_maxclusters = QtWidgets.QSpinBox()
@@ -216,12 +215,12 @@ class CrispClust(QtWidgets.QDialog):
 
         if not nodialog:
             self.parent.process_is_active(False)
-            self.pbar.to_max()
+            self.parent.pbar.to_max()
         return True
 
     def loadproj(self, projdata):
         """
-        Loads project data into class.
+        Load project data into class.
 
         Parameters
         ----------
@@ -234,7 +233,6 @@ class CrispClust(QtWidgets.QDialog):
             A check to see if settings was successfully run.
 
         """
-
         self.combobox_alg.setCurrentText(projdata['cltype'])
         self.spinbox_minclusters.setProperty('value', projdata['min_cluster'])
         self.spinbox_maxclusters.setProperty('value', projdata['max_cluster'])
@@ -251,7 +249,6 @@ class CrispClust(QtWidgets.QDialog):
         """
         Save project data from class.
 
-
         Returns
         -------
         projdata : dictionary
@@ -574,7 +571,7 @@ class CrispClust(QtWidgets.QDialog):
         ----------
         data : numpy array
             NxP matrix containing the data to be clustered, N is number of
-            samples, P is number of different attributes availabe for each
+            samples, P is number of different attributes available for each
             sample.
         no_clust : int
             Number of clusters to be used.
@@ -585,7 +582,7 @@ class CrispClust(QtWidgets.QDialog):
         centfix : TYPE
             Constrains the position of cluster centers, if centfix is empty,
             cluster centers can freely vary during cluster analysis, otherwise
-            CENTFIX is of equal size to CENT and gives an absolut deviation
+            CENTFIX is of equal size to CENT and gives an absolute deviation
             from initial center positions that should not be exceeded during
             clustering. Note, CETNFIX applies only if center values are
             provided by the user.
@@ -605,7 +602,7 @@ class CrispClust(QtWidgets.QDialog):
             latter is the crisp version of the Gustafson-Kessel algorithm
         cov_constr : float
             scalar between [0 1], values > 0 trim the covariance matrix
-            to avoid needle-like ellpsoids for the clusters, applies only for
+            to avoid needle-like ellipsoids for the clusters, applies only for
             CLTYPE='vardet', but must always be provided.
 
         Returns
@@ -646,7 +643,7 @@ class CrispClust(QtWidgets.QDialog):
     # initial size of objective function
         obj_fcn_initial = np.sum(mindist**2)
         obj_fcn_prev = obj_fcn_initial
-        obj_fcn = np.zeros(maxit)  # This is new - we must initialize this.
+        obj_fcn = np.zeros(maxit)  # This is new - we must initialise this.
 
         for i in self.piter(range(maxit)):  # =1:maxit. loop over all iters
             cent_prev = cent  # store result of last iteration
