@@ -28,6 +28,7 @@ import os
 import copy
 from PyQt5 import QtWidgets, QtCore
 import numpy as np
+
 from pygmi.raster.datatypes import Data
 from pygmi.clust import var_ratio as vr
 from pygmi.clust import xie_beni as xb
@@ -56,12 +57,11 @@ class FuzzyClust(QtWidgets.QDialog):
 
         self.indata = {}
         self.outdata = {}
+        self.parent = parent
+
         if parent is not None:
-            self.parent = parent
-            self.pbar = parent.pbar
             self.piter = parent.pbar.iter
         else:
-            self.pbar = None
             self.piter = iter
 
         self.combobox_alg = QtWidgets.QComboBox()
@@ -223,13 +223,13 @@ class FuzzyClust(QtWidgets.QDialog):
 
         if not nodialog:
             self.parent.process_is_active(False)
-            self.pbar.to_max()
+            self.parent.pbar.to_max()
 
         return True
 
     def loadproj(self, projdata):
         """
-        Loads project data into class.
+        Load project data into class.
 
         Parameters
         ----------
@@ -259,7 +259,6 @@ class FuzzyClust(QtWidgets.QDialog):
         """
         Save project data from class.
 
-
         Returns
         -------
         projdata : dictionary
@@ -551,7 +550,7 @@ class FuzzyClust(QtWidgets.QDialog):
             DATA is size M-by-N, where M is the number of samples
             and N is the number of coordinates (attributes) for each sample.
         no_clust : int
-            Numer of clusters.
+            Number of clusters.
         init : TYPE
             INIT may be set to [], in this case the fcm generates random
             initial center locations to start the algorithm. Alternatively,
@@ -568,7 +567,7 @@ class FuzzyClust(QtWidgets.QDialog):
         expo : float
             Fuzzification exponent.
         cltype : str
-            either 'FCM' for fuzy c-means (spherically shaped clusters),
+            either 'FCM' for fuzzy c-means (spherically shaped clusters),
             'DET' for advanced fuzzy c-means (ellipsoidal clusters, all
             clusters use the same ellipsoid), or 'GK' for Gustafson-Kessel
             clustering (ellipsoidal clusters, each cluster uses its own
@@ -577,7 +576,7 @@ class FuzzyClust(QtWidgets.QDialog):
             COV_CONSTR applies only to the GK algorithm. constrains the cluster
             shape towards spherical clusters to avoid needle-like clusters.
             COV_CONSTR = 1 make the GK algorithm equal to the FCM algorithm,
-            COV_CONSTR = 0 results in no constraining of the covarince matrices
+            COV_CONSTR = 0 results in no constraining of the covariance matrices
             of the clusters.
 
         Returns
@@ -671,7 +670,7 @@ class FuzzyClust(QtWidgets.QDialog):
     # initial size of objective function
     #    obj_fcn_initial = np.sum((edist**2)*m_f)
     #    obj_fcn_prev = obj_fcn_initial
-        obj_fcn = np.zeros(maxit)  # This is new - we must initialize this.
+        obj_fcn = np.zeros(maxit)  # This is new - we must initialise this.
 
 #    hh = waitbar(0,['No. of clusters: ',
 #    num2unicode(info(1)),'/[',num2unicode(info(2)),
