@@ -31,7 +31,9 @@ from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg
 from matplotlib.figure import Figure
 from matplotlib.backends.backend_qt5 import NavigationToolbar2QT
 from matplotlib.ticker import MaxNLocator
+
 from pygmi.misc import frm
+from pygmi.raster.modest_image import imshow
 
 
 class MyMplCanvas(FigureCanvasQTAgg):
@@ -54,7 +56,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
 
         super().__init__(fig)
 
-    def update_contour(self, data1):
+    def update_classes(self, data1):
         """
         Update the plot.
 
@@ -72,13 +74,19 @@ class MyMplCanvas(FigureCanvasQTAgg):
         self.axes = self.figure.add_subplot(111)
 
         cdat = data1.data
-        csp = self.axes.imshow(cdat, cmap=cm.get_cmap('jet'),
-                               extent=data1.extent)
+        csp = imshow(self.axes, cdat, cmap=cm.get_cmap('jet'),
+                     extent=data1.extent)
+        # csp = self.axes.imshow(cdat, cmap=cm.get_cmap('jet'),
+        #                        extent=data1.extent)
         vals = np.unique(cdat)
         vals = vals.compressed()
         bnds = (vals - 0.5).tolist() + [vals.max() + .5]
-        self.axes.figure.colorbar(csp, boundaries=bnds, values=vals,
-                                  ticks=vals)
+
+        if len(vals) > 1:
+            self.axes.figure.colorbar(csp, boundaries=bnds, values=vals,
+                                      ticks=vals)
+        # else:
+        #     self.axes.figure.colorbar(csp)
 
         self.axes.set_xlabel('Eastings')
         self.axes.set_ylabel('Northings')
@@ -164,9 +172,14 @@ class MyMplCanvas(FigureCanvasQTAgg):
         self.figure.clear()
         self.axes = self.figure.add_subplot(111)
 
-        rdata = self.axes.imshow(data1.metadata['Cluster']['memdat'][mem],
-                                 extent=data1.extent, cmap=cm.get_cmap('jet'))
+        # rdata = self.axes.imshow(data1.metadata['Cluster']['memdat'][mem],
+        #                          extent=data1.extent, cmap=cm.get_cmap('jet'))
+
+        rdata = imshow(self.axes, data1.metadata['Cluster']['memdat'][mem],
+                       extent=data1.extent, cmap=cm.get_cmap('jet'))
+
         self.figure.colorbar(rdata)
+
 #        self.axes.set_title('Data')
         self.axes.set_xlabel('Eastings')
         self.axes.set_ylabel('Northings')
@@ -256,7 +269,7 @@ class PlotRaster(GraphWindow):
         """
         i = self.combobox1.currentIndex()
         data = self.indata['Cluster']
-        self.mmc.update_contour(data[i])
+        self.mmc.update_classes(data[i])
 
     def run(self):
         """
@@ -322,7 +335,8 @@ class PlotMembership(GraphWindow):
 
         """
         data = self.indata['Cluster']
-        if 'memdat' not in data[0].metadata['Cluster'] or len(data[0].metadata['Cluster']['memdat']) == 0:
+        if ('memdat' not in data[0].metadata['Cluster'] or
+                len(data[0].metadata['Cluster']['memdat']) == 0):
             return
 
         self.show()
@@ -377,7 +391,8 @@ class PlotVRCetc(GraphWindow):
 
         j = str(self.combobox1.currentText())
 
-        if j == 'Objective Function' and data[0].metadata['Cluster']['obj_fcn'] is not None:
+        if (j == 'Objective Function' and
+                data[0].metadata['Cluster']['obj_fcn'] is not None):
             x = len(data)
             y = 0
             for i in data:
@@ -398,15 +413,18 @@ class PlotVRCetc(GraphWindow):
             x += data[0].metadata['Cluster']['no_clusters']
             self.mmc.update_wireframe(x.T, y.T, np.log(z))
 
-        if j == 'Variance Ratio Criterion' and data[0].metadata['Cluster']['vrc'] is not None:
+        if (j == 'Variance Ratio Criterion' and
+                data[0].metadata['Cluster']['vrc'] is not None):
             x = [k.metadata['Cluster']['no_clusters'] for k in data]
             y = [k.metadata['Cluster']['vrc'] for k in data]
             self.mmc.update_scatter(x, y)
-        if j == 'Normalized Class Entropy' and data[0].metadata['Cluster']['nce'] is not None:
+        if (j == 'Normalized Class Entropy' and
+                data[0].metadata['Cluster']['nce'] is not None):
             x = [k.metadata['Cluster']['no_clusters'] for k in data]
             y = [k.metadata['Cluster']['nce'] for k in data]
             self.mmc.update_scatter(x, y)
-        if j == 'Xie-Beni Index' and data[0].metadata['Cluster']['xbi'] is not None:
+        if (j == 'Xie-Beni Index' and
+                data[0].metadata['Cluster']['xbi'] is not None):
             x = [k.metadata['Cluster']['no_clusters'] for k in data]
             y = [k.metadata['Cluster']['xbi'] for k in data]
             self.mmc.update_scatter(x, y)
