@@ -25,6 +25,7 @@
 """Clustering Menu Routines."""
 
 from PyQt5 import QtWidgets
+
 from pygmi.clust import cluster
 from pygmi.clust import graphtool
 from pygmi.clust import graphs
@@ -122,23 +123,22 @@ class MenuWidget():
 
     def cluster(self):
         """Clustering of data."""
-        fnc = cluster.Cluster(self.parent)
-        self.parent.item_insert('Step', 'Cluster Analysis', fnc)
+        self.parent.item_insert('Step', 'Cluster Analysis', cluster.Cluster)
 
     def crisp_cluster(self):
         """Crisp Clustering of data."""
-        fnc = crisp_clust.CrispClust(self.parent)
-        self.parent.item_insert('Step', 'Crisp Clustering', fnc)
+        self.parent.item_insert('Step', 'Crisp Clustering',
+                                crisp_clust.CrispClust)
 
     def fuzzy_cluster(self):
         """Fuzzy Clustering of data."""
-        fnc = fuzzy_clust.FuzzyClust(self.parent)
-        self.parent.item_insert('Step', 'Fuzzy Clustering', fnc)
+        self.parent.item_insert('Step', 'Fuzzy Clustering',
+                                fuzzy_clust.FuzzyClust)
 
     def super_class(self):
         """Supervised Classification."""
-        fnc = super_class.SuperClass(self.parent)
-        self.parent.item_insert('Step', 'Supervised Classification', fnc)
+        self.parent.item_insert('Step', 'Supervised Classification',
+                                super_class.SuperClass)
 
     def export_data(self):
         """Export raster data."""
@@ -146,8 +146,8 @@ class MenuWidget():
 
     def scatter_plot(self):
         """Scatter Plot Tool."""
-        fnc = graphtool.ScatterPlot(self.parent)
-        self.parent.item_insert('Step', 'Scatter Plot Tool', fnc)
+        self.parent.item_insert('Step', 'Scatter Plot Tool',
+                                graphtool.ScatterPlot)
 
     def show_raster_data(self):
         """Show raster data."""
@@ -163,5 +163,5 @@ class MenuWidget():
 
     def segmentation(self):
         """Image Segmentation."""
-        fnc = segmentation.ImageSeg(self.parent)
-        self.parent.item_insert('Step', 'Image Segmentation', fnc)
+        self.parent.item_insert('Step', 'Image Segmentation',
+                                segmentation.ImageSeg)
