@@ -25,8 +25,9 @@
 """Image segmentation routines."""
 import copy
 import numpy as np
+from sklearn.cluster import DBSCAN
 import skimage
-import matplotlib.pyplot as plt
+import sklearn.preprocessing as skp
 from numba import jit
 from PyQt5 import QtWidgets, QtCore, QtGui
 import pygmi.menu_default as menu_default
@@ -54,19 +55,21 @@ class ImageSeg(QtWidgets.QDialog):
         super().__init__(parent)
         if parent is None:
             self.showprocesslog = print
+            self.pbar = None
         else:
             self.showprocesslog = parent.showprocesslog
+            self.pbar = parent.pbar
 
         self.parent = parent
         self.indata = {}
         self.outdata = {}
         self.ifile = ''
-        self.pbar = self.parent.pbar
 
         self.scale = QtWidgets.QLineEdit('1000')
         self.wcompact = QtWidgets.QLineEdit('0.5')
         self.wcolor = QtWidgets.QLineEdit('0.9')
-        self.isrecursive = QtWidgets.QCheckBox('Recursive file search')
+        self.eps = QtWidgets.QLineEdit('0.1')
+        self.dbscan = QtWidgets.QCheckBox('Use DBSCAN to group segments')
 
         self.setupui()
 
@@ -84,8 +87,9 @@ class ImageSeg(QtWidgets.QDialog):
         helpdocs = menu_default.HelpButton('pygmi.clust.segmentation')
 
         lbl_wcompact = QtWidgets.QLabel('Compactness weight')
-        lbl_wcolor = QtWidgets.QLabel('Colour weight')
+        lbl_wcolor = QtWidgets.QLabel('Color weight')
         lbl_scale = QtWidgets.QLabel('Maximum allowable cost function')
+        lbl_eps = QtWidgets.QLabel('DBSCAN eps')
 
         val = QtGui.QDoubleValidator(0.0, 1.0, 2)
         val.setNotation(QtGui.QDoubleValidator.StandardNotation)
@@ -93,6 +97,7 @@ class ImageSeg(QtWidgets.QDialog):
 
         self.wcompact.setValidator(val)
         self.wcolor.setValidator(val)
+        self.dbscan.setChecked(False)
 
         val = QtGui.QDoubleValidator()
         val.setBottom = 0
@@ -113,7 +118,10 @@ class ImageSeg(QtWidgets.QDialog):
         gridlayout_main.addWidget(lbl_scale, 2, 0, 1, 1)
         gridlayout_main.addWidget(self.scale, 2, 1, 1, 1)
 
-        # gridlayout_main.addWidget(self.isrecursive, 2, 0, 1, 2)
+        gridlayout_main.addWidget(self.dbscan, 3, 0, 1, 2)
+
+        gridlayout_main.addWidget(lbl_eps, 4, 0, 1, 1)
+        gridlayout_main.addWidget(self.eps, 4, 1, 1, 1)
 
         gridlayout_main.addWidget(helpdocs, 5, 0, 1, 1)
         gridlayout_main.addWidget(buttonbox, 5, 1, 1, 3)
@@ -150,6 +158,7 @@ class ImageSeg(QtWidgets.QDialog):
         scale = float(self.scale.text())
         wcolor = float(self.wcolor.text())
         wcompact = float(self.wcompact.text())
+        eps = float(self.eps.text())
 
         doshape = True
 
@@ -158,9 +167,38 @@ class ImageSeg(QtWidgets.QDialog):
 
         odat = copy.deepcopy(self.indata['Raster'][0])
         odat.data = np.ma.array(omap, mask=self.indata['Raster'][0].data.mask)
+        odat.dataid = 'Segments'
 
         self.outdata['Raster'] = [odat]
 
+        if not self.dbscan.isChecked():
+            return True
+
+        means = []
+        for i in range(odat.data.max()+1):
+            tmp = data1[odat.data == i]
+            if tmp.size == 0:
+                continue
+            means.append(tmp.mean(0))
+
+        means = np.array(means)
+        means = skp.StandardScaler().fit_transform(means)
+        dbout = DBSCAN(eps=eps).fit_predict(means)
+
+        data2 = odat.data.copy()
+
+        newmax = dbout.max()+1
+        for i, val in enumerate(dbout):
+            filt = (odat.data == i)
+            if val == -1:
+                data2[filt] = newmax
+                newmax += 1
+                continue
+            data2[filt] = val
+
+        odat.data = data2
+        self.outdata['Raster'] = [odat]
+
         return True
 
     def loadproj(self, projdata):
@@ -317,9 +355,10 @@ class ImageSeg(QtWidgets.QDialog):
             elist = set(olist.keys())
 
             clen = len(elist)
-            self.pbar.setMaximum(clen)
-            self.pbar.setMinimum(0)
-            self.pbar.setValue(0)
+            if self.pbar is not None:
+                self.pbar.setMaximum(clen)
+                self.pbar.setMinimum(0)
+                self.pbar.setValue(0)
             self.showprocesslog('Iteration number: '+str(cnt))
             oldperc = 0
 
@@ -459,7 +498,8 @@ class ImageSeg(QtWidgets.QDialog):
 
                 cnow = clen-len(elist)
                 if cnow*1000//clen-oldperc > 0:
-                    self.pbar.setValue(cnow)
+                    if self.pbar is not None:
+                        self.pbar.setValue(cnow)
                     oldperc = cnow*1000//clen
 
                 rmin, rmax = rminmax[i]
@@ -499,15 +539,84 @@ def get_l(data):
     return ltmp
 
 
-def test():
-    """Main testing routine."""
-    data1 = skimage.data.coffee()  # 400x600 50.6 secs
+def _testfn():
+    """Test routine."""
+    import sys
+    import matplotlib.pyplot as plt
+    from pygmi.raster.datatypes import Data
+    from pygmi.misc import PTime
+    from pygmi.raster import iodefs
+
+
+    APP = QtWidgets.QApplication(sys.argv)  # Necessary to test Qt Classes
+
+    data1 = skimage.data.coffee()  # 400x600 48.5 secs
+
+
+    # data1 = data1[:, :300]  # 26
+
+    plt.imshow(data1)
+    plt.show()
 
     wcolor = 0.5
     wcompact = 0.5
     doshape = True
     scale = 1000
 
+
+    b1 = Data()
+    b1.data = np.ma.array(data1[:, :, 0])
+    b2 = Data()
+    b2.data = np.ma.array(data1[:, :, 1])
+    b3 = Data()
+    b3.data = np.ma.array(data1[:, :, 2])
+
+    data = [b1, b2, b3]
+
+    ifile = r'E:\Workdata\testdata.hdr'
+
+    data = iodefs.get_raster(ifile)
+
+    ttt = PTime()
+    IS = ImageSeg()
+    IS.indata = {'Raster': data}
+    # IS.settings(True)
+    IS.settings()
+    ttt.since_last_call()
+
+    odata = IS.outdata['Raster'][0]
+
+    plt.imshow(odata.data)
+    plt.show()
+
+    # means = []
+    # for i in range(odata.data.max()+1):
+    #     tmp = data1[odata.data==i]
+    #     means.append(tmp.mean(0))
+
+    # means = np.array(means)
+    # means = skp.StandardScaler().fit_transform(means)
+
+    # dbout = DBSCAN(eps=0.15).fit_predict(means)
+
+    # data2 = odata.data.copy()
+
+    # newmax = dbout.max()+1
+    # for i, val in enumerate(dbout):
+    #     filt = (odata.data==i)
+    #     if val == -1:
+    #         data2[filt] = newmax
+    #         newmax += 1
+    #         continue
+    #     data2[filt] = val
+
+    # plt.imshow(data2, cmap='inferno')
+    # plt.colorbar()
+    # plt.show()
+
+    breakpoint()
+
+
     # omap = segment1(data1, scale=scale, wcolor=wcolor,
     #                 wcompact=wcompact, doshape=doshape)
 
@@ -532,6 +641,6 @@ def test():
 
 
 if __name__ == "__main__":
-    test()
+    _testfn()
 
     print('Finished!')
