@@ -37,6 +37,7 @@ from matplotlib.patches import Polygon as mPolygon
 from matplotlib.lines import Line2D
 from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg
 from matplotlib.backends.backend_qt5 import NavigationToolbar2QT
+import pandas as pd
 import geopandas as gpd
 from shapely.geometry import Polygon
 from PIL import Image, ImageDraw
@@ -46,8 +47,10 @@ import sklearn.metrics as skm
 from sklearn.ensemble import RandomForestClassifier
 from sklearn.tree import DecisionTreeClassifier
 from sklearn.svm import SVC
+
 from pygmi.raster.datatypes import Data
 from pygmi.misc import frm
+from pygmi.raster.modest_image import imshow
 
 
 class GraphMap(FigureCanvasQTAgg):
@@ -91,8 +94,10 @@ class GraphMap(FigureCanvasQTAgg):
         # self.subplot.get_xaxis().set_visible(False)
         # self.subplot.get_yaxis().set_visible(False)
 
-        self.csp = self.subplot.imshow(dat.data, extent=dat.extent,
-                                       cmap=cm.get_cmap('jet'))
+        # self.csp = self.subplot.imshow(dat.data, extent=dat.extent,
+        #                                cmap=cm.get_cmap('jet'))
+        self.csp = imshow(self.subplot, dat.data, extent=dat.extent,
+                          cmap=cm.get_cmap('jet'))
         axes = self.figure.gca()
 
         axes.set_xlabel('Eastings')
@@ -211,7 +216,7 @@ class PolygonInteractor(QtCore.QObject):
 
     def new_poly(self, npoly=None):
         """
-        New polygon.
+        Create new polygon.
 
         Parameters
         ----------
@@ -552,6 +557,7 @@ class SuperClass(QtWidgets.QDialog):
         calcmetrics.clicked.connect(self.calc_metrics)
 #        self.tablewidget.cellChanged.connect(self.ontablechange)
         self.tablewidget.currentItemChanged.connect(self.onrowchange)
+        self.tablewidget.cellChanged.connect(self.oncellchange)
         self.combo_class.currentIndexChanged.connect(self.class_change)
 
         buttonbox.accepted.connect(self.accept)
@@ -559,7 +565,7 @@ class SuperClass(QtWidgets.QDialog):
 
     def class_change(self):
         """
-        Current classification choice changed.
+        Routine called when current classification choice changes.
 
         Returns
         -------
@@ -598,7 +604,7 @@ class SuperClass(QtWidgets.QDialog):
         if self.df is None:
             return
 
-        classifier, _, _, X_test, y_test = self.init_classifier()
+        classifier, lbls, _, X_test, y_test, tlbls = self.init_classifier()
 
         # Predicting the Test set results
         y_pred = classifier.predict(X_test)
@@ -607,13 +613,28 @@ class SuperClass(QtWidgets.QDialog):
         accuracy = skm.accuracy_score(y_test, y_pred)
         kappa = skm.cohen_kappa_score(y_pred, y_test)
 
-        message = 'Confusion Matrix:\n'
-        message += str(cmat)+'\n'
-        message += 'Accuracy: '+str(accuracy)+'\n'
-        message += 'Kappa:\t  '+str(kappa)+'\n'
+        message = '<p>Confusion Matrix:</p>'
+        message += pd.DataFrame(cmat, columns=tlbls, index=tlbls).to_html()
+        message += '<p>Accuracy: '+str(accuracy)+'</p>'
+        message += '<p>Kappa:\t  '+str(kappa)+'</p>'
 
-        QtWidgets.QMessageBox.information(self.parent, 'Metrics',
-                                          message)
+        qsave = QtWidgets.QMessageBox.Save
+        qokay = QtWidgets.QMessageBox.Ok
+        ret = QtWidgets.QMessageBox.information(self.parent, 'Metrics',
+                                                message,
+                                                buttons=qsave | qokay)
+        if ret == qsave:
+            filename, _ = QtWidgets.QFileDialog.getSaveFileName(
+                self.parent, 'Save File', '.', 'Excel spreadsheet (*.xlsx)')
+
+            if filename != '':
+                df = pd.DataFrame(cmat, columns=tlbls, index=tlbls)
+                df.loc['Accuracy'] = np.nan
+                df.loc['Accuracy', tlbls[0]] = accuracy
+                df.loc['Kappa'] = np.nan
+                df.loc['Kappa', tlbls[0]] = kappa
+
+                df.to_excel(filename)
 
     def updatepoly(self, xycoords=None):
         """
@@ -643,6 +664,27 @@ class SuperClass(QtWidgets.QDialog):
         else:
             self.df.loc[row, 'geometry'] = Polygon(xycoords)
 
+    def oncellchange(self, row, col):
+        """
+        Routine activated whenever a cell is changed.
+
+        Parameters
+        ----------
+        row : int
+            Current row.
+        col : int
+            Current column.
+
+        Returns
+        -------
+        None.
+
+        """
+        if self.tablewidget.currentItem() is None or col != 0:
+            return
+
+        self.df.loc[row, 'class'] = self.tablewidget.item(row, 0).text()
+
     def onrowchange(self, current, previous):
         """
         Routine activated whenever a row is changed.
@@ -668,6 +710,9 @@ class SuperClass(QtWidgets.QDialog):
         if self.df.loc[row, 'geometry'] == Polygon([]):
             return
         coords = list(self.df.loc[row, 'geometry'].exterior.coords)
+
+        self.update_class_polys()
+
         self.map.polyi.new_poly(coords)
 
     def ontablechange(self, row, column):
@@ -710,6 +755,7 @@ class SuperClass(QtWidgets.QDialog):
         item.setFlags(item.flags() & ~QtCore.Qt.ItemIsEditable)
         self.tablewidget.setItem(row, 1, item)
 
+        self.update_class_polys()
         self.map.polyi.new_poly([[1, 1]])
 
         self.df.loc[row] = None
@@ -733,6 +779,8 @@ class SuperClass(QtWidgets.QDialog):
         self.tablewidget.removeRow(self.tablewidget.currentRow())
         self.df = self.df.drop(row)
         self.df = self.df.reset_index(drop=True)
+
+        self.update_class_polys()
         if self.tablewidget.rowCount() == 0:
             self.map.polyi.new_poly()
             self.map.polyi.isactive = False
@@ -768,14 +816,18 @@ class SuperClass(QtWidgets.QDialog):
             return False
 
         df = gpd.read_file(filename)
+        df.columns = df.columns.str.lower()
+        if 'id' in df:
+            df = df.drop('id', axis='columns')
+
         if 'class' not in df or 'geometry' not in df:
             return False
 
-        self.df = df
+        self.df = df.dropna()
         self.tablewidget.setRowCount(0)
         for index, _ in self.df.iterrows():
             self.tablewidget.insertRow(index)
-            item = QtWidgets.QTableWidgetItem('Class '+str(index+1))
+            item = QtWidgets.QTableWidgetItem(self.df['class'].iloc[index])
             self.tablewidget.setItem(index, 0, item)
 
         self.map.polyi.isactive = True
@@ -806,7 +858,10 @@ class SuperClass(QtWidgets.QDialog):
 
     def settings(self, nodialog=False):
         """
-        Settings.
+        Entrypoint into class.
+
+        This is called when the used double clicks the routine from the
+        main PyGMI interface.
 
         Returns
         -------
@@ -839,7 +894,7 @@ class SuperClass(QtWidgets.QDialog):
         if tmp == 0:
             return False
 
-        classifier, lbls, datall, _, _ = self.init_classifier()
+        classifier, lbls, datall, _, _, _ = self.init_classifier()
 
         mask = self.map.data[0].data.mask
         yout = np.zeros_like(datall[:, :, 0], dtype=int)
@@ -882,6 +937,7 @@ class SuperClass(QtWidgets.QDialog):
 
         # self.log = ('Cluster complete' + ' (' + self.cltype+')')
 
+        dat_out[-1].wkt = data[0].wkt
         dat_out[-1].xdim = data[0].xdim
         dat_out[-1].ydim = data[0].ydim
         dat_out[-1].dataid = 'Clusters: '+str(dat_out[-1].metadata['Cluster']['no_clusters'])
@@ -903,7 +959,7 @@ class SuperClass(QtWidgets.QDialog):
 
     def loadproj(self, projdata):
         """
-        Loads project data into class.
+        Load project data into class.
 
         Parameters
         ----------
@@ -983,7 +1039,6 @@ class SuperClass(QtWidgets.QDialog):
         masks = {}
         for _, row in self.df.iterrows():
             # pixels = list(row['geometry'].exterior.coords)
-
             pixels = np.array(row['geometry'].exterior.coords)
             pixels[:, 0] = pixels[:, 0]-self.map.data[0].extent[0]
             pixels[:, 0] /= self.map.data[0].xdim
@@ -1000,8 +1055,6 @@ class SuperClass(QtWidgets.QDialog):
             rasterize = ImageDraw.Draw(rasterPoly)
             rasterize.polygon(pixels, 0)
             mask = np.array(rasterPoly, dtype=bool)
-            # plt.imshow(mask)
-            # plt.show()
 
             masks[cname] = np.logical_or(~mask, masks[cname])
 
@@ -1013,9 +1066,11 @@ class SuperClass(QtWidgets.QDialog):
 
         y = []
         x = []
+        tlbls = []
         for i, lbl in enumerate(masks):
             y += [i]*masks[lbl].sum()
             x.append(datall[masks[lbl]])
+            tlbls.append(lbl)
 
         y = np.array(y)
         x = np.vstack(x)
@@ -1032,7 +1087,7 @@ class SuperClass(QtWidgets.QDialog):
 
         classifier.fit(X_train, y_train)
 
-        return classifier, lbls, datall, X_test, y_test
+        return classifier, lbls, datall, X_test, y_test, tlbls
 
     def update_map(self, polymask):
         """
@@ -1063,6 +1118,22 @@ class SuperClass(QtWidgets.QDialog):
         self.map.csp.changed()
         self.map.figure.canvas.draw()
 
+    def update_class_polys(self):
+        """Update class poly summaries."""
+        axes = self.map.figure.gca()
+
+        [p.remove() for p in reversed(axes.patches)]
+
+        for index, row in self.df.iterrows():
+            if row['geometry'] is None:
+                return
+            crds = np.array(row['geometry'].exterior.coords)
+
+            poly = mPolygon(crds, ec='k', fill=False)
+            axes.add_patch(poly)
+
+        self.map.figure.canvas.draw()
+
 
 def dist_point_to_segment(p, s0, s1):
     """
@@ -1107,14 +1178,21 @@ def dist_point_to_segment(p, s0, s1):
     return np.linalg.norm(p - pb)
 
 
-def test():
+def _testfn():
     """Test."""
     sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__),
                                                  '..//..')))
     from pygmi.raster import iodefs
+    from pygmi.misc import ProgressBarText
     app = QtWidgets.QApplication(sys.argv)
 
-    data = iodefs.get_raster(r'C:\work\WorkData\testdata.hdr')
+    piter = ProgressBarText().iter
+
+    ifile = r'E:\Workdata\people\janinetest2\coal_12052020_pan.img'
+
+    data = iodefs.get_raster(ifile, piter=piter)
+    # data = iodefs.get_raster(r'D:\Workdata\BV1_17_fx_extracted_image_1.hdr')
+    os.chdir(r'e:\Workdata\people\janinetest2')
 
     tmp = SuperClass(None)
     tmp.indata['Raster'] = data
@@ -1123,4 +1201,4 @@ def test():
 
 if __name__ == "__main__":
 
-    test()
+    _testfn()
