@@ -25,6 +25,7 @@
 """EM Menu Routines."""
 
 from PyQt5 import QtWidgets
+
 from pygmi.em import tdem
 
 
@@ -57,5 +58,4 @@ class MenuWidget():
 
     def tdem1d(self):
         """TDEM 1D inversion."""
-        fnc = tdem.TDEM1D(self.parent)
-        self.parent.item_insert('Step', 'TDEM 1D Inversion', fnc)
+        self.parent.item_insert('Step', 'TDEM 1D Inversion', tdem.TDEM1D)
