@@ -39,6 +39,7 @@ from SimPEG import (maps, data_misfit, regularization,
 from SimPEG.electromagnetics import time_domain
 import SimPEG.data as Sdata
 import pygmi.menu_default as menu_default
+
 from pygmi.misc import QLabelVStack
 from contextlib import redirect_stdout
 
@@ -61,7 +62,7 @@ class MyMplCanvas2(FigureCanvasQTAgg):
         pdata : numpy array
             Phase data.
         rdata : numpy array
-            Apperent resistivity data.
+            Apparent resistivity data.
         depths : numpy array, optional
             Model depths. The default is None.
         res : numpy array, optional
@@ -100,14 +101,13 @@ class MyMplCanvas2(FigureCanvasQTAgg):
 
     def disp_wave(self, times, wave, title):
         """
-
+        Display waveform.
 
         Returns
         -------
         None.
 
         """
-
         self.figure.clear()
 
         ax1 = self.figure.add_subplot(111)
@@ -459,14 +459,13 @@ class TDEM1D(QtWidgets.QDialog):
 
     def change_source(self):
         """
-
+        Change Source.
 
         Returns
         -------
         None.
 
         """
-
         stype = self.combostype.currentText()
 
         if stype == 'CircularLoop':
@@ -480,14 +479,13 @@ class TDEM1D(QtWidgets.QDialog):
 
     def disp_wave(self):
         """
-
+        Display waveform.
 
         Returns
         -------
         None.
 
         """
-
         offtime = float(self.txofftime.text())
         times = np.linspace(0, offtime, 1000)
         wtype = self.combowtype.currentText()
@@ -516,12 +514,12 @@ class TDEM1D(QtWidgets.QDialog):
 
     def update_wave(self):
         """
-
+        Update waveform.
 
         Returns
         -------
-        wform : TYPE
-            DESCRIPTION.
+        wform : tdem waveform.
+            Waveform.
 
         """
         offtime = float(self.txofftime.text())
@@ -629,7 +627,8 @@ class TDEM1D(QtWidgets.QDialog):
         self.combobalt.addItems(cnames)
         for i, tmp in enumerate(cnames):
             tmp = tmp.lower()
-            if ('elev' in tmp or 'alt' in tmp or 'height' in tmp or 'radar' in tmp):
+            if ('elev' in tmp or 'alt' in tmp or 'height' in tmp or
+                    'radar' in tmp):
                 self.combobalt.setCurrentIndex(i)
                 break
 
@@ -674,7 +673,6 @@ class TDEM1D(QtWidgets.QDialog):
             A check to see if settings was successfully run.
 
         """
-
         return False
 
     def saveproj(self):
@@ -708,7 +706,7 @@ def tonumber(test, alttext=None):
     Returns
     -------
     str or int or float
-        Returns a lower case verion of alttext, or a number.
+        Returns a lower case version of alttext, or a number.
 
     """
     if alttext is not None and test.lower() == alttext.lower():
@@ -723,9 +721,8 @@ def tonumber(test, alttext=None):
     return int(test)
 
 
-def testrun():
+def _testfn():
     """Test routine."""
-
     from pygmi.vector.iodefs import ImportLineData
 
     app = QtWidgets.QApplication(sys.argv)
@@ -752,8 +749,6 @@ def testrun():
     # os.environ['KMP_WARNINGS'] ='0'
     tmp.settings(True)
 
-    breakpoint()
-
 
 if __name__ == "__main__":
-    testrun()
+    _testfn()
