@@ -25,6 +25,7 @@
 """Exploration seismics Menu Routines."""
 
 from PyQt5 import QtWidgets
+
 from pygmi.eseis import iodefs
 from pygmi.eseis import graphs
 
@@ -69,8 +70,7 @@ class MenuWidget():
 
     def import_data(self):
         """Import data."""
-        fnc = iodefs.ImportSEGY(self.parent)
-        self.parent.item_insert('Io', 'Import SEG-Y Data', fnc)
+        self.parent.item_insert('Io', 'Import SEG-Y Data', iodefs.ImportSEGY)
 
     def export_data(self):
         """Export data."""
