@@ -36,7 +36,7 @@ class ProcessData(QtWidgets.QDialog):
     """
     Process Gravity Data.
 
-    This class grids point data using a nearest neighbourhood technique.
+    This class processes gravity data.
 
     Attributes
     ----------
@@ -58,7 +58,6 @@ class ProcessData(QtWidgets.QDialog):
         self.indata = {}
         self.outdata = {}
         self.parent = parent
-#        self.pbar = parent.pbar
 
         self.dsb_dxy = QtWidgets.QDoubleSpinBox()
         self.dsb_null = QtWidgets.QDoubleSpinBox()
@@ -179,7 +178,6 @@ class ProcessData(QtWidgets.QDialog):
             A check to see if settings was successfully run.
 
         """
-
         self.dsb_dxy.setValue(projdata['dxy'])
         self.dsb_null.setValue(projdata['null'])
         self.dataid.setCurrentText(projdata['dataid'])
@@ -273,6 +271,9 @@ class ProcessData(QtWidgets.QDialog):
         tmp2.append(tcnt)
         ix += tmp2
 
+        drate = []
+        dtime = []
+        dday = []
         for iday in np.unique(ix):
             filt = (ix == iday)
             x2 = xp1[filt].values/60.
@@ -281,16 +282,28 @@ class ProcessData(QtWidgets.QDialog):
             driftrate = (dcor2[-1]-dcor2[0])/drifttime
             self.showprocesslog(f'Day {iday+1} drift: {driftrate:.3e} '
                                 f'mGal/min over {drifttime:.3f} minutes.')
+            dday.append(iday+1+x2[-1]/1440)
+            drate.append(driftrate)
+            dtime.append(drifttime)
 
         xp2 = xp1/86400 + ix+1
 
         if not nodialog:
             plt.figure('QC: Gravimeter Drift')
+            plt.subplot(2, 1, 1)
             plt.xlabel('Decimal Days')
-            plt.ylabel('GRAV')
+            plt.ylabel('mGal')
             plt.grid(True)
             plt.plot(xp2, fp, '.-')
             plt.xticks(range(1, ix[-1]+2, 1))
+            ax = plt.gca()
+
+            plt.subplot(2, 1, 2, sharex=ax)
+            plt.xlabel('Decimal Days')
+            plt.ylabel('mGal/min')
+            plt.grid(True)
+            plt.plot(dday, drate, '.-')
+            # plt.xticks(range(1, ix[-1]+2, 1))
             plt.tight_layout()
 
             plt.get_current_fig_manager().window.setWindowIcon(self.parent.windowIcon())
@@ -418,7 +431,7 @@ def theoretical_gravity(lat):
     Returns
     -------
     gT : numpy array
-        Array of theoretrical gravity values.
+        Array of theoretical gravity values.
 
     """
     gT = 978032.67715*((1 + 0.001931851353 * np.sin(lat)**2) /
@@ -434,7 +447,7 @@ def atmospheric_correction(h):
     Parameters
     ----------
     h : numpy array
-        Heights relative to elipsoid (GPS heights).
+        Heights relative to ellipsoid (GPS heights).
 
     Returns
     -------
@@ -456,7 +469,7 @@ def height_correction(lat, h):
     lat : numpy array
         Latitude in radians.
     h : numpy array
-        Heights relative to elipsoid (GPS heights).
+        Heights relative to ellipsoid (GPS heights).
 
     Returns
     -------
@@ -471,12 +484,12 @@ def height_correction(lat, h):
 
 def spherical_bouguer(h, dens):
     """
-    Calculate spherical bouguer.
+    Calculate spherical Bouguer.
 
     Parameters
     ----------
     h : numpy array
-        Heights relative to elipsoid (GPS heights).
+        Heights relative to ellipsoid (GPS heights).
     dens : float
         Density.
 
@@ -533,15 +546,15 @@ def time_convert(x):
     return (h*60+m)*60+s
 
 
-def test():
+def _testfn():
     """Test routine."""
     APP = QtWidgets.QApplication(sys.argv)  # Necessary to test Qt Classes
 
     grvfile = r'C:\Work\Workdata\gravity\skeifontein 2018.txt'
     gpsfile = r'C:\Work\Workdata\gravity\skei_dgps.csv'
 
-    grvfile = r'C:\Work\Workdata\gravity\Laxeygarvity until2511.txt'
-    gpsfile = r'C:\Work\Workdata\gravity\laxey.dgps.csv'
+    # grvfile = r'C:\Work\Workdata\gravity\Laxeygarvity until2511.txt'
+    # gpsfile = r'C:\Work\Workdata\gravity\laxey.dgps.csv'
 
 # Import Data
     IO = iodefs.ImportCG5(None)
@@ -562,14 +575,14 @@ def test():
 
     gdf = datout['Gravity']
 
-    gdf = gdf[(gdf.STATION >4470) & (gdf.STATION<4472)]
-#    gdf = gdf[(gdf.STATION >2213) & (gdf.STATION<2900)]
+    gdf = gdf[(gdf.STATION > 4470) & (gdf.STATION < 4472)]
+#    gdf = gdf[(gdf.STATION > 2213) & (gdf.STATION < 2900)]
 
     plt.plot(gdf.longitude, gdf.latitude, '.')
     plt.show()
 
 
 if __name__ == "__main__":
-    test()
+    _testfn()
 
     print('Finished!')
