@@ -25,6 +25,7 @@
 """Gravity Menu Routines."""
 
 from PyQt5 import QtWidgets
+
 from pygmi.grav import iodefs
 from pygmi.grav import dataprep
 
@@ -62,10 +63,9 @@ class MenuWidget():
 
     def import_data(self):
         """Import data."""
-        fnc = iodefs.ImportCG5(self.parent)
-        self.parent.item_insert('Io', 'Import CG-5 Data', fnc)
+        self.parent.item_insert('Io', 'Import CG-5 Data', iodefs.ImportCG5)
 
     def process_data(self):
         """Process data."""
-        fnc = dataprep.ProcessData(self.parent)
-        self.parent.item_insert('Step', 'Process Gravity Data', fnc)
+        self.parent.item_insert('Step', 'Process Gravity Data',
+                                dataprep.ProcessData)
