@@ -31,6 +31,7 @@ from scipy.signal import tukey
 import scipy.interpolate as si
 import scipy.signal as signal
 import pygmi.menu_default as menu_default
+
 from pygmi.raster.datatypes import Data
 
 
@@ -59,7 +60,11 @@ class Tilt1(QtWidgets.QDialog):
         self.outdata = {}
         self.azi = 75
         self.smooth = 0
-        self.pbar = self.parent.pbar
+
+        if parent is not None:
+            self.piter = self.parent.pbar.iter
+        else:
+            self.piter = iter
 
         self.sb_azi = QtWidgets.QSpinBox()
         self.sb_s = QtWidgets.QSpinBox()
@@ -127,7 +132,7 @@ class Tilt1(QtWidgets.QDialog):
         data = copy.deepcopy(self.indata['Raster'])
         data2 = []
 
-        for i in self.pbar.iter(range(len(data))):
+        for i in self.piter(range(len(data))):
             t1, th, t2, ta, tdx = tilt1(data[i].data, self.azi, self.smooth)
             data2.append(copy.deepcopy(data[i]))
             data2.append(copy.deepcopy(data[i]))
@@ -191,8 +196,10 @@ class Tilt1(QtWidgets.QDialog):
 
 def tilt1(data, azi, s):
     """
-    Tilt angle calculations. Based on work by Gordon Cooper (School of
-    Geosciences, University of the Witwatersrand, Johannesburg, South Africa)
+    Tilt angle calculations.
+
+    Based on work by Gordon Cooper (School of Geosciences, University of the
+                                    Witwatersrand, Johannesburg, South Africa)
 
     Parameters
     ----------
@@ -276,8 +283,10 @@ def tilt1(data, azi, s):
 
 def nextpow2(n):
     """
-    Next power of 2. Based on work by Gordon Cooper (School of Geosciences,
-    University of the Witwatersrand, Johannesburg, South Africa).
+    Next power of 2.
+
+    Based on work by Gordon Cooper (School of Geosciences, University of the
+                                    Witwatersrand, Johannesburg, South Africa).
 
     Parameters
     ----------
@@ -296,8 +305,10 @@ def nextpow2(n):
 
 def vertical(data, npts=None, xint=1, order=1):
     """
-    Vertical derivative. Based on work by Gordon Cooper (School of Geosciences,
-    University of the Witwatersrand, Johannesburg, South Africa).
+    Vertical derivative.
+
+    Based on work by Gordon Cooper (School of Geosciences, University of the
+                                    Witwatersrand, Johannesburg, South Africa).
 
     Parameters
     ----------
@@ -369,7 +380,11 @@ class RTP(QtWidgets.QDialog):
         self.indata = {}
         self.outdata = {}
         self.parent = parent
-        self.pbar = self.parent.pbar
+
+        if parent is not None:
+            self.piter = self.parent.pbar.iter
+        else:
+            self.piter = iter
 
         self.dataid = QtWidgets.QComboBox()
         self.dsb_inc = QtWidgets.QDoubleSpinBox()
@@ -503,7 +518,7 @@ class RTP(QtWidgets.QDialog):
         D_deg = self.dsb_dec.value()
 
         newdat = []
-        for data in self.pbar.iter(self.indata['Raster']):
+        for data in self.piter(self.indata['Raster']):
             if data.dataid != self.dataid.currentText():
                 continue
             dat = rtp(data, I_deg, D_deg)
@@ -594,7 +609,7 @@ def fft_getkxy(fftmod, xdim, ydim):
 
 def rtp(data, I_deg, D_deg):
     """
-    Reduction to th epole.
+    Reduction to the pole.
 
     Parameters
     ----------
@@ -644,8 +659,8 @@ def rtp(data, I_deg, D_deg):
     return dat
 
 
-def testfn():
-    """Main RTP testing routine."""
+def _testfn():
+    """RTP testing routine."""
     import matplotlib.pyplot as plt
     from matplotlib import cm
     from pygmi.pfmod.grvmag3d import quick_model, calc_field
@@ -674,4 +689,4 @@ def testfn():
 
 
 if __name__ == "__main__":
-    testfn()
+    _testfn()
