@@ -610,7 +610,8 @@ class MainWidget(QtWidgets.QMainWindow):
         menus = [raster_menu, vector_menu]+menus
         menus = [i for i in menus if 'menu' in i[-5:]]
 
-        # menus = ['pygmi.raster.menu',
+        # menus = [
+        #          'pygmi.raster.menu',
         #          'pygmi.em.menu',
         #          'pygmi.vector.menu',
         #          'pygmi.bholes.menu',
@@ -783,7 +784,6 @@ class MainWidget(QtWidgets.QMainWindow):
         None.
 
         """
-
         if event.key() == QtCore.Qt.Key_Delete:
             self.delete_item()
 
@@ -823,12 +823,13 @@ class MainWidget(QtWidgets.QMainWindow):
         """Help Routine."""
         menu_default.HelpDocs(self, 'pygmi.main')
 
-    def item_insert(self, item_type, item_name, class_name, runimport=True):
+    def item_insert(self, item_type, item_name, class_name, runimport=True,
+                    params=None):
         """
         Item insert.
 
         Insert an item on the main interface. The item is an object passed by
-        one of the menu.py routines and is one of the algorithims chosen on
+        one of the menu.py routines and is one of the algorithms chosen on
         the main PyGMI menu.
 
         Parameters
@@ -845,8 +846,13 @@ class MainWidget(QtWidgets.QMainWindow):
         item : DiagramItem
             Return a DiagramItem object
         """
-        item = DiagramItem(item_type, self.scene.my_item_menu, class_name,
-                           self)
+        if params is None:
+            class_name_active = class_name(self)
+        else:
+            class_name_active = class_name(self, params)
+
+        item = DiagramItem(item_type, self.scene.my_item_menu,
+                           class_name_active, self)
         item_color = self.scene.my_item_color
 
         item_name = item_name.replace(' ', '\n')
@@ -975,14 +981,13 @@ class MainWidget(QtWidgets.QMainWindow):
 
     def load(self):
         """
-        Loads project state from JSON file.
+        Load project state from JSON file.
 
         Returns
         -------
         None.
 
         """
-
         self.process_is_active()
         self.showprocesslog('Project load busy...')
 
@@ -991,8 +996,6 @@ class MainWidget(QtWidgets.QMainWindow):
         if ifile == '':
             return False
 
-        # ifile = r'C:\Work\Workdata\jason.json'
-
         with open(ifile, 'r') as fromdisk:
             ilist = json.load(fromdisk)
 
@@ -1007,7 +1010,7 @@ class MainWidget(QtWidgets.QMainWindow):
             my_class = my_class.rsplit('.', 1)
 
             class_name = getattr(sys.modules[my_class[0]], my_class[1])
-            class_name = class_name(self)
+            # class_name = class_name(self)
             item_name = item['my_class_name']
             item_type = item['diagram_type']
 
@@ -1020,6 +1023,9 @@ class MainWidget(QtWidgets.QMainWindow):
             ditems[key] = citem
 
             citem.setBrush(QtGui.QColor(0, 255, 255, 254))
+
+            class_name = citem.my_class
+
             if hasattr(class_name, 'loadproj'):
                 chk = class_name.loadproj(item['itemdata'])
                 if chk is True:
@@ -1044,14 +1050,13 @@ class MainWidget(QtWidgets.QMainWindow):
 
     def save(self):
         """
-        Saves project state to a JSON file.
+        Save project state to a JSON file.
 
         Returns
         -------
         None.
 
         """
-
         ofile, _ = QtWidgets.QFileDialog.getSaveFileName(
             self, 'Save Project', '.', 'PyGMI project (*.json);;')
         if ofile == '':
@@ -1088,7 +1093,6 @@ class MainWidget(QtWidgets.QMainWindow):
         None.
 
         """
-
         # get all arrows
         alist = {}
         for item in self.scene.items():
@@ -1099,7 +1103,7 @@ class MainWidget(QtWidgets.QMainWindow):
             self.showprocesslog('No connections. Aborting run.')
             return
 
-        # Collect only items recieving data
+        # Collect only items receiving data
         ilist = []
         slist = []
         for item in self.scene.items():
@@ -1199,7 +1203,6 @@ class MainWidget(QtWidgets.QMainWindow):
             flag to indicate whether the last row on the log should be
             overwritten.
         """
-
         txtobj = self.textbrowser_processlog
 
         txtmsg = str(txtobj.toPlainText()+'\n')
@@ -1217,8 +1220,8 @@ class MainWidget(QtWidgets.QMainWindow):
         """
         Clean deleted objects in self.pdlg and appends a new object.
 
-        self.pdlg allows for modeless dialogs to remain in existance until they
-        are closed
+        self.pdlg allows for modeless dialogues to remain in existence until
+        they are closed
 
         Parameters
         ----------
@@ -1266,13 +1269,13 @@ class Startup(QtWidgets.QDialog):
         self.open()
 
     def update(self):
-        """Update the text on the dialog"""
+        """Update the text on the dialog."""
         self.pbar.setValue(self.pbar.value() + 1)
         QtWidgets.QApplication.processEvents()
 
 
 class EmittingStream(QtCore.QObject):
-    """ Class to intercept stdout for later use in a textbox """
+    """Class to intercept stdout for later use in a textbox."""
 
     def __init__(self, textWritten):
         self.textWritten = textWritten
@@ -1295,7 +1298,7 @@ class EmittingStream(QtCore.QObject):
 
     def flush(self):
         """
-        Flush
+        Flush.
 
         Returns
         -------
@@ -1305,7 +1308,7 @@ class EmittingStream(QtCore.QObject):
 
     def fileno(self):
         """
-        Fileno
+        Fileno.
 
         Returns
         -------
@@ -1313,12 +1316,11 @@ class EmittingStream(QtCore.QObject):
             Returns -1.
 
         """
-
         return -1
 
 
 def main():
-    """Entry point for the PyGMI software"""
+    """Entry point for the PyGMI software."""
     app = QtWidgets.QApplication(sys.argv)
     # The try statement is because this command is only available for qt>=5.10
     try:
