@@ -70,16 +70,10 @@ from PyQt5 import QtWidgets, QtCore, QtGui
 
 class BIRRP(QtWidgets.QDialog):
     """
-    Import Line Data.
-
-    This class imports ASCII point data.
+    Class to export config file for BIRRP .
 
     Attributes
     ----------
-    name : str
-        item name
-    pbar : progressbar
-        reference to a progress bar.
     parent : parent
         reference to the parent routine
     outdata : dictionary
@@ -95,7 +89,6 @@ class BIRRP(QtWidgets.QDialog):
         else:
             self.showprocesslog = parent.showprocesslog
 
-        self.pbar = None  # self.parent.pbar
         self.parent = parent
         self.indata = {'tmp': True}
         self.outdata = {}
@@ -227,7 +220,7 @@ class BIRRP(QtWidgets.QDialog):
                         self.c2threshe)
         self.lay.addRow("OFIL: output filename root", self.ofil)
         self.lay.addRow("NLEV: output level", self.nlev)
-        self.lay.addRow("NPCS: numer of data pieces", self.npcs)
+        self.lay.addRow("NPCS: number of data pieces", self.npcs)
         self.lay.addRow("NAR: length of ar filter (0 for none, <0 for "
                         "filename)", self.nar)
         self.lay.addRow("IMODE: file mode", self.imode)
@@ -756,7 +749,7 @@ class BIRRP(QtWidgets.QDialog):
 
     def loadproj(self, projdata):
         """
-        Loads project data into class.
+        Load project data into class.
 
         Parameters
         ----------
@@ -769,14 +762,12 @@ class BIRRP(QtWidgets.QDialog):
             A check to see if settings was successfully run.
 
         """
-
         return False
 
     def saveproj(self):
         """
         Save project data from class.
 
-
         Returns
         -------
         projdata : dictionary
