@@ -281,9 +281,7 @@ class Metadata(QtWidgets.QDialog):
 
 
 class MyMplCanvas(FigureCanvasQTAgg):
-    """
-    MPL Canvas class.
-    """
+    """MPL Canvas class."""
 
     def __init__(self, parent=None):
         fig = Figure()
@@ -532,7 +530,6 @@ class StaticShiftEDI(QtWidgets.QDialog):
             True if successful, False otherwise.
 
         """
-
         if 'MT - EDI' in self.indata:
             self.data = copy.deepcopy(self.indata['MT - EDI'])
         else:
@@ -561,7 +558,7 @@ class StaticShiftEDI(QtWidgets.QDialog):
 
     def loadproj(self, projdata):
         """
-        Loads project data into class.
+        Load project data into class.
 
         Parameters
         ----------
@@ -574,7 +571,6 @@ class StaticShiftEDI(QtWidgets.QDialog):
             A check to see if settings was successfully run.
 
         """
-
         self.shiftx.setValue(projdata['shiftx'])
         self.shifty.setValue(projdata['shifty'])
         self.checkbox.setChecked(projdata['checkbox'])
@@ -585,7 +581,6 @@ class StaticShiftEDI(QtWidgets.QDialog):
         """
         Save project data from class.
 
-
         Returns
         -------
         projdata : dictionary
@@ -602,7 +597,7 @@ class StaticShiftEDI(QtWidgets.QDialog):
 
 
 class RotateEDI(QtWidgets.QDialog):
-    """Roitate EDI data."""
+    """Rotate EDI data."""
 
     def __init__(self, parent=None):
         super().__init__(parent)
@@ -749,7 +744,6 @@ class RotateEDI(QtWidgets.QDialog):
             True if successful, False otherwise.
 
         """
-
         if 'MT - EDI' in self.indata:
             self.data = copy.deepcopy(self.indata['MT - EDI'])
         else:
@@ -781,7 +775,7 @@ class RotateEDI(QtWidgets.QDialog):
 
     def loadproj(self, projdata):
         """
-        Loads project data into class.
+        Load project data into class.
 
         Parameters
         ----------
@@ -794,7 +788,6 @@ class RotateEDI(QtWidgets.QDialog):
             A check to see if settings was successfully run.
 
         """
-
         self.spinbox.setValue(projdata['rotz'])
         self.checkbox.setChecked(projdata['checkbox'])
 
@@ -804,7 +797,6 @@ class RotateEDI(QtWidgets.QDialog):
         """
         Save project data from class.
 
-
         Returns
         -------
         projdata : dictionary
@@ -1267,7 +1259,7 @@ class EditEDI(QtWidgets.QDialog):
 
     def loadproj(self, projdata):
         """
-        Loads project data into class.
+        Load project data into class.
 
         Parameters
         ----------
@@ -1280,14 +1272,12 @@ class EditEDI(QtWidgets.QDialog):
             A check to see if settings was successfully run.
 
         """
-
         return False
 
     def saveproj(self):
         """
         Save project data from class.
 
-
         Returns
         -------
         projdata : dictionary
@@ -1303,7 +1293,7 @@ class EditEDI(QtWidgets.QDialog):
 
 class MySlider(QtWidgets.QSlider):
     """
-    My Slider
+    My Slider.
 
     Custom class which allows clicking on a horizontal slider bar with slider
     moving to click in a single step.
@@ -1352,9 +1342,7 @@ class MySlider(QtWidgets.QSlider):
 
 
 class MyMplCanvas2(FigureCanvasQTAgg):
-    """
-    MPL Canvas class.
-    """
+    """MPL Canvas class."""
 
     def __init__(self, parent=None):
         fig = Figure()
@@ -1371,7 +1359,7 @@ class MyMplCanvas2(FigureCanvasQTAgg):
         pdata : numpy array
             Phase data.
         rdata : numpy array
-            Apperent resistivity data.
+            Apparent resistivity data.
         depths : numpy array, optional
             Model depths. The default is None.
         res : numpy array, optional
@@ -1477,6 +1465,9 @@ class Occam1D(QtWidgets.QDialog):
         self.errfloorres.setSizePolicy(sizepolicy)
         self.errfloorphase = QtWidgets.QLineEdit('2.')
         self.errfloorphase.setSizePolicy(sizepolicy)
+        self.remove_out_quad = QtWidgets.QCheckBox(r'Remove Resistivity/'
+                                                   r'Phase values out of '
+                                                   r'1st/3rd Quadrant')
 
         self.targetdepth = QtWidgets.QLineEdit('40000.')
         self.targetdepth.setSizePolicy(sizepolicy)
@@ -1492,6 +1483,7 @@ class Occam1D(QtWidgets.QDialog):
         self.maxiter.setSizePolicy(sizepolicy)
         self.targetrms = QtWidgets.QLineEdit('1.')
         self.targetrms.setSizePolicy(sizepolicy)
+        self.remove_out_quad.setChecked(True)
 
         self.hs_profnum = MySlider()
         self.hs_profnum.setOrientation(QtCore.Qt.Horizontal)
@@ -1503,6 +1495,8 @@ class Occam1D(QtWidgets.QDialog):
         label5 = QtWidgets.QLabel('Phase Errorbar (Data or %):')
         label6 = QtWidgets.QLabel('Resistivity Error Floor (%):')
         label7 = QtWidgets.QLabel('Phase Error Floor (degrees):')
+        label7a = QtWidgets.QLabel(r'Remove Resistivity/Phase values out of'
+                                   r' 1st/3rd Quadrant (True/False):')
         label8 = QtWidgets.QLabel('Height of air layer:')
         label9 = QtWidgets.QLabel('Bottom of model:')
         label10 = QtWidgets.QLabel('Depth of target to investigate:')
@@ -1546,9 +1540,10 @@ class Occam1D(QtWidgets.QDialog):
         gbl.addWidget(self.maxiter, 12, 1)
         gbl.addWidget(label14, 13, 0)
         gbl.addWidget(self.targetrms, 13, 1)
+        gbl.addWidget(self.remove_out_quad, 14, 0, 1, 2)
 
-        gbl.addWidget(pb_apply, 14, 0, 1, 2)
-        gbl.addWidget(buttonbox, 15, 0, 1, 2)
+        gbl.addWidget(pb_apply, 15, 0, 1, 2)
+        gbl.addWidget(buttonbox, 16, 0, 1, 2)
 
         hbl2.addWidget(helpdocs)
         hbl2.addWidget(self.lbl_profnum)
@@ -1615,6 +1610,7 @@ class Occam1D(QtWidgets.QDialog):
         parm['perr'] = tonumber(self.errphase.text(), 'data')
         parm['perrflr'] = tonumber(self.errfloorphase.text())
         parm['rerrflr'] = tonumber(self.errfloorres.text())
+        parm['routq'] = self.remove_out_quad.isChecked()
 
         if -999 in parm.values():
             return
@@ -1640,7 +1636,7 @@ class Occam1D(QtWidgets.QDialog):
                            phase_err=parm['perr'],
                            res_errorfloor=parm['rerrflr'],
                            phase_errorfloor=parm['perrflr'],
-                           remove_outofquadrant=True
+                           remove_outofquadrant=parm['routq']
                            )
 
         m1 = occam1d.Model(target_depth=parm['tdepth'],
@@ -1812,7 +1808,7 @@ class Occam1D(QtWidgets.QDialog):
 
     def loadproj(self, projdata):
         """
-        Loads project data into class.
+        Load project data into class.
 
         Parameters
         ----------
@@ -1837,6 +1833,7 @@ class Occam1D(QtWidgets.QDialog):
         self.errfloorphase.setText(projdata['perrflr'])
         self.errfloorres.setText(projdata['rerrflr'])
         self.combomode.setCurrentText(projdata['mode'])
+        self.remove_out_quad.setChecked(projdata['routq'])
 
         return False
 
@@ -1844,7 +1841,6 @@ class Occam1D(QtWidgets.QDialog):
         """
         Save project data from class.
 
-
         Returns
         -------
         projdata : dictionary
@@ -1865,13 +1861,14 @@ class Occam1D(QtWidgets.QDialog):
         projdata['perrflr'] = self.errfloorphase.text()
         projdata['rerrflr'] = self.errfloorres.text()
         projdata['mode'] = self.combomode.currentText()
+        projdata['routq'] = self.remove_out_quad.isChecked()
 
         return projdata
 
 
 def tonumber(test, alttext=None):
     """
-    Checks if something is a number or matches alttext
+    Check if something is a number or matches alttext.
 
     Parameters
     ----------
@@ -1883,7 +1880,7 @@ def tonumber(test, alttext=None):
     Returns
     -------
     str or int or float
-        Returns a lower case verion of alttext, or a number.
+        Returns a lower case version of alttext, or a number.
 
     """
     if alttext is not None and test.lower() == alttext.lower():
@@ -1898,9 +1895,9 @@ def tonumber(test, alttext=None):
     return int(test)
 
 
-def testfn():
-    """ main test """
-    datadir = r'C:\Work\Programming\pygmi\data\MT\\'
+def _testfn_occam():
+    """Test routine."""
+    datadir = r'C:\Work\workdata\MT\\'
     edi_file = datadir+r"synth02.edi"
 
     # Create an MT object
@@ -1914,5 +1911,22 @@ def testfn():
     test.settings()
 
 
+def _testfn():
+    """Test routine."""
+    datadir = r'C:\Work\workdata\MT\\'
+    allfiles = glob.glob(datadir+'\\*.edi')
+
+    for edi_file in allfiles:
+        # Create an MT object
+        mt_obj = MT(edi_file)
+
+    print('loading complete')
+
+    app = QtWidgets.QApplication(sys.argv)
+    test = Occam1D(None)
+    test.indata['MT - EDI'] = {'SYNTH02': mt_obj}
+    test.settings()
+
+
 if __name__ == "__main__":
-    testfn()
+    _testfn()
