@@ -52,7 +52,6 @@ class ImportLEMI417Data():
     """
 
     def __init__(self, parent=None):
-        self.pbar = None
         self.parent = parent
         self.indata = {}
         self.outdata = {}
@@ -100,7 +99,7 @@ class ImportLEMI417Data():
 
     def loadproj(self, projdata):
         """
-        Loads project data into class.
+        Load project data into class.
 
         Parameters
         ----------
@@ -123,7 +122,6 @@ class ImportLEMI417Data():
         """
         Save project data from class.
 
-
         Returns
         -------
         projdata : dictionary
@@ -160,7 +158,6 @@ class ImportEDI():
     def __init__(self, parent=None):
         self.ifile = ''
         self.ifilelist = []
-        self.pbar = None
         self.parent = parent
         self.indata = {}
         self.outdata = {}
@@ -202,7 +199,7 @@ class ImportEDI():
 
     def loadproj(self, projdata):
         """
-        Loads project data into class.
+        Load project data into class.
 
         Parameters
         ----------
@@ -225,7 +222,6 @@ class ImportEDI():
         """
         Save project data from class.
 
-
         Returns
         -------
         projdata : dictionary
@@ -253,7 +249,6 @@ def get_EDI(ifiles):
     dat : EDI data.
         Dataset imported
     """
-
     dat = {}
 
     for edi_file in ifiles:
@@ -289,7 +284,6 @@ class ExportEDI():
 
     def __init__(self, parent=None):
         self.ifile = ''
-        self.pbar = None
         self.parent = parent
         self.indata = {}
         self.outdata = {}
