@@ -48,6 +48,7 @@ from numba import jit, prange
 from matplotlib import cm
 import matplotlib as mpl
 import matplotlib.pyplot as plt
+
 from pygmi.raster.dataprep import gdal_to_dat
 from pygmi.raster.dataprep import data_to_gdal_mem
 from pygmi.pfmod.datatypes import LithModel
@@ -82,9 +83,14 @@ class GravMag():
 
         self.actionregionaltest = QtWidgets.QAction('Regional\nTest')
         self.actioncalculate = QtWidgets.QAction('Calculate\nGravity\n(All)')
-        self.actioncalculate2 = QtWidgets.QAction('Calculate\nMagnetics\n(All)')
-        self.actioncalculate3 = QtWidgets.QAction('Calculate\nGravity\n(Changes Only)')
-        self.actioncalculate4 = QtWidgets.QAction('Calculate\nMagnetics\n(Changes Only)')
+        self.actioncalculate2 = QtWidgets.QAction('Calculate\nMagnetics\n'
+                                                  '(All)')
+        self.actioncalculate3 = QtWidgets.QAction('Calculate\nGravity\n'
+                                                  '(Changes Only)')
+        self.actioncalculate4 = QtWidgets.QAction('Calculate\nMagnetics\n'
+                                                  '(Changes Only)')
+        self.cb_demag = QtWidgets.QCheckBox('Apply\nDemagnetization\n'
+                                            'Correction')
         self.setupui()
 
     def setupui(self):
@@ -96,6 +102,8 @@ class GravMag():
         None.
 
         """
+        self.cb_demag.setChecked(False)
+
         self.parent.toolbardock.addSeparator()
         self.parent.toolbardock.addAction(self.actionregionaltest)
         self.parent.toolbardock.addSeparator()
@@ -103,6 +111,7 @@ class GravMag():
         self.parent.toolbardock.addAction(self.actioncalculate2)
         self.parent.toolbardock.addAction(self.actioncalculate3)
         self.parent.toolbardock.addAction(self.actioncalculate4)
+        self.parent.toolbardock.addWidget(self.cb_demag)
         self.parent.toolbardock.addSeparator()
 
         self.actionregionaltest.triggered.connect(self.test_pattern)
@@ -206,9 +215,11 @@ class GravMag():
         None.
 
         """
+        demag = self.cb_demag.isChecked()
+
         calc_field(self.lmod, pbars=self.pbars, showtext=self.showtext,
                    parent=self.parent, showreports=showreports,
-                   magcalc=magcalc)
+                   magcalc=magcalc, demag=demag)
 
     def calc_regional(self):
         """
@@ -448,7 +459,6 @@ class GeoData():
         None.
 
         """
-
         if self.modified is True:
             numx = self.g_cols*self.g_dxy
             numy = self.g_rows*self.g_dxy
@@ -470,7 +480,7 @@ class GeoData():
 
             self.modified = False
 
-    def calc_origin_mag(self, hcor=None):
+    def calc_origin_mag(self, hcor=None, demag=False):
         """
         Calculate the field values for the lithologies.
 
@@ -484,7 +494,6 @@ class GeoData():
         None.
 
         """
-
         if self.modified is True:
             numx = self.g_cols*self.g_dxy
             numy = self.g_rows*self.g_dxy
@@ -503,7 +512,7 @@ class GeoData():
             else:
                 hcor2 = int(self.numz-hcor.max())
 
-            self.mboxmain(xdist, ydist, self.zobsm, hcor2)
+            self.mboxmain(xdist, ydist, self.zobsm, hcor2, demag)
 
             self.modified = False
 
@@ -661,9 +670,9 @@ class GeoData():
 
         self.glayers = np.array(glayers)
 
-    def mboxmain(self, xobs, yobs, zobs, hcor):
+    def mboxmain(self, xobs, yobs, zobs, hcor, demag=False):
         """
-        Mbox routine by Blakely
+        Mbox routine by Blakely.
 
         Note: xobs, yobs and zobs must be floats or there will be problems
         later.
@@ -691,7 +700,7 @@ class GeoData():
         |    horizontal and declinations positive east of true north.
         |    Magnetization in A/m.
 
-        Output paramters:
+        Output parameters:
         |    Total field anomaly t, in nT.
 
         Parameters
@@ -733,6 +742,12 @@ class GeoData():
         mi = self.susc*self.hintn*np.array([fa, fb, fc]) / (4*np.pi)
         m3 = mr+mi
 
+        if demag is True:
+            m3 = calc_demag(m3, self.susc,
+                            np.abs(self.x12[1]-self.x12[0]),
+                            np.abs(self.y12[1]-self.y12[0]),
+                            np.abs(self.z12[1]-self.z12[0]))
+
         mt = np.sqrt(m3 @ m3)
         if mt > 0:
             m3 /= mt
@@ -767,6 +782,64 @@ class GeoData():
         self.mlayers = self.mlayers[:-1]-self.mlayers[1:]
 
 
+def calc_demag(mvec, k, dx, dy, dz):
+    """
+    Calculate demagnetisation correction.
+
+    Parameters
+    ----------
+    mvec : numpy array
+        Body Magnetisation.
+    k : TYPE
+        DESCRIPTION.
+    dx : TYPE
+        DESCRIPTION.
+    dy : TYPE
+        DESCRIPTION.
+    dz : TYPE
+        DESCRIPTION.
+
+    Returns
+    -------
+    outvec : numpy array
+        Corrected magnetisation.
+
+    """
+    # Y = dy/2
+    t = dx
+    d = dz
+
+    # Ndz = 4*np.pi*(2*Y*t/(d*t+2*Y*t+2*Y*d))
+    # Ndy = 4*np.pi*(d*t/(d*t+2*Y*t+2*Y*d))
+    # Ndx = 4*np.pi*(2*Y*d/(d*t+2*Y*t+2*Y*d))
+
+    Ndz = 4*np.pi*(t/(2*d+t))
+    Ndy = 4*np.pi*(d/(2*d+t))
+    Ndx = 4*np.pi*(d/(2*d+t))
+
+    Jx, Jy, Jz = mvec
+
+    # Jdz = Jz
+    # Jdy = Jz
+    # Jdx = Jx
+
+    # Jdz2 = Jdz/(1+Ndz*k)
+    # Jdy2 = Jdy/(1+Ndy*k)
+    # Jdx2 = Jdx/(1+Ndx*k)
+
+    # Jx2 = Jdx2
+    # Jy2 = Jdy2
+    # Jz2 = Jdz2
+
+    Jz2 = Jz/(1+Ndz*k)
+    Jy2 = Jy/(1+Ndy*k)
+    Jx2 = Jx/(1+Ndx*k)
+
+    outvec = np.array([Jx2, Jy2, Jz2])
+
+    return outvec
+
+
 def save_layer(mlist):
     """
     Routine to save the mlayer and glayer to a file.
@@ -800,8 +873,7 @@ def save_layer(mlist):
 
 def gridmatch(lmod, ctxt, rtxt):
     """
-    Matches the rows and columns of the second grid to the first
-    grid.
+    Match the rows and columns of the second grid to the first grid.
 
     Parameters
     ----------
@@ -851,7 +923,7 @@ def gridmatch(lmod, ctxt, rtxt):
 
 
 def calc_field(lmod, pbars=None, showtext=None, parent=None,
-               showreports=False, magcalc=False):
+               showreports=False, magcalc=False, demag=False):
     """
     Calculate magnetic and gravity field.
 
@@ -877,7 +949,6 @@ def calc_field(lmod, pbars=None, showtext=None, parent=None,
     lmod.griddata : dictionary
         dictionary of items of type Data.
     """
-
     if showtext is None:
         showtext = print
     if pbars is not None:
@@ -919,12 +990,9 @@ def calc_field(lmod, pbars=None, showtext=None, parent=None,
 #        showtext('No changes to model!')
 #        return None
 
-    try:
-        if False not in tmp:
-            showtext('No changes to model!')
-            return None
-    except:
-        breakpoint()
+    if False not in tmp:
+        showtext('No changes to model!')
+        return None
 
 # get height corrections
     tmp = np.copy(lmod.lith_index)
@@ -944,7 +1012,7 @@ def calc_field(lmod, pbars=None, showtext=None, parent=None,
                 mlist[1].pbars = parent.pbars
                 mlist[1].showtext = parent.showtext
             if magcalc:
-                mlist[1].calc_origin_mag(hcor)
+                mlist[1].calc_origin_mag(hcor, demag)
             else:
                 mlist[1].calc_origin_grav()
             tmpfiles[mlist[0]] = save_layer(mlist)
@@ -1238,8 +1306,9 @@ def quick_model(numx=50, numy=40, numz=5, dxy=100., d_z=100.,
 def _mbox(mval, xobs, yobs, numx, numy, z0, x1, y1, z1, x2, y2, fm1, fm2, fm3,
           fm4, fm5, fm6, alpha, beta):
     """
-    Mbox routine by Blakely, continued from Geodata.mboxmain. It exists
-    in a separate function for JIT purposes.
+    Mbox routine by Blakely, continued from Geodata.mboxmain.
+
+    It exists in a separate function for JIT purposes.
 
     Note: xobs, yobs and zobs must be floats or there will be problems
     later.
@@ -1267,7 +1336,7 @@ def _mbox(mval, xobs, yobs, numx, numy, z0, x1, y1, z1, x2, y2, fm1, fm2, fm3,
     |    horizontal and declinations positive east of true north.
     |    Magnetization in A/m.
 
-    Output paramters:
+    Output parameters:
     |    Total field anomaly t, in nT.
 
 
@@ -1359,8 +1428,9 @@ def _mbox(mval, xobs, yobs, numx, numy, z0, x1, y1, z1, x2, y2, fm1, fm2, fm3,
 def _gbox(gval, xobs, yobs, numx, numy, z_0, x_1, y_1, z_1, x_2, y_2, z_2,
           x, y, z, isign):
     """
-    Gbox routine by Blakely, continued from Geodata.gboxmain. It exists
-    in a separate function for JIT purposes.
+    Gbox routine by Blakely, continued from Geodata.gboxmain.
+
+    It exists in a separate function for JIT purposes.
 
     Note: xobs, yobs and zobs must be floats or there will be problems
     later.
@@ -1452,8 +1522,7 @@ def _gbox(gval, xobs, yobs, numx, numy, z_0, x_1, y_1, z_1, x_2, y_2, z_2,
 
 def dircos(incl, decl, azim):
     """
-    Subroutine DIRCOS computes direction cosines from inclination
-    and declination.
+    DIRCOS computes direction cosines from inclination and declination.
 
     Parameters
     ----------
@@ -1494,7 +1563,7 @@ def dat_extent(dat, axes):
     dat : PyGMI Data
         PyGMI raster dataset.
     axes : matplotlib.axes._subplots.AxesSubplot
-        Matploltib axes.
+        Matplotlib axes.
 
     Returns
     -------
@@ -1524,8 +1593,8 @@ def dat_extent(dat, axes):
     return (left, right, bottom, top)
 
 
-def test():
-    """This routine is for testing purposes."""
+def _testfn():
+    """Test routine."""
 #    from pygmi.pfmod.iodefs import ImportMod3D
 
 # Import model file
@@ -1555,4 +1624,4 @@ def test():
 
 
 if __name__ == "__main__":
-    test()
+    _testfn()
