@@ -32,6 +32,7 @@ from PyQt5 import QtWidgets, QtCore
 import numpy as np
 from osgeo import osr, ogr
 import matplotlib.pyplot as plt
+
 from pygmi.pfmod.datatypes import LithModel
 import pygmi.pfmod.grvmag3d as grvmag3d
 import pygmi.pfmod.cubes as mvis3d
@@ -40,6 +41,7 @@ import pygmi.raster.dataprep as dp
 # This is necessary for loading npz files, since I moved the location of
 # datatypes.
 from pygmi.pfmod import datatypes
+
 sys.modules['datatypes'] = datatypes
 
 
@@ -56,7 +58,9 @@ class ImportMod3D():
         self.outdata = {}
 
         if parent is not None:
-            self.pbars = parent.pbar
+            self.piter = parent.pbar.iter
+        else:
+            self.piter = iter
 
     def settings(self, nodialog=False):
         """
@@ -68,7 +72,6 @@ class ImportMod3D():
             True if successful, False otherwise.
 
         """
-
         if not nodialog:
             ext = ('npz (*.npz);;'
                    'Leapfrog Block Model (*.csv);;'
@@ -111,7 +114,7 @@ class ImportMod3D():
 
     def loadproj(self, projdata):
         """
-        Loads project data into class.
+        Load project data into class.
 
         Parameters
         ----------
@@ -135,7 +138,6 @@ class ImportMod3D():
         """
         Save project data from class.
 
-
         Returns
         -------
         projdata : dictionary
@@ -151,7 +153,7 @@ class ImportMod3D():
 
     def import_leapfrog_csv(self, filename):
         """
-        Imports leapfrog csv block models.
+        Import leapfrog csv block models.
 
         Parameters
         ----------
@@ -163,8 +165,6 @@ class ImportMod3D():
         None.
 
         """
-        piter = self.pbars.iter
-
         with open(filename) as fno:
             tmp = fno.readlines()
 
@@ -189,7 +189,7 @@ class ImportMod3D():
         ycell = float(tmp[0].split(',')[4])
         zcell = float(tmp[0].split(',')[5])
 
-        for i in piter(tmp):
+        for i in self.piter(tmp):
             i2 = i.split(',')
             x.append(float(i2[0]))
             y.append(float(i2[1]))
@@ -246,7 +246,7 @@ class ImportMod3D():
                     usedtm=True)
         lmod.update_lith_list_reverse()
 
-        for i in piter(range(len(x))):
+        for i in self.piter(range(len(x))):
             xi = x[i]
             col = int((xi-lmod.xrange[0])/lmod.dxy)
             row = int((lmod.yrange[1]-y[i])/lmod.dxy)
@@ -348,7 +348,7 @@ class ImportMod3D():
 
     def dict2lmod(self, indict, pre=''):
         """
-        Convert a dictionary to a LithModel
+        Convert a dictionary to a LithModel.
 
         Parameters
         ----------
@@ -484,7 +484,6 @@ class ExportMod3D():
 
     def __init__(self, parent=None):
         self.ifile = ''
-        self.pbar = None
         self.parent = parent
         self.indata = {}
         self.outdata = {}
@@ -623,7 +622,7 @@ class ExportMod3D():
 
     def mod3dtocsv(self):
         """
-        Saves the 3D model in a csv file.
+        Save the 3D model in a csv file.
 
         Returns
         -------
@@ -674,7 +673,7 @@ class ExportMod3D():
 
     def mod3dtokmz(self):
         """
-        Saves the 3D model and grids in a kmz file.
+        Save the 3D model and grids in a kmz file.
 
         Only the boundary of the area is in degrees. The actual coordinates
         are still in meters.
@@ -1030,7 +1029,7 @@ class ExportMod3D():
 
     def mod3dtoshp(self):
         """
-        Saves the 3D model and grids in a shapefile file.
+        Save the 3D model and grids in a shapefile file.
 
         Only the boundary of the area is in degrees. The actual coordinates
         are still in meters.
@@ -1169,7 +1168,6 @@ class Exportkmz(QtWidgets.QDialog):
         None.
 
         """
-
         gridlayout = QtWidgets.QGridLayout(self)
         buttonbox = QtWidgets.QDialogButtonBox()
         helpdocs = menu_default.HelpButton('pygmi.pfmod.iodefs.exportkmz')
