@@ -26,6 +26,7 @@
 
 from PyQt5 import QtWidgets, QtCore, QtGui
 import numpy as np
+
 from pygmi.pfmod import grvmag3d
 from pygmi.pfmod import misc
 import pygmi.menu_default as menu_default
@@ -780,7 +781,7 @@ class ParamDisplay(QtWidgets.QDialog):
 
     def merge_defs(self):
         """
-        Merge geophysical definitions
+        Merge geophysical definitions.
 
         Returns
         -------
@@ -814,7 +815,7 @@ class ParamDisplay(QtWidgets.QDialog):
 
     def rename_defs(self):
         """
-        Rename a definition
+        Rename a definition.
 
         Returns
         -------
