@@ -39,6 +39,7 @@ from osgeo import gdal
 from osgeo import osr
 import pandas as pd
 import pygmi.raster.iodefs as ir
+
 from pygmi.pfmod import grvmag3d
 from pygmi.pfmod import misc
 import pygmi.menu_default as menu_default
@@ -252,7 +253,6 @@ class ProfileDisplay(QtWidgets.QWidget):
         pb_cprof_add.clicked.connect(self.cprof_add)
         pb_cprof_delete.clicked.connect(self.cprof_del)
 
-    ### Custom Profiles
     def cprof_add(self):
         """
         Add new custom profile.
@@ -467,7 +467,6 @@ class ProfileDisplay(QtWidgets.QWidget):
 
         self.update_plot(slide=True)
 
-    ### Misc
     def borehole_import(self):
         """
         Import borehole data.
@@ -889,7 +888,6 @@ class ProfileDisplay(QtWidgets.QWidget):
         # Reset the profile back to the current profile
         self.calc_prof_limits()
 
-    ### Profiles
     def change_defs(self):
         """
         Change definitions.
@@ -1092,7 +1090,6 @@ class ProfileDisplay(QtWidgets.QWidget):
 
         self.update_plot(slide=True)
 
-    ### Layers
     def hlayer(self):
         """
         Horizontal slider to change the layer.
@@ -1146,7 +1143,6 @@ class ProfileDisplay(QtWidgets.QWidget):
         self.mmc.update_line()
         self.mmc.figure.canvas.draw()
 
-    ### Profile Direction
     def calc_prof_limits(self, curprof=None):
         """
         Calculate profile limits.
@@ -1528,7 +1524,7 @@ class ProfileDisplay(QtWidgets.QWidget):
 
 
 class MyMplCanvas(FigureCanvasQTAgg):
-    """Matplotlib Canvas"""
+    """Matplotlib Canvas."""
 
     def __init__(self, parent=None):
         fig = Figure()
@@ -1753,8 +1749,9 @@ class MyMplCanvas(FigureCanvasQTAgg):
 
     def set_mdata(self, xdata, ydata, mdata):
         """
-        Routine to 'draw' the line on mdata. xdata and ydata are the cursor
-        centre coordinates.
+        Routine to 'draw' the line on mdata.
+
+        xdata and ydata are the cursor centre coordinates.
 
         Parameters
         ----------
@@ -1894,7 +1891,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
         Parameters
         ----------
         dat2 : str, optional
-            Comobox text. The default is None.
+            Combobox text. The default is None.
         opac : float, optional
             Opacity between 0 and 100. The default is 100.0.
 
@@ -2038,7 +2035,6 @@ class MyMplCanvas(FigureCanvasQTAgg):
 
         self.axes.draw_artist(self.prfc[0])
 
-
     def update_line_top(self):
         """
         Update the top line position.
@@ -2196,7 +2192,7 @@ class MySlider(QtWidgets.QSlider):
 
 
 class LithBound(QtWidgets.QDialog):
-    """ Class to call up a dialog for lithological boundary."""
+    """Class to call up a dialog for lithological boundary."""
 
     def __init__(self, lmod):
         super().__init__(None)
@@ -2285,7 +2281,7 @@ class LithBound(QtWidgets.QDialog):
 
 
 class PlotScale(QtWidgets.QDialog):
-    """ Class to call up a dialog for plot axis scale."""
+    """Class to call up a dialog for plot axis scale."""
 
     def __init__(self, parent, lmod):
         super().__init__(parent)
@@ -2580,7 +2576,6 @@ class ImportPicture(QtWidgets.QDialog):
         self.lmod = self.parent.lmod1
 
         self.ifile = ''
-        self.pbar = None
         self.indata = {}
         self.outdata = {}
         self.grid = None
@@ -2728,7 +2723,10 @@ class ImportPicture(QtWidgets.QDialog):
 
     def settings(self, nodialog=False):
         """
-        Settings.
+        Entrypoint into class.
+
+        This is called when the used double clicks the routine from the
+        main PyGMI interface.
 
         This section also imports the picture.
 
@@ -2840,7 +2838,7 @@ class ImportPicture(QtWidgets.QDialog):
 
     def loadproj(self, projdata):
         """
-        Loads project data into class.
+        Load project data into class.
 
         Parameters
         ----------
@@ -2853,14 +2851,12 @@ class ImportPicture(QtWidgets.QDialog):
             A check to see if settings was successfully run.
 
         """
-
         return False
 
     def saveproj(self):
         """
         Save project data from class.
 
-
         Returns
         -------
         projdata : dictionary
@@ -2948,8 +2944,8 @@ def rotate2d(pts, cntr, ang=np.pi/4):
     return pts2
 
 
-def testfn():
-    """Main testing routine."""
+def _testfn():
+    """Test routine."""
     aaa = np.arange(12.).reshape((4, 3))
     print(aaa)
 
@@ -2959,4 +2955,4 @@ def testfn():
 
 
 if __name__ == "__main__":
-    testfn()
+    _testfn()
