@@ -35,6 +35,7 @@ import pandas as pd
 from PIL import Image, ImageDraw
 import scipy.ndimage as ndimage
 from scipy.signal import tukey
+
 import pygmi.menu_default as menu_default
 from pygmi.raster.datatypes import Data
 
@@ -101,14 +102,9 @@ class DataCut():
                 return False
 
         os.chdir(os.path.dirname(self.ifile))
-        data = cut_raster(data, self.ifile)
+        data = cut_raster(data, self.ifile, pprint=self.showprocesslog)
 
         if data is None:
-            err = ('There was a problem importing the shapefile. Please make '
-                   'sure you have at all the individual files which make up '
-                   'the shapefile.')
-            QtWidgets.QMessageBox.warning(self.parent, 'Error', err,
-                                          QtWidgets.QMessageBox.Ok)
             return False
 
         self.pbar.to_max()
@@ -328,7 +324,8 @@ class DataMerge(QtWidgets.QDialog):
         """
         dxy = self.dsb_dxy.value()
         self.dxy = dxy
-        dat = merge(self.indata['Raster'], self.piter, dxy)
+        dat = merge(self.indata['Raster'], self.piter, dxy,
+                    pprint=self.showprocesslog)
         self.outdata['Raster'] = dat
 
 
@@ -352,13 +349,14 @@ class DataReproj(QtWidgets.QDialog):
         super().__init__(parent)
         if parent is None:
             self.showprocesslog = print
+            self.piter = iter
         else:
             self.showprocesslog = parent.showprocesslog
+            self.piter = parent.pbar.iter
 
         self.indata = {}
         self.outdata = {}
         self.parent = parent
-        self.pbar = self.parent.pbar
         self.orig_wkt = None
         self.targ_wkt = None
 
@@ -412,7 +410,11 @@ class DataReproj(QtWidgets.QDialog):
 
         """
         if self.in_proj.wkt == 'Unknown' or self.out_proj.wkt == 'Unknown':
-            self.showprocesslog('Could not reproject')
+            self.showprocesslog('Unknown Projection. Could not reproject')
+            return
+
+        if self.in_proj.wkt == '' or self.out_proj.wkt == '':
+            self.showprocesslog('Unknown Projection. Could not reproject')
             return
 
 # Input stuff
@@ -434,7 +436,7 @@ class DataReproj(QtWidgets.QDialog):
 
 # Now create virtual dataset
         dat = []
-        for data in self.pbar.iter(self.indata['Raster']):
+        for data in self.piter(self.indata['Raster']):
             datamin = data.data.min()
             if datamin <= 0:
                 data.data = data.data-(datamin-1)
@@ -590,14 +592,15 @@ class GetProf():
 
     def __init__(self, parent=None):
         self.ifile = ''
-        self.pbar = parent.pbar
         self.parent = parent
         self.indata = {}
         self.outdata = {}
         if parent is None:
             self.showprocesslog = print
+            self.piter = iter
         else:
             self.showprocesslog = parent.showprocesslog
+            self.piter = parent.pbar.iter
 
     def settings(self, nodialog=False):
         """
@@ -641,10 +644,10 @@ class GetProf():
             self.showprocesslog('You need lines in that shape file')
             return False
 
-        data = merge(data)
+        data = merge(data, self.piter, pprint=self.showprocesslog)
         gdf = None
 
-        for idata in self.pbar.iter(data):
+        for idata in self.piter(data):
             tmp = line.GetGeometryRef()
             points = tmp.GetPoints()
 
@@ -760,7 +763,7 @@ class GroupProj(QtWidgets.QWidget):
         Parameters
         ----------
         wkt : str
-            Well Known Text descriptions for coordfinates (WKT) .
+            Well Known Text descriptions for coordinates (WKT) .
 
         Returns
         -------
@@ -946,10 +949,10 @@ class Metadata(QtWidgets.QDialog):
                     tmp.nullvalue = i.nullvalue
                     tmp.wkt = wkt
                     tmp.units = i.units
-                    if tmp.dataid[-1] == ')':
-                        tmp.dataid = tmp.dataid[:tmp.dataid.rfind(' (')]
-                    if i.units != '':
-                        tmp.dataid += ' ('+i.units+')'
+                    # if tmp.dataid[-1] == ')':
+                    #     tmp.dataid = tmp.dataid[:tmp.dataid.rfind(' (')]
+                    # if i.units != '':
+                    #     tmp.dataid += ' ('+i.units+')'
                     tmp.data.mask = (tmp.data.data == i.nullvalue)
 
     def rename_id(self):
@@ -1029,7 +1032,7 @@ class Metadata(QtWidgets.QDialog):
 
     def run(self):
         """
-        Entrypoint to start this routine.
+        Entry point to start this routine.
 
         Returns
         -------
@@ -1108,7 +1111,10 @@ class RTP(QtWidgets.QDialog):
         self.indata = {}
         self.outdata = {}
         self.parent = parent
-        self.pbar = self.parent.pbar
+        if parent is None:
+            self.piter = iter
+        else:
+            self.piter = parent.pbar.iter
 
         self.dataid = QtWidgets.QComboBox()
         self.dsb_inc = QtWidgets.QDoubleSpinBox()
@@ -1242,7 +1248,7 @@ class RTP(QtWidgets.QDialog):
         D_deg = self.dsb_dec.value()
 
         newdat = []
-        for data in self.pbar.iter(self.indata['Raster']):
+        for data in self.piter(self.indata['Raster']):
             if data.dataid != self.dataid.currentText():
                 continue
             dat = rtp(data, I_deg, D_deg)
@@ -1271,7 +1277,6 @@ class Continuation(QtWidgets.QDialog):
         self.indata = {}
         self.outdata = {}
         self.parent = parent
-        self.pbar = self.parent.pbar
 
         self.dataid = QtWidgets.QComboBox()
         self.continuation = QtWidgets.QComboBox()
@@ -1661,7 +1666,7 @@ def taylorcont(data, h):
 
 def rtp(data, I_deg, D_deg):
     """
-    Reduction to th epole.
+    Reduction to the pole.
 
     Parameters
     ----------
@@ -1772,7 +1777,7 @@ def cluster_to_raster(indata):
     return indata
 
 
-def cut_raster(data, ifile):
+def cut_raster(data, ifile, pprint=print):
     """Cuts a raster dataset.
 
     Cut a raster dataset using a shapefile.
@@ -1791,6 +1796,9 @@ def cut_raster(data, ifile):
     """
     shapef = ogr.Open(ifile)
     if shapef is None:
+        pprint('There was a problem importing the shapefile. Please make '
+               'sure you have at all the individual files which make up '
+               'the shapefile.')
         return None
     lyr = shapef.GetLayer()
     poly = lyr.GetNextFeature()
@@ -1801,6 +1809,17 @@ def cut_raster(data, ifile):
 
     for idata in data:
         # Convert the layer extent to image pixel coordinates
+        dext = idata.extent
+        lext = lyr.GetExtent()
+
+        if ((dext[0] > lext[1]) or (dext[1] < lext[0]) or
+                (dext[2] > lext[3]) or (dext[3] < lext[2])):
+
+            pprint('The shapefile is not in the same area as the raster '
+                   'dataset. Please check its coordinates and make sure its '
+                   'projection is the same as the raster dataset')
+            return None
+
         minX, maxX, minY, maxY = lyr.GetExtent()
         itlx = idata.extent[0]
         itly = idata.extent[-1]
@@ -2055,58 +2074,7 @@ def getepsgcodes():
     return pcodes
 
 
-# def merge(dat, piter=None):
-#     """
-#     Merge datasets found in a single PyGMI data object.
-
-#     The aim is to ensure that all datasets have the same number of rows and
-#     columns.
-
-#     Parameters
-#     ----------
-#     dat : PyGMI Data
-#         data object which stores datasets
-
-#     Returns
-#     -------
-#     out : PyGMI Data
-#         data object which stores datasets
-#     """
-#     if piter is None:
-#         piter = iter
-
-#     if dat[0].isrgb:
-#         return dat
-
-#     needsmerge = False
-#     rows, cols = dat[0].data.shape
-#     for i in dat:
-#         irows, icols = i.data.shape
-#         if irows != rows or icols != cols:
-#             needsmerge = True
-
-#     if needsmerge is False:
-#         dat = check_dataid(dat)
-#         return dat
-
-#     self.showprocesslog('Merging data...')
-#     mrg = DataMerge()
-#     mrg.indata['Raster'] = dat
-#     data = dat[0]
-#     dxy0 = min(data.xdim, data.ydim)
-#     for data in dat:
-#         dxy = min(dxy0, data.xdim, data.ydim)
-
-#     mrg.dsb_dxy.setValue(dxy)
-#     mrg.acceptall()
-#     out = mrg.outdata['Raster']
-
-#     out = check_dataid(out)
-
-#     return out
-
-
-def merge(dat, piter=None, dxy=None):
+def merge(dat, piter=iter, dxy=None, pprint=print):
     """
     Merge datasets found in a single PyGMI data object.
 
@@ -2123,10 +2091,6 @@ def merge(dat, piter=None, dxy=None):
     out : PyGMI Data
         data object which stores datasets
     """
-
-    if piter is None:
-        piter = iter
-
     if dat[0].isrgb:
         return dat
 
@@ -2144,7 +2108,7 @@ def merge(dat, piter=None, dxy=None):
         dat = check_dataid(dat)
         return dat
 
-    # self.showprocesslog('Merging data...')
+    pprint('Merging data...')
 
     data = dat[0]
     dxy0 = min(data.xdim, data.ydim)
@@ -2164,10 +2128,11 @@ def merge(dat, piter=None, dxy=None):
 
     cols = int((xmax - xmin)/dxy)
     rows = int((ymax - ymin)/dxy)
-    gtr = (xmin, dxy, 0.0, ymax, 0.0, -dxy)
+    gtr = (xmin, dxy, 0.0, ymax, 0.0, -1.0*dxy)
 
     if cols == 0 or rows == 0:
-        print('Your rows or cols are zero. Your input projection may be wrong')
+        pprint('Your rows or cols are zero. '
+               'Your input projection may be wrong')
         return None
 
     dat2 = []
@@ -2188,6 +2153,7 @@ def merge(dat, piter=None, dxy=None):
                             gdal.GRA_Bilinear)
 
         dat2.append(gdal_to_dat(dest, data.dataid))
+        dat2[-1].metadata = data.metadata
         dat2[-1].data = dat2[-1].data + doffset
         data.data = data.data + doffset
 
@@ -2254,8 +2220,8 @@ def trim_raster(olddata):
     return olddata
 
 
-def testrtp():
-    """Main RTP testing routine."""
+def _testrtp():
+    """RTP testing routine."""
     import matplotlib.pyplot as plt
     from matplotlib import cm
     from pygmi.pfmod.grvmag3d import quick_model, calc_field
@@ -2283,8 +2249,8 @@ def testrtp():
     plt.show()
 
 
-def testdown():
-    """Main continuation testing routine."""
+def _testdown():
+    """Continuation testing routine."""
     import matplotlib.pyplot as plt
     from pygmi.pfmod.grvmag3d import quick_model, calc_field
     from IPython import get_ipython
@@ -2346,9 +2312,9 @@ def testdown():
     plt.show()
 
 
-def testgrid():
+def _testgrid():
     """
-    Test.
+    Test routine.
 
     Returns
     -------
@@ -2419,5 +2385,104 @@ def testgrid():
     ttt.since_last_call('Griddata, nearest')
 
 
+def _testfft():
+    """Test FFT."""
+    import matplotlib.pyplot as plt
+    from matplotlib import cm
+    import scipy
+    from pygmi.pfmod.grvmag3d import quick_model, calc_field
+    from IPython import get_ipython
+    from pygmi.raster.iodefs import get_raster, export_gdal
+
+    get_ipython().run_line_magic('matplotlib', 'inline')
+
+    # ifile = r'D:\Workdata\geothermal\bushveld.hdr'
+    # dat = get_raster(ifile)[0]
+
+    # finc = -63.4
+    # fdec = -16.25
+    # # quick model
+    # plt.imshow(dat.data, cmap=cm.get_cmap('jet'), vmin=-1000, vmax=1000)
+    # plt.colorbar()
+    # plt.show()
+
+    # dat2 = rtp(dat, finc, fdec)
+    # dat2.data -= np.ma.median(dat2.data)
+
+    # plt.imshow(dat2.data, cmap=cm.get_cmap('jet'), vmin=-500, vmax=500)
+    # plt.colorbar()
+    # plt.show()
+
+    # ofile = r'D:\Workdata\geothermal\bushveldrtp.hdr'
+    # export_gdal(ofile, [dat2], 'ENVI')
+
+    ifile = r'D:\Workdata\geothermal\bushveldrtp.hdr'
+    data = get_raster(ifile)[0]
+
+    # quick model
+    plt.imshow(data.data, cmap=cm.get_cmap('jet'), vmin=-500, vmax=500)
+    plt.colorbar()
+    plt.show()
+
+    # Start new stuff
+    xdim = data.xdim
+    ydim = data.ydim
+
+    ndat, rdiff, cdiff, datamedian = fftprep(data)
+
+    datamedian = np.ma.median(data.data)
+    ndat = data.data - datamedian
+
+    fftmod = np.fft.fft2(ndat)
+    # fftmod = np.fft.fftshift(fftmod)
+
+    # ny, nx = fftmod.shape
+    KX, KY = fft_getkxy(fftmod, xdim, ydim)
+
+    vmin = fftmod.real.mean()-2*fftmod.real.std()
+    vmax = fftmod.real.mean()+2*fftmod.real.std()
+    plt.imshow(np.fft.fftshift(fftmod.real), vmin=vmin, vmax=vmax)
+    plt.show()
+
+    knrm = np.sqrt(KX**2+KY**2)
+
+    plt.imshow(knrm)
+
+    plt.show()
+
+    knrm = knrm.flatten()
+    fftamp = np.abs(fftmod)**2
+    fftamp = fftamp.flatten()
+
+    plt.plot(knrm, fftamp, '.')
+    plt.yscale('log')
+    plt.show()
+
+    bins = max(fftmod.shape)//2
+
+    abins, bedge, _ = scipy.stats.binned_statistic(knrm, fftamp,
+                                                   statistic='mean',
+                                                   bins=bins)
+
+    bins = (bedge[:-1] + bedge[1:])/2
+    plt.plot(bins, abins)
+    plt.yscale('log')
+    plt.show()
+
+    breakpoint()
+
+    # I = np.deg2rad(I_deg)
+    # D = np.deg2rad(D_deg)
+    # alpha = np.arctan2(KY, KX)
+
+    # filt = 1/(np.sin(I)+1j*np.cos(I)*np.sin(D+alpha))**2
+
+    # zout = np.real(np.fft.ifft2(fftmod*filt))
+    # zout = zout[rdiff:-rdiff, cdiff:-cdiff]
+    # zout = zout + datamedian
+
+    # zout[data.data.mask] = data.data.fill_value
+
+
 if __name__ == "__main__":
-    testdown()
+    _testfft()
