@@ -22,28 +22,6 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 # -----------------------------------------------------------------------------
-# Licence for original ModestImage code (modified version below)
-# ModestImage
-# Copyright (c) 2013 Chris Beaumont
-#
-# Permission is hereby granted, free of charge, to any person obtaining a
-# copy of this software and associated documentation files (the "Software"),
-# to deal in the Software without restriction, including without limitation
-# the rights to use, copy, modify, merge, publish, distribute, sublicense,
-# and/or sell copies of the Software, and to permit persons to whom the
-# Software is furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
-# DEALINGS IN THE SOFTWARE.
-# -----------------------------------------------------------------------------
 """
 Plot Raster Data.
 
@@ -80,9 +58,11 @@ from matplotlib.backends.backend_qt5 import NavigationToolbar2QT
 from matplotlib.path import Path
 from matplotlib.patches import PathPatch
 from matplotlib.pyplot import colormaps
+
 import pygmi.raster.iodefs as iodefs
 import pygmi.raster.dataprep as dataprep
 import pygmi.menu_default as menu_default
+from pygmi.raster.modest_image import imshow
 
 
 class MyMplCanvas(FigureCanvasQTAgg):
@@ -102,7 +82,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
     sdata : list
         list of PyGMI raster data objects - used for shaded images
     gmode : str
-        string contaning the graphics mode - Contour, Ternary, Sunshade,
+        string containing the graphics mode - Contour, Ternary, Sunshade,
         Single Color Map.
     argb : list
         list of matplotlib subplots. There are up to three.
@@ -113,7 +93,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
     htxt : list
         list of strings associated with hhist, denoting a raster value (where
         mouse is currently hovering over on image)
-    image : Modestimage imshow
+    image : imshow
         imshow instance - this is the primary way of displaying an image.
     cnt : matplotlib contour
         contour instance - used for the contour image
@@ -127,7 +107,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
         green histogram bounding box
     bbox_hist_blue :  matplotlib bounding box
         blue histogram bounding box
-    axes : matpolotlib axes
+    axes : matplotlib axes
         axes for the plot
     pinit : numpy array
         calculated with aspect - used in sunshading
@@ -261,8 +241,11 @@ class MyMplCanvas(FigureCanvasQTAgg):
 
         self.background = self.figure.canvas.copy_from_bbox(self.axes.bbox)
 
-        self.image = self.axes.imshow(self.data[0].data, origin='upper',
-                                      extent=(x_1, x_2, y_1, y_2))
+        # self.image = self.axes.imshow(self.data[0].data, origin='upper',
+        #                               extent=(x_1, x_2, y_1, y_2))
+
+        self.image = imshow(self.axes, self.data[0].data, origin='upper',
+                            extent=(x_1, x_2, y_1, y_2))
 
         # This line prevents imshow from generating color values on the
         # toolbar
@@ -271,6 +254,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
 
         self.cid = self.figure.canvas.mpl_connect('resize_event',
                                                   self.revent)
+        self.figure.canvas.draw()
 
     def move(self, event):
         """
@@ -417,8 +401,9 @@ class MyMplCanvas(FigureCanvasQTAgg):
             for j in patches:
                 j.set_color(hcol[i])
 
-            if np.ma.is_masked(zval[i]) is True:
+            if np.ma.is_masked(zval[i]) is True or zval[i] is None:
                 bnum.append(0)
+                self.update_hist_text(self.htxt[i], None)
                 continue
 
             binnum = (bins < zval[i]).sum()-1
@@ -431,7 +416,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
             self.update_hist_text(self.htxt[i], zval[i])
         return bnum
 
-    def update_hist_single(self, zval, hno=0):
+    def update_hist_single(self, zval=None, hno=0):
         """
         Update the color on a single histogram.
 
@@ -461,11 +446,13 @@ class MyMplCanvas(FigureCanvasQTAgg):
             patches[j].set_color(bincol[j])
 
         # This section draws the black line.
-        if np.ma.is_masked(zval) is True:
+        if zval is None or np.ma.is_masked(zval) is True:
+            self.update_hist_text(self.htxt[hno], None)
             return 0
-        binnum = (bins < zval).sum()-1
 
+        binnum = (bins < zval).sum()-1
         if binnum < 0 or binnum >= len(patches):
+            self.update_hist_text(self.htxt[hno], zval)
             return 0
 
         patches[binnum].set_color('k')
@@ -474,7 +461,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
 
     def update_hist_text(self, hst, zval):
         """
-        Update the value on the histogram
+        Update the value on the histogram.
 
         Parameters
         ----------
@@ -492,7 +479,11 @@ class MyMplCanvas(FigureCanvasQTAgg):
         xnew = 0.95*(xmax-xmin)+xmin
         ynew = 0.95*(ymax-ymin)+ymin
         hst.set_position((xnew, ynew))
-        hst.set_text(f'{zval:.4f}')
+
+        if zval is None:
+            hst.set_text('')
+        else:
+            hst.set_text(f'{zval:.4f}')
 
     def update_rgb(self):
         """
@@ -552,7 +543,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
                                   self.hhist[i][1].max())
             self.argb[i].set_ylim(0, self.hhist[i][0].max()*1.2)
 
-        self.update_hist_rgb([-999, -999, -999])
+        self.update_hist_rgb([None, None, None])
 
         self.axes.draw_artist(self.image)
 
@@ -577,7 +568,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
 
     def update_single_color_map(self):
         """
-        Updates the single color map.
+        Update the single color map.
 
         Returns
         -------
@@ -611,7 +602,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
         self.argb[0].set_xlim(self.hhist[0][1].min(), self.hhist[0][1].max())
         self.argb[0].set_ylim(0, self.hhist[0][0].max()*1.2)
 
-        self.update_hist_single(0.0)
+        self.update_hist_single()
         self.axes.draw_artist(self.image)
 
         for i in self.hhist[0][2]:
@@ -633,7 +624,6 @@ class MyMplCanvas(FigureCanvasQTAgg):
         None.
 
         """
-
         if self.shade is not True:
             return 1
 
@@ -696,8 +686,9 @@ class MySunCanvas(FigureCanvasQTAgg):
 
 class PlotInterp(QtWidgets.QDialog):
     """
-    This is the primary class for the raster data interpretation module. The
-    main interface is set up from here, as well as monitoring of the mouse
+    The primary class for the raster data interpretation module.
+
+    The main interface is set up from here, as well as monitoring of the mouse
     over the sunshading.
 
     The PlotInterp class allows for the display of raster data in a variety of
@@ -1043,7 +1034,7 @@ class PlotInterp(QtWidgets.QDialog):
 
     def change_sunsliders(self):
         """
-        Changes the sun shading sliders.
+        Change the sun shading sliders.
 
         Returns
         -------
@@ -1108,7 +1099,7 @@ class PlotInterp(QtWidgets.QDialog):
 
     def data_init(self):
         """
-        Data initialise.
+        Initialise Data.
 
         Entry point into routine. This entry point exists for
         the case  where data must be initialised before entering at the
@@ -1202,7 +1193,6 @@ class PlotInterp(QtWidgets.QDialog):
             True if successful, False otherwise.
 
         """
-
         snorm = self.mmc.update_shade_plot()
 
         ext = 'GeoTiff (*.tif)'
@@ -1383,8 +1373,6 @@ class PlotInterp(QtWidgets.QDialog):
 
             mask = img[:, :, 3]
 
-        # export = iodefs.ExportData(self.parent)
-
         os.chdir(os.path.dirname(filename))
 
         newimg = [copy.deepcopy(self.mmc.data[0]),
@@ -1522,7 +1510,7 @@ class PlotInterp(QtWidgets.QDialog):
 
     def settings(self, nodialog=False):
         """
-        Settings.
+        Entrypoint into class.
 
         This is called when the used double clicks the routine from the
         main PyGMI interface.
@@ -1554,7 +1542,7 @@ class PlotInterp(QtWidgets.QDialog):
 
     def loadproj(self, projdata):
         """
-        Loads project data into class.
+        Load project data into class.
 
         Parameters
         ----------
@@ -1567,14 +1555,12 @@ class PlotInterp(QtWidgets.QDialog):
             A check to see if settings was successfully run.
 
         """
-
         return False
 
     def saveproj(self):
         """
         Save project data from class.
 
-
         Returns
         -------
         projdata : dictionary
@@ -1645,7 +1631,7 @@ def currentshader(data, cell, theta, phi, alpha):
     Returns
     -------
     R : numpy array
-        array containg the shaded results.
+        array containing the shaded results.
 
     """
     asp = aspect2(data)
@@ -1673,7 +1659,7 @@ def currentshader(data, cell, theta, phi, alpha):
 
 def histcomp(img, nbr_bins=None, perc=5.):
     """
-    Histogram Compaction
+    Histogram Compaction.
 
     This compacts a % of the outliers in data, allowing for a cleaner, linear
     representation of the data.
@@ -1690,7 +1676,6 @@ def histcomp(img, nbr_bins=None, perc=5.):
     img2 : numpy array
         compacted array
     """
-
     if nbr_bins is None:
         nbr_bins = max(img.shape)
         nbr_bins = max(nbr_bins, 256)
@@ -1838,8 +1823,8 @@ def norm255(dat):
     return out
 
 
-def test():
-    """Test."""
+def _testfn():
+    """Test routine."""
     import matplotlib
 
     matplotlib.interactive(False)
@@ -1848,7 +1833,9 @@ def test():
                                                  '..//..')))
     app = QtWidgets.QApplication(sys.argv)
 
-    data = iodefs.get_raster(r'C:\work\WorkData\testdata.hdr')
+    data = iodefs.get_raster(r'E:\Workdata\raster\polygon cut get profile\mag_IGRFcorrected.ers')
+
+    # data = iodefs.get_raster(r'e:\WorkData\testdata.hdr')
 
     tmp = PlotInterp(None)
     tmp.indata['Raster'] = data
@@ -1857,5 +1844,4 @@ def test():
 
 
 if __name__ == "__main__":
-
-    test()
+    _testfn()
