@@ -41,7 +41,7 @@ from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg
 from matplotlib.figure import Figure
 from matplotlib.backends.backend_qt5 import NavigationToolbar2QT
 import matplotlib.colors as mcolors
-# from pygmi.raster.ginterp import imshow
+
 from pygmi.misc import frm
 from pygmi.raster.modest_image import imshow
 
@@ -62,7 +62,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
         self.axes = fig.add_subplot(111)
         super().__init__(fig)
 
-    def update_pcolor(self, data1, dmat):
+    def update_ccoef(self, data1, dmat):
         """
         Update the correlation coefficient plot.
 
@@ -100,7 +100,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
         self.figure.tight_layout()
         self.figure.canvas.draw()
 
-    def update_raster(self, data1):
+    def update_raster(self, data1, cmap):
         """
         Update the raster plot.
 
@@ -108,6 +108,8 @@ class MyMplCanvas(FigureCanvasQTAgg):
         ----------
         data1 : PyGMI raster Data
             raster dataset to be used in contouring
+        cmap : str
+            Matplotlib colormap description
 
         Returns
         -------
@@ -117,13 +119,18 @@ class MyMplCanvas(FigureCanvasQTAgg):
         self.figure.clear()
         self.axes = self.figure.add_subplot(111)
 
-        rdata = self.axes.imshow(data1.data, extent=data1.extent,
-                                 cmap=cm.get_cmap('jet'),
-                                 interpolation='nearest')
+        vstd = 2.5 * data1.data.std()
+        vmean = data1.data.mean()
+        vmin = vmean-vstd
+        vmax = vmean+vstd
 
-        # rdata = imshow(self.axes, data1.data, extent=data1.extent,
-        #                cmap=cm.get_cmap('jet'),
-        #                interpolation='nearest')
+        rdata = imshow(self.axes, data1.data, extent=data1.extent,
+                       cmap=cm.get_cmap(cmap), vmin=vmin, vmax=vmax,
+                       interpolation='nearest')
+
+        # rdata = self.axes.imshow(data1.data, extent=data1.extent,
+        #                          cmap=cm.get_cmap(cmap), vmin=vmin, vmax=vmax,
+        #                          interpolation='nearest')
 
         if not data1.isrgb:
             cbar = self.figure.colorbar(rdata, format=frm)
@@ -170,7 +177,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
         ymin = y.min()
         ymax = y.max()
 
-        hbin = self.axes.hexbin(x, y, bins='log')
+        hbin = self.axes.hexbin(x, y, bins='log', cmap='inferno')
         self.axes.axis([xmin, xmax, ymin, ymax])
         self.axes.set_title('Hexbin Plot')
         cbar = self.figure.colorbar(hbin, format=frm)
@@ -182,14 +189,16 @@ class MyMplCanvas(FigureCanvasQTAgg):
         self.figure.tight_layout()
         self.figure.canvas.draw()
 
-    def update_wireframe(self, data):
+    def update_surface(self, data, cmap):
         """
-        Update the surface wireframe plot.
+        Update the surface plot.
 
         Parameters
         ----------
         data : PyGMI raster Data
             raster dataset to be used
+        cmap : str
+            Matplotlib colormap description
 
         Returns
         -------
@@ -211,7 +220,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
         x = np.ma.array(x, mask=z.mask)
         y = np.ma.array(y, mask=z.mask)
 
-        cmap = cm.get_cmap('jet')
+        cmap = cm.get_cmap(cmap)
 
         norml = mcolors.Normalize(vmin=z.min(), vmax=z.max())
 
@@ -221,7 +230,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
         self.figure.clear()
         self.axes = self.figure.add_subplot(111, projection='3d')
 
-        surf = self.axes.plot_surface(x, y, z, cmap=cmap, linewidth=0.1,
+        surf = self.axes.plot_surface(x, y, z, cmap=cmap,
                                       norm=norml, vmin=z.min(), vmax=z.max(),
                                       shade=False, antialiased=False)
 
@@ -236,9 +245,10 @@ class MyMplCanvas(FigureCanvasQTAgg):
         self.axes.set_ylabel('Y')
         self.axes.set_zlabel('Z')
 
+        self.figure.tight_layout()
         self.figure.canvas.draw()
 
-    def update_hist(self, data1):
+    def update_hist(self, data1, ylog):
         """
         Update the hiostogram plot.
 
@@ -246,6 +256,8 @@ class MyMplCanvas(FigureCanvasQTAgg):
         ----------
         data1 : PyGMI raster Data
             raster dataset to be used
+        ylog : bool
+            Boolean for a log scale on y-axis.
 
         Returns
         -------
@@ -256,7 +268,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
         self.axes = self.figure.add_subplot(111)
 
         dattmp = data1.data[data1.data.mask == 0].flatten()
-        self.axes.hist(dattmp, 50)
+        self.axes.hist(dattmp, bins='sqrt')
         self.axes.set_title(data1.dataid, fontsize=12)
         self.axes.set_xlabel('Data Value', fontsize=8)
         self.axes.set_ylabel('Counts', fontsize=8)
@@ -264,75 +276,19 @@ class MyMplCanvas(FigureCanvasQTAgg):
         self.axes.xaxis.set_major_formatter(frm)
         self.axes.yaxis.set_major_formatter(frm)
 
+        if ylog is True:
+            self.axes.set_yscale('log')
+
         self.figure.tight_layout()
         self.figure.canvas.draw()
 
 
-class GraphWindow(QtWidgets.QDialog):
+class PlotCCoef(QtWidgets.QDialog):
     """
-    Graph Window - The QDialog window which will contain our image.
+    Plot 2D Correlation Coefficients.
 
     Attributes
     ----------
-    parent : parent
-        reference to the parent routine
-    """
-
-    def __init__(self, parent=None):
-        super().__init__(parent)
-        self.parent = parent
-
-        self.setAttribute(QtCore.Qt.WA_DeleteOnClose)
-        self.setWindowTitle('Graph Window')
-
-        vbl = QtWidgets.QVBoxLayout(self)  # self is where layout is assigned
-        self.hbl = QtWidgets.QHBoxLayout()
-        self.mmc = MyMplCanvas(self)
-        mpl_toolbar = NavigationToolbar2QT(self.mmc, self.parent)
-
-        self.combobox1 = QtWidgets.QComboBox()
-        self.combobox2 = QtWidgets.QComboBox()
-        self.label1 = QtWidgets.QLabel('Bands:')
-        self.label2 = QtWidgets.QLabel('Bands:')
-        self.hbl.addWidget(self.label1)
-        self.hbl.addWidget(self.combobox1)
-        self.hbl.addWidget(self.label2)
-        self.hbl.addWidget(self.combobox2)
-
-        vbl.addWidget(self.mmc)
-        vbl.addWidget(mpl_toolbar)
-        vbl.addLayout(self.hbl)
-
-        self.setFocus()
-
-        self.combobox1.currentIndexChanged.connect(self.change_band)
-        self.combobox2.currentIndexChanged.connect(self.change_band)
-
-    def change_band(self):
-        """
-        Combo box to choose band.
-
-        Returns
-        -------
-        None.
-
-        """
-
-
-class PlotCCoef(GraphWindow):
-    """
-    Plot 2D Correlation Coeffiecients.
-
-    Attributes
-    ----------
-    label1 : QLabel
-        reference to GraphWindow's label1
-    combobox1 : QComboBox
-        reference to GraphWindow's combobox1
-    label2 : QLabel
-        reference to GraphWindow's label2
-    combobox2 : QComboBox
-        reference to GraphWindow's combobox2
     parent : parent
         reference to the parent routine
     indata : dictionary
@@ -341,22 +297,20 @@ class PlotCCoef(GraphWindow):
 
     def __init__(self, parent=None):
         super().__init__(parent)
-        self.label1.hide()
-        self.combobox1.hide()
-        self.label2.hide()
-        self.combobox2.hide()
         self.indata = {}
         self.parent = parent
 
-    def change_band(self):
-        """
-        Combo box to choose band.
+        self.setAttribute(QtCore.Qt.WA_DeleteOnClose)
+        self.setWindowTitle('Graph Window')
 
-        Returns
-        -------
-        None.
+        vbl = QtWidgets.QVBoxLayout(self)  # self is where layout is assigned
+        self.mmc = MyMplCanvas(self)
+        mpl_toolbar = NavigationToolbar2QT(self.mmc, self.parent)
 
-        """
+        vbl.addWidget(self.mmc)
+        vbl.addWidget(mpl_toolbar)
+
+        self.setFocus()
 
     def run(self):
         """
@@ -382,7 +336,323 @@ class PlotCCoef(GraphWindow):
         dummy_mat = [[corr2d(i.data, j.data) for j in data] for i in data]
         dummy_mat = np.array(dummy_mat)
 
-        self.mmc.update_pcolor(data, dummy_mat)
+        self.mmc.update_ccoef(data, dummy_mat)
+
+
+class PlotRaster(QtWidgets.QDialog):
+    """
+    Plot Raster Class.
+
+    Attributes
+    ----------
+    parent : parent
+        reference to the parent routine
+    indata : dictionary
+        dictionary of input datasets
+    """
+
+    def __init__(self, parent=None):
+        super().__init__(parent)
+        self.indata = {}
+        self.parent = parent
+
+        self.setAttribute(QtCore.Qt.WA_DeleteOnClose)
+        self.setWindowTitle('Graph Window')
+
+        vbl = QtWidgets.QVBoxLayout(self)  # self is where layout is assigned
+        hbl = QtWidgets.QHBoxLayout()
+        self.mmc = MyMplCanvas(self)
+        mpl_toolbar = NavigationToolbar2QT(self.mmc, self.parent)
+
+        self.combobox1 = QtWidgets.QComboBox()
+        label1 = QtWidgets.QLabel('Bands:')
+        hbl.addWidget(label1)
+        hbl.addWidget(self.combobox1)
+
+        self.combobox2 = QtWidgets.QComboBox()
+        label2 = QtWidgets.QLabel('Colormap:')
+        hbl.addWidget(label2)
+        hbl.addWidget(self.combobox2)
+        self.combobox2.addItems(['viridis', 'jet', 'gray', 'terrain'])
+
+        vbl.addWidget(self.mmc)
+        vbl.addWidget(mpl_toolbar)
+        vbl.addLayout(hbl)
+
+        self.setFocus()
+        self.combobox1.currentIndexChanged.connect(self.change_band)
+        self.combobox2.currentIndexChanged.connect(self.change_band)
+
+    def change_band(self):
+        """
+        Combo box to choose band.
+
+        Returns
+        -------
+        None.
+
+        """
+        i = self.combobox1.currentIndex()
+        cmap = self.combobox2.currentText()
+        if 'Raster' in self.indata:
+            data = self.indata['Raster']
+            self.mmc.update_raster(data[i], cmap)
+
+    def run(self):
+        """
+        Run.
+
+        Returns
+        -------
+        None.
+
+        """
+        self.show()
+        if 'Raster' in self.indata:
+            data = self.indata['Raster']
+        elif 'Cluster' in self.indata:
+            data = self.indata['Cluster']
+
+        for i in data:
+            self.combobox1.addItem(i.dataid)
+
+
+class PlotSurface(QtWidgets.QDialog):
+    """
+    Plot Surface Class.
+
+    Attributes
+    ----------
+    parent : parent
+        reference to the parent routine
+    indata : dictionary
+        dictionary of input datasets
+    """
+
+    def __init__(self, parent=None):
+        super().__init__(parent)
+        self.indata = {}
+        self.parent = parent
+
+        self.setAttribute(QtCore.Qt.WA_DeleteOnClose)
+        self.setWindowTitle('Graph Window')
+
+        vbl = QtWidgets.QVBoxLayout(self)  # self is where layout is assigned
+        hbl = QtWidgets.QHBoxLayout()
+        self.mmc = MyMplCanvas(self)
+        mpl_toolbar = NavigationToolbar2QT(self.mmc, self.parent)
+
+        self.combobox1 = QtWidgets.QComboBox()
+        label1 = QtWidgets.QLabel('Bands:')
+        hbl.addWidget(label1)
+        hbl.addWidget(self.combobox1)
+
+        self.combobox2 = QtWidgets.QComboBox()
+        label2 = QtWidgets.QLabel('Colormap:')
+        hbl.addWidget(label2)
+        hbl.addWidget(self.combobox2)
+        self.combobox2.addItems(['viridis', 'jet', 'gray', 'terrain'])
+
+        vbl.addWidget(self.mmc)
+        vbl.addWidget(mpl_toolbar)
+        vbl.addLayout(hbl)
+
+        self.setFocus()
+
+        self.combobox1.currentIndexChanged.connect(self.change_band)
+        self.combobox2.currentIndexChanged.connect(self.change_band)
+
+    def change_band(self):
+        """
+        Combo box to choose band.
+
+        Returns
+        -------
+        None.
+
+        """
+        i = self.combobox1.currentIndex()
+        cmap = self.combobox2.currentText()
+        if 'Raster' in self.indata:
+            data = self.indata['Raster']
+            self.mmc.update_surface(data[i], cmap)
+
+    def run(self):
+        """
+        Run.
+
+        Returns
+        -------
+        None.
+
+        """
+        if 'Raster' in self.indata:
+            self.show()
+            data = self.indata['Raster']
+
+            for i in data:
+                self.combobox1.addItem(i.dataid)
+            self.change_band()
+
+
+class PlotScatter(QtWidgets.QDialog):
+    """
+    Plot Hexbin Class. A Hexbin is a type of scatter plot which is raster.
+
+    Attributes
+    ----------
+    parent : parent
+        reference to the parent routine
+    indata : dictionary
+        dictionary of input datasets
+    """
+
+    def __init__(self, parent=None):
+        super().__init__(parent)
+        self.indata = {}
+        self.parent = parent
+
+        self.setAttribute(QtCore.Qt.WA_DeleteOnClose)
+        self.setWindowTitle('Graph Window')
+
+        vbl = QtWidgets.QVBoxLayout(self)  # self is where layout is assigned
+        hbl = QtWidgets.QHBoxLayout()
+        self.mmc = MyMplCanvas(self)
+        mpl_toolbar = NavigationToolbar2QT(self.mmc, self.parent)
+
+        self.combobox1 = QtWidgets.QComboBox()
+        self.combobox2 = QtWidgets.QComboBox()
+        label1 = QtWidgets.QLabel('X Band:')
+        label2 = QtWidgets.QLabel('Y Band:')
+        hbl.addWidget(label1)
+        hbl.addWidget(self.combobox1)
+        hbl.addWidget(label2)
+        hbl.addWidget(self.combobox2)
+
+        vbl.addWidget(self.mmc)
+        vbl.addWidget(mpl_toolbar)
+        vbl.addLayout(hbl)
+
+        self.setFocus()
+
+        self.combobox1.currentIndexChanged.connect(self.change_band)
+        self.combobox2.currentIndexChanged.connect(self.change_band)
+
+    def change_band(self):
+        """
+        Combo box to choose band.
+
+        Returns
+        -------
+        None.
+
+        """
+        data = self.indata['Raster']
+        i = self.combobox1.currentIndex()
+        j = self.combobox2.currentIndex()
+
+        x = data[i].data
+        y = data[j].data
+        if x.mask.shape != y.mask.shape:
+            QtWidgets.QMessageBox.warning(self, 'Warning',
+                                          'Different size input datasets. '
+                                          'Merge and resample your input data '
+                                          'to fix this.',
+                                          QtWidgets.QMessageBox.Ok)
+            return
+
+        self.mmc.update_hexbin(x, y)
+
+    def run(self):
+        """
+        Run.
+
+        Returns
+        -------
+        None.
+
+        """
+        self.show()
+        data = self.indata['Raster']
+        for i in data:
+            self.combobox1.addItem(i.dataid)
+            self.combobox2.addItem(i.dataid)
+
+        self.combobox1.setCurrentIndex(0)
+        self.combobox2.setCurrentIndex(1)
+
+
+class PlotHist(QtWidgets.QDialog):
+    """
+    Plot Histogram Class.
+
+    Attributes
+    ----------
+    parent : parent
+        reference to the parent routine
+    indata : dictionary
+        dictionary of input datasets
+    """
+
+    def __init__(self, parent=None):
+        super().__init__(parent)
+        self.indata = {}
+        self.parent = parent
+
+        self.setAttribute(QtCore.Qt.WA_DeleteOnClose)
+        self.setWindowTitle('Graph Window')
+
+        vbl = QtWidgets.QVBoxLayout(self)  # self is where layout is assigned
+        hbl = QtWidgets.QHBoxLayout()
+        self.mmc = MyMplCanvas(self)
+        mpl_toolbar = NavigationToolbar2QT(self.mmc, self.parent)
+
+        self.combobox1 = QtWidgets.QComboBox()
+        label1 = QtWidgets.QLabel('Bands:')
+        self.chk_log = QtWidgets.QCheckBox('Log Y Axis:')
+        hbl.addWidget(self.chk_log)
+        hbl.addWidget(label1)
+        hbl.addWidget(self.combobox1)
+
+        vbl.addWidget(self.mmc)
+        vbl.addWidget(mpl_toolbar)
+        vbl.addLayout(hbl)
+
+        self.setFocus()
+
+        self.combobox1.currentIndexChanged.connect(self.change_band)
+        self.chk_log.stateChanged.connect(self.change_band)
+
+    def change_band(self):
+        """
+        Combo box to choose band.
+
+        Returns
+        -------
+        None.
+
+        """
+        data = self.indata['Raster']
+        i = self.combobox1.currentIndex()
+        ylog = self.chk_log.isChecked()
+        self.mmc.update_hist(data[i], ylog)
+
+    def run(self):
+        """
+        Run.
+
+        Returns
+        -------
+        None.
+
+        """
+        self.show()
+        data = self.indata['Raster']
+        for i in data:
+            self.combobox1.addItem(i.dataid)
+
+        self.combobox1.setCurrentIndex(0)
+        self.change_band()
 
 
 def check_bands(data):
@@ -442,234 +712,3 @@ def corr2d(dat1, dat2):
         out = numerator / denominator
 
     return out
-
-
-class PlotRaster(GraphWindow):
-    """
-    Plot Raster Class.
-
-    Attributes
-    ----------
-    label2 : QLabel
-        reference to GraphWindow's label2
-    combobox2 : QComboBox
-        reference to GraphWindow's combobox2
-    parent : parent
-        reference to the parent routine
-    indata : dictionary
-        dictionary of input datasets
-    """
-
-    def __init__(self, parent=None):
-        super().__init__(parent)
-        self.label2.hide()
-        self.combobox2.hide()
-        self.indata = {}
-        self.parent = parent
-
-    def change_band(self):
-        """
-        Combo box to choose band.
-
-        Returns
-        -------
-        None.
-
-        """
-        i = self.combobox1.currentIndex()
-        if 'Raster' in self.indata:
-            data = self.indata['Raster']
-            self.mmc.update_raster(data[i])
-
-    def run(self):
-        """
-        Run.
-
-        Returns
-        -------
-        None.
-
-        """
-        self.show()
-        if 'Raster' in self.indata:
-            data = self.indata['Raster']
-        elif 'Cluster' in self.indata:
-            data = self.indata['Cluster']
-
-        for i in data:
-            self.combobox1.addItem(i.dataid)
-#        self.change_band()
-
-
-class PlotSurface(GraphWindow):
-    """
-    Plot Raster Class.
-
-    Attributes
-    ----------
-    label2 : QLabel
-        reference to GraphWindow's label2
-    combobox2 : QComboBox
-        reference to GraphWindow's combobox2
-    parent : parent
-        reference to the parent routine
-    indata : dictionary
-        dictionary of input datasets
-    """
-
-    def __init__(self, parent=None):
-        super().__init__(parent)
-        self.label2.hide()
-        self.combobox2.hide()
-        self.indata = {}
-        self.parent = parent
-
-    def change_band(self):
-        """
-        Combo box to choose band.
-
-        Returns
-        -------
-        None.
-
-        """
-        i = self.combobox1.currentIndex()
-        if 'Raster' in self.indata:
-            data = self.indata['Raster']
-            self.mmc.update_wireframe(data[i])
-
-    def run(self):
-        """
-        Run.
-
-        Returns
-        -------
-        None.
-
-        """
-        if 'Raster' in self.indata:
-            self.show()
-            data = self.indata['Raster']
-
-            for i in data:
-                self.combobox1.addItem(i.dataid)
-            self.change_band()
-
-
-class PlotScatter(GraphWindow):
-    """
-    Plot Hexbin Class. A Hexbin is a type of scatter plot which is raster.
-
-    Attributes
-    ----------
-    parent : parent
-        reference to the parent routine
-    indata : dictionary
-        dictionary of input datasets
-    """
-
-    def __init__(self, parent=None):
-        super().__init__(parent)
-
-        self.indata = {}
-        self.parent = parent
-
-    def change_band(self):
-        """
-        Combo box to choose band.
-
-        Returns
-        -------
-        None.
-
-        """
-        data = self.indata['Raster']
-        i = self.combobox1.currentIndex()
-        j = self.combobox2.currentIndex()
-
-        x = data[i].data
-        y = data[j].data
-        if x.mask.shape != y.mask.shape:
-            QtWidgets.QMessageBox.warning(self, 'Warning',
-                                          'Different size input datasets. '
-                                          'Merge and resample your input data '
-                                          'to fix this.',
-                                          QtWidgets.QMessageBox.Ok)
-            return
-
-        self.mmc.update_hexbin(x, y)
-
-    def run(self):
-        """
-        Run.
-
-        Returns
-        -------
-        None.
-
-        """
-        self.show()
-        data = self.indata['Raster']
-        for i in data:
-            self.combobox1.addItem(i.dataid)
-            self.combobox2.addItem(i.dataid)
-
-        self.label1.setText('X Band:')
-        self.label2.setText('Y Band:')
-        self.combobox1.setCurrentIndex(0)
-        self.combobox2.setCurrentIndex(1)
-
-
-class PlotHist(GraphWindow):
-    """
-    Plot Hist Class.
-
-    Attributes
-    ----------
-    label2 : QLabel
-        reference to GraphWindow's label2
-    combobox2 : QComboBox
-        reference to GraphWindow's combobox2
-    parent : parent
-        reference to the parent routine
-    indata : dictionary
-        dictionary of input datasets
-    """
-
-    def __init__(self, parent=None):
-        super().__init__(parent)
-        self.label2.hide()
-        self.combobox2.hide()
-        self.indata = {}
-        self.parent = parent
-
-    def change_band(self):
-        """
-        Combo box to choose band.
-
-        Returns
-        -------
-        None.
-
-        """
-        data = self.indata['Raster']
-        i = self.combobox1.currentIndex()
-        self.mmc.update_hist(data[i])
-
-    def run(self):
-        """
-        Run.
-
-        Returns
-        -------
-        None.
-
-        """
-        self.show()
-        data = self.indata['Raster']
-        for i in data:
-            self.combobox1.addItem(i.dataid)
-
-        self.label1.setText('Band:')
-        self.combobox1.setCurrentIndex(0)
-        self.change_band()
