@@ -22,7 +22,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 # -----------------------------------------------------------------------------
-""" Import Data """
+"""Import raster data."""
 
 import warnings
 import os
@@ -32,6 +32,7 @@ import struct
 from PyQt5 import QtWidgets, QtCore
 import numpy as np
 from osgeo import gdal, osr
+
 from pygmi.raster.datatypes import Data
 from pygmi.raster.dataprep import merge
 
@@ -128,7 +129,7 @@ class ComboBoxBasic(QtWidgets.QDialog):
 
 class ImportData():
     """
-    Import Data - Interfaces with GDAL routines
+    Import Data - Interfaces with GDAL routines.
 
     Attributes
     ----------
@@ -148,7 +149,6 @@ class ImportData():
 
     def __init__(self, parent=None):
         self.ifile = ''
-        self.pbar = None
         self.parent = parent
         self.indata = {}
         self.outdata = {}
@@ -168,27 +168,28 @@ class ImportData():
             True if successful, False otherwise.
 
         """
-
-        piter = None
+        piter = iter
         if not nodialog:
             if self.parent is not None:
                 piter = self.parent.pbar.iter
-            ext = ('Common formats (*.ers *.hdr *.tif *.sdat *.img *.pix *.bil);;'
-                   'ERMapper (*.ers);;'
-                   'ENVI (*.hdr *.dat *.img *.raw);;'
-                   'ERDAS Imagine (*.img);;'
-                   'PCI Geomatics Database File (*.pix);;'
-                   'GeoTiff (*.tif);;'
-                   'SAGA binary grid (*.sdat);;'
-                   'Geosoft UNCOMPRESSED grid (*.grd);;'
-                   'Geosoft (*.gxf);;'
-                   'Surfer grid (*.grd);;'
-                   'GeoPak grid (*.grd);;'
-                   'ESRI ASCII (*.asc);;'
+            ext = ('Common formats (*.ers *.hdr *.tif *.tiff *.sdat *.img *.pix '
+                   '*.bil);;'
+                   'ArcGIS BIL (*.bil);;'
+                   'Arcinfo Binary Grid (hdr.adf);;'
                    'ASCII with .hdr header (*.asc);;'
                    'ASCII XYZ (*.xyz);;'
-                   'Arcinfo Binary Grid (hdr.adf);;'
-                   'ArcGIS BIL (*.bil)')
+                   'ENVI (*.hdr);;'
+                   'ESRI ASCII (*.asc);;'
+                   'ERMapper (*.ers);;'
+                   'ERDAS Imagine (*.img);;'
+                   'GeoPak grid (*.grd);;'
+                   'Geosoft UNCOMPRESSED grid (*.grd);;'
+                   'Geosoft (*.gxf);;'
+                   'GeoTiff (*.tif *.tiff);;'
+                   'PCI Geomatics Database File (*.pix);;'
+                   'SAGA binary grid (*.sdat);;'
+                   'Surfer grid (*.grd);;'
+                   )
 
             self.ifile, self.filt = QtWidgets.QFileDialog.getOpenFileName(
                 self.parent, 'Open File', '.', ext)
@@ -225,7 +226,7 @@ class ImportData():
                                               'Could not import the surfer 6 '
                                               'grid. Please make sure it not '
                                               'another format, such as '
-                                              'geosoft.',
+                                              'Geosoft.',
                                               QtWidgets.QMessageBox.Ok)
             elif self.filt == 'Geosoft UNCOMPRESSED grid (*.grd)':
                 QtWidgets.QMessageBox.warning(self.parent, 'Error',
@@ -261,7 +262,7 @@ class ImportData():
 
     def loadproj(self, projdata):
         """
-        Loads project data into class.
+        Load project data into class.
 
         Parameters
         ----------
@@ -285,7 +286,6 @@ class ImportData():
         """
         Save project data from class.
 
-
         Returns
         -------
         projdata : dictionary
@@ -302,7 +302,7 @@ class ImportData():
 
 class ImportRGBData():
     """
-    Import RGB Image - Interfaces with GDAL routines
+    Import RGB Image - Interfaces with GDAL routines.
 
     Attributes
     ----------
@@ -322,7 +322,6 @@ class ImportRGBData():
 
     def __init__(self, parent=None):
         self.ifile = ''
-        self.pbar = None
         self.parent = parent
         self.indata = {}
         self.outdata = {}
@@ -388,7 +387,7 @@ class ImportRGBData():
 
     def loadproj(self, projdata):
         """
-        Loads project data into class.
+        Load project data into class.
 
         Parameters
         ----------
@@ -411,7 +410,6 @@ class ImportRGBData():
         """
         Save project data from class.
 
-
         Returns
         -------
         projdata : dictionary
@@ -457,7 +455,7 @@ def clusterprep(dat):
 
 def get_ascii(ifile):
     """
-    Import ascii raster dataset
+    Import ascii raster dataset.
 
     Parameters
     ----------
@@ -540,8 +538,11 @@ def get_ascii(ifile):
     return dat
 
 
-def get_raster(ifile, nval=None, piter=None, showprocesslog=print):
+def get_raster(ifile, nval=None, piter=iter, showprocesslog=print,
+               iraster=None):
     """
+    Get raster dataset.
+
     This function loads a raster dataset off the disk using the GDAL
     libraries. It returns the data in a PyGMI data object.
 
@@ -551,16 +552,19 @@ def get_raster(ifile, nval=None, piter=None, showprocesslog=print):
         filename to import
     nval : float, optional
         No data/null value. The default is None.
+    piter : iterable from misc.ProgressBar or misc.ProgressBarText
+        progress bar iterable
+    showprocesslog : print or other text output
+        Allows for printing either using print or to the Qt interface.
+    iraster : None or tuple
+        Incremental raster import, to import a section of a file. The tuple is
+        (xoff, yoff, xsize, ysize)
 
     Returns
     -------
     dat : PyGMI raster Data
         dataset imported
     """
-
-    if piter is None:
-        piter = iter
-
     dat = []
     bname = ifile.split('/')[-1].rpartition('.')[0]
     ifile = ifile[:]
@@ -571,9 +575,14 @@ def get_raster(ifile, nval=None, piter=None, showprocesslog=print):
     # Envi Case
     if ext == 'hdr':
         ifile = ifile[:-4]
-        tmp = glob.glob(ifile+'.dat')
-        if tmp:
-            ifile = tmp[0]
+        if os.path.exists(ifile+'.dat'):
+            ifile = ifile+'.dat'
+        elif os.path.exists(ifile+'.raw'):
+            ifile = ifile+'.raw'
+        elif os.path.exists(ifile+'.img'):
+            ifile = ifile+'.img'
+        elif not os.path.exists(ifile):
+            return None
 
     if ext == 'ers':
         with open(ifile) as f:
@@ -596,12 +605,30 @@ def get_raster(ifile, nval=None, piter=None, showprocesslog=print):
                     custom_wkt = orig.ExportToWkt()
 
     dataset = gdal.Open(ifile, gdal.GA_ReadOnly)
-
     if dataset is None:
         return None
 
-    gtr = dataset.GetGeoTransform()
+    istruct = dataset.GetMetadata('IMAGE_STRUCTURE')
+    driver = dataset.GetDriver().GetDescription()
 
+    dmeta = {}
+    if driver == 'ENVI':
+        dmeta = dataset.GetMetadata('ENVI')
+
+    if 'INTERLEAVE' in istruct and driver in ['ENVI', 'ERS', 'EHdr']:
+        if istruct['INTERLEAVE'] == 'LINE':
+            dataset = None
+            dat = get_bil(ifile, nval, piter, showprocesslog)
+            return dat
+
+    if custom_wkt is None:
+        srs = osr.SpatialReference()
+        srs.ImportFromWkt(dataset.GetProjection())
+        srs.SetAxisMappingStrategy(osr.OAMS_TRADITIONAL_GIS_ORDER)
+        srs.AutoIdentifyEPSG()
+        custom_wkt = srs.ExportToWkt()
+
+    gtr = dataset.GetGeoTransform()
     for i in piter(range(dataset.RasterCount)):
         rtmp = dataset.GetRasterBand(i+1)
         bandid = rtmp.GetDescription()
@@ -609,7 +636,12 @@ def get_raster(ifile, nval=None, piter=None, showprocesslog=print):
             nval = rtmp.GetNoDataValue()
 
         dat.append(Data())
-        dat[i].data = rtmp.ReadAsArray()
+        if iraster is None:
+            dat[i].data = rtmp.ReadAsArray()
+        else:
+            xoff, yoff, xsize, ysize = iraster
+            dat[i].data = rtmp.ReadAsArray(xoff, yoff, xsize, ysize)
+
         if dat[i].data.dtype.kind == 'i':
             if nval is None:
                 nval = 999999
@@ -648,30 +680,201 @@ def get_raster(ifile, nval=None, piter=None, showprocesslog=print):
         if bandid == '':
             bandid = 'Band '+str(i+1)+' '+bname
         dat[i].dataid = bandid
-        if bandid[-1] == ')':
-            dat[i].units = bandid[bandid.rfind('(')+1:-1]
+
+        for unit in ['micrometers', 'nanometers', 'nT', 'mGal']:
+            if unit in bandid or unit in bandid.lower():
+                if unit == 'micrometers':
+                    dat[i].units = 'μm'
+                elif unit == 'nanometers':
+                    dat[i].units = 'nm'
+                else:
+                    dat[i].units = unit
+
+        # if bandid[-1] == ')':
+        #     dat[i].units = bandid[bandid.rfind('(')+1:-1]
 
         dat[i].nullvalue = nval
-
-        if custom_wkt is None:
-            srs = osr.SpatialReference()
-            srs.ImportFromWkt(dataset.GetProjection())
-            srs.SetAxisMappingStrategy(osr.OAMS_TRADITIONAL_GIS_ORDER)
-            srs.AutoIdentifyEPSG()
-            dat[i].wkt = srs.ExportToWkt()
-        else:
-            dat[i].wkt = custom_wkt
-
+        dat[i].wkt = custom_wkt
         dat[i].filename = filename
 
+        dest = rtmp.GetMetadata()
+        for j in ['Wavelength', 'WAVELENGTH']:
+            if j in dest:
+                dest[j.lower()] = dest[j]
+                del dest[j]
+
+        dat[i].metadata['Raster'] = {**dmeta, **dest}
+
     dataset = None
 
     return dat
 
 
+def get_bil(ifile, nval, piter, showprocesslog):
+    """
+    Get BIL format file.
+
+    Parameters
+    ----------
+    ifile : str
+        filename to import
+    nval : float
+        No data/null value. The default is None.
+    piter : iterable from misc.ProgressBar or misc.ProgressBarText
+        progress bar iterable
+    showprocesslog : print or other text output
+        Allows for printing either using print or to the Qt interface.
+
+    Returns
+    -------
+    dat : PyGMI raster Data
+        dataset imported
+
+    """
+    dat = []
+    bname = ifile.split('/')[-1].rpartition('.')[0]
+    ifile = ifile[:]
+    ext = ifile[-3:]
+    custom_wkt = None
+    filename = ifile
+
+    if ext == 'hdr':
+        ifile = ifile[:-4]
+        if os.path.exists(ifile+'.dat'):
+            ifile = ifile+'.dat'
+        elif os.path.exists(ifile+'.raw'):
+            ifile = ifile+'.raw'
+        elif os.path.exists(ifile+'.img'):
+            ifile = ifile+'.img'
+        elif not os.path.exists(ifile):
+            return None
+
+    if ext == 'ers':
+        with open(ifile) as f:
+            metadata = f.read()
+            if 'STMLO' in metadata:
+                clong = metadata.split('STMLO')[1][:2]
+
+                orig = osr.SpatialReference()
+                orig.SetAxisMappingStrategy(osr.OAMS_TRADITIONAL_GIS_ORDER)
+
+                if 'CAPE' in metadata:
+                    orig.ImportFromEPSG(4222)
+                    orig.SetTM(0., float(clong), 1., 0., 0.)
+                    orig.SetProjCS(r'Cape / TM'+clong)
+                    custom_wkt = orig.ExportToWkt()
+                elif 'WGS84' in metadata:
+                    orig.ImportFromEPSG(4148)
+                    orig.SetTM(0., float(clong), 1., 0., 0.)
+                    orig.SetProjCS(r'Hartebeesthoek94 / TM'+clong)
+                    custom_wkt = orig.ExportToWkt()
+
+    dataset = gdal.Open(ifile, gdal.GA_ReadOnly)
+    driver = dataset.GetDriver().GetDescription()
+
+    dmeta = {}
+    if driver == 'ENVI':
+        dmeta = dataset.GetMetadata('ENVI')
+
+    if custom_wkt is None:
+        srs = osr.SpatialReference()
+        srs.ImportFromWkt(dataset.GetProjection())
+        srs.SetAxisMappingStrategy(osr.OAMS_TRADITIONAL_GIS_ORDER)
+        srs.AutoIdentifyEPSG()
+        custom_wkt = srs.ExportToWkt()
+
+    bands = dataset.RasterCount
+    cols = dataset.RasterXSize
+    rows = dataset.RasterYSize
+    # envimeta = dataset.GetMetadata('ENVI')
+    gtr = dataset.GetGeoTransform()
+
+    band = dataset.GetRasterBand(1)
+    cols = band.XSize
+    rows = band.YSize
+    dtype = band.DataType
+
+    dt2np = {}
+    dt2np[0] = None
+    dt2np[1] = np.uint8
+    dt2np[2] = np.uint16
+    dt2np[3] = np.int16
+    dt2np[4] = np.uint32
+    dt2np[5] = np.int32
+    dt2np[6] = np.float32
+    dt2np[7] = np.float64
+
+    if dt2np[dtype] is None:
+        return False
+
+    count = bands*cols*rows
+
+    offset = 0
+    icount = count//10
+    datin = []
+    dsize = dt2np[dtype]().itemsize
+    for i in piter(range(0, 10)):
+        tmp = np.fromfile(ifile, dtype=dt2np[dtype], sep='', count=icount,
+                          offset=offset)
+        offset += icount*dsize
+        datin.append(tmp)
+
+    extra = int(count-offset/dsize)
+    if extra > 0:
+        tmp = np.fromfile(ifile, dtype=dt2np[dtype], sep='', count=extra,
+                          offset=offset)
+        datin.append(tmp)
+
+    datin = np.concatenate(datin)
+
+    datin.shape = (rows, bands, cols)
+
+    datin = np.swapaxes(datin, 0, 1)
+
+    if nval is None:
+        nval = 0
+
+    dat = []
+    for i in piter(range(bands)):
+        rtmp = dataset.GetRasterBand(i+1)
+        bandid = rtmp.GetDescription()
+        if nval is None:
+            nval = rtmp.GetNoDataValue()
+        dat.append(Data())
+
+        dat[-1].data = datin[i]
+
+        if ext == 'ers' and nval == -1.0e+32:
+            dat[i].data[dat[-1].data <= nval] = -1.0e+32
+
+        dat[i].data = np.ma.array(dat[i].data)
+        dat[i].data.mask = (dat[i].data == nval)
+
+        # dat[i].data = np.ma.masked_invalid(dat[i].data)
+
+        dat[i].extent_from_gtr(gtr)
+
+        if bandid == '':
+            bandid = 'Band '+str(i+1)+' '+bname
+        dat[i].dataid = bandid
+        if bandid[-1] == ')':
+            dat[i].units = bandid[bandid.rfind('(')+1:-1]
+
+        dat[i].nullvalue = nval
+        dat[i].wkt = custom_wkt
+        dat[i].filename = filename
+        dest = rtmp.GetMetadata()
+        for j in ['Wavelength', 'WAVELENGTH']:
+            if j in dest:
+                dest[j.lower()] = dest[j]
+                del dest[j]
+        dat[i].metadata['Raster'] = {**dmeta, **dest}
+    return dat
+
+
 def get_geopak(hfile):
     """
-    GeoPak Import
+    Geopak Import.
 
     Parameters
     ----------
@@ -689,7 +892,6 @@ def get_geopak(hfile):
         PyGMI raster dataset.
 
     """
-
     with open(hfile, 'rb') as fin:
         fall = fin.read()
 
@@ -789,7 +991,7 @@ def get_geopak(hfile):
 
 def get_geosoft(hfile):
     """
-    Get geosoft file.
+    Get Geosoft file.
 
     Parameters
     ----------
@@ -877,7 +1079,7 @@ def get_geosoft(hfile):
 
 class ExportData():
     """
-    Export Data
+    Export Data.
 
     Attributes
     ----------
@@ -902,7 +1104,6 @@ class ExportData():
             self.piter = iter
         else:
             self.piter = parent.pbar.iter
-        self.pbar = None
         self.parent = parent
         self.indata = {}
         self.outdata = {}
@@ -1001,7 +1202,7 @@ class ExportData():
 
     def export_gxf(self, data):
         """
-        Export GXF data
+        Export GXF data.
 
         Parameters
         ----------
@@ -1067,7 +1268,7 @@ class ExportData():
 
     def export_surfer(self, data):
         """
-        Export a surfer binary grid
+        Export a surfer binary grid.
 
         Parameters
         ----------
@@ -1112,7 +1313,7 @@ class ExportData():
 
     def export_ascii(self, data):
         """
-        Export Ascii file
+        Export Ascii file.
 
         Parameters
         ----------
@@ -1159,7 +1360,7 @@ class ExportData():
 
     def export_ascii_xyz(self, data):
         """
-        Export and xyz file
+        Export and xyz file.
 
         Parameters
         ----------
@@ -1197,7 +1398,7 @@ class ExportData():
 
     def get_filename(self, data, ext):
         """
-        Gets a valid filename in the case of multi band image
+        Get a valid filename in the case of multi band image.
 
         Parameters
         ----------
@@ -1220,26 +1421,28 @@ class ExportData():
         return file_out
 
 
-def export_gdal(ifile, dat, drv, envimeta='', piter=None):
+def export_gdal(ofile, dat, drv, envimeta='', piter=iter):
     """
-    Export to GDAL format
+    Export to GDAL format.
 
     Parameters
     ----------
+    ofile : str
+        Output file name.
     dat : PyGMI raster Data
         dataset to export
     drv : str
         name of the GDAL driver to use
+    envimeta : str, optional
+        ENVI metadata. The default is ''.
+    piter : ProgressBar.iter/ProgressBarText.iter, optional
+        Progressbar iterable from misc. The default is None.
 
     Returns
     -------
     None.
 
     """
-
-    if piter is None:
-        piter = iter
-
     if isinstance(dat, dict):
         dat2 = []
         for i in dat:
@@ -1247,7 +1450,7 @@ def export_gdal(ifile, dat, drv, envimeta='', piter=None):
     else:
         dat2 = dat
 
-    data = merge(dat2)
+    data = merge(dat2, piter)
 
     driver = gdal.GetDriverByName(drv)
     dtype = data[0].data.dtype
@@ -1263,7 +1466,7 @@ def export_gdal(ifile, dat, drv, envimeta='', piter=None):
     else:
         fmt = gdal.GDT_Float32
 
-    tmp = ifile.rpartition('.')
+    tmp = ofile.rpartition('.')
 
     if drv == 'GTiff':
         tmpfile = tmp[0] + '.tif'
@@ -1285,12 +1488,13 @@ def export_gdal(ifile, dat, drv, envimeta='', piter=None):
     elif drv == 'ERS':  # ER Mapper
         tmpfile = tmp[0]
     else:
-        tmpfile = ifile
+        tmpfile = ofile
 
     drows, dcols = data[0].data.shape
     if drv == 'GTiff':
         out = driver.Create(tmpfile, int(dcols), int(drows),
                             len(data), fmt, options=['COMPRESS=NONE',
+                                                     'INTERLEAVE=BAND',
                                                      'TFW=YES',
                                                      'PROFILE=GeoTIFF',
                                                      'ESRI_XML_PAM=True'])
@@ -1311,7 +1515,6 @@ def export_gdal(ifile, dat, drv, envimeta='', piter=None):
                             len(data), fmt)
 
     out.SetGeoTransform(data[0].get_gtr())
-
     out.SetProjection(data[0].wkt)
 
     numbands = len(data)
@@ -1335,8 +1538,39 @@ def export_gdal(ifile, dat, drv, envimeta='', piter=None):
         rtmp.WriteArray(dtmp)
         rtmp.GetStatistics(False, True)
 
+        if 'WavelengthMin' in datai.metadata:
+            rtmp.SetMetadataItem('WavelengthMin',
+                                 str(datai.metadata['WavelengthMin']))
+            rtmp.SetMetadataItem('WavelengthMax',
+                                 str(datai.metadata['WavelengthMax']))
+
     out = None  # Close File
     if drv == 'ENVI':
         with open(tmpfile[:-4]+'.hdr', 'a') as myfile:
             myfile.write('data ignore value = ' + str(data[0].nullvalue)+'\n')
             myfile.write(envimeta)
+
+
+def _filespeedtest():
+    """Test."""
+    from pygmi.misc import ProgressBarText
+
+    print('Starting')
+    pbar = ProgressBarText()
+    ifile = r'E:\WorkData\HyperspectralScanner\Raw Data\LWIR(OWL)\bv1_17_118m16_125m79_2020-06-30_12-43-14\capture\BV1_17_118m16_125m79_2020-06-30_12-43-14.raw'
+    ifile = r'E:\WorkData\Richtersveld\Reprocessed\RSarea_Hyper.dat'
+    ifile = r'C:\Work\WorkData\Hyperspectral\056_0818-1125_ref_rect.dat'
+    # ifile = r'C:\Work\WorkData\Hyperspectral\056_0818-1125_ref_rect_BSQ.dat'
+
+    # xoff = 0
+    # yoff = 0
+    # xsize = None
+    # ysize = 1000
+    # iraster = (xoff, yoff, xsize, ysize)
+    iraster = None
+
+    dataset = get_raster(ifile, piter=pbar.iter, iraster=iraster)
+
+
+if __name__ == "__main__":
+    _filespeedtest()
