@@ -1,6 +1,8 @@
 """
 Modification of Chris Beaumont's mpl-modest-image package to allow the use of
 set_extent.
+
+pcole, 2021  - Bugfix to allow for correct zooming if origin is set to 'upper'
 """
 from __future__ import print_function, division
 
@@ -39,6 +41,7 @@ class ModestImage(mi.AxesImage):
     def __init__(self, *args, **kwargs):
         self._full_res = None
         self._full_extent = kwargs.get('extent', None)
+        self.origin = kwargs.get('origin', 'lower')
         super(ModestImage, self).__init__(*args, **kwargs)
         self.invalidate_cache()
 
@@ -52,12 +55,12 @@ class ModestImage(mi.AxesImage):
         self._A = A
 
         if self._A.dtype != np.uint8 and not np.can_cast(self._A.dtype,
-                                                         np.float):
+                                                         float):
             raise TypeError("Image data can not convert to float")
 
         if (self._A.ndim not in (2, 3) or
                 (self._A.ndim == 3 and self._A.shape[-1] not in (3, 4))):
-                raise TypeError("Invalid dimensions for image data")
+            raise TypeError("Invalid dimensions for image data")
 
         self.invalidate_cache()
 
@@ -101,8 +104,10 @@ class ModestImage(mi.AxesImage):
 
                 self._pixel2world.translate(+0.5, +0.5)
 
-                self._pixel2world.scale((extent[1] - extent[0]) / self._full_res.shape[1],
-                                        (extent[3] - extent[2]) / self._full_res.shape[0])
+                self._pixel2world.scale((extent[1] - extent[0]) /
+                                        self._full_res.shape[1],
+                                        (extent[3] - extent[2]) /
+                                        self._full_res.shape[0])
 
                 self._pixel2world.translate(extent[0], extent[2])
 
@@ -129,6 +134,7 @@ class ModestImage(mi.AxesImage):
                                                         shape=self._full_res.shape,
                                                         transform=self._world2pixel)
 
+        # breakpoint()
         # Check whether we've already calculated what we need, and if so just
         # return without doing anything further.
         if (self._bounds is not None and
@@ -139,11 +145,20 @@ class ModestImage(mi.AxesImage):
 
         # Slice the array using the slices determined previously to optimally
         # match the display
-        self._A = self._full_res[y0:y1:sy, x0:x1:sx]
-        self._A = cbook.safe_masked_invalid(self._A)
+        # sx=1
+        # sy=1
 
-        # We now determine the extent of the subset of the image, by determining
-        # it first in pixel space, and converting it to the 'world' coordinates.
+        if self.origin == 'upper':
+            self._A = self._full_res[::-1][y0:y1:sy, x0:x1:sx]
+            self._A = cbook.safe_masked_invalid(self._A)
+            self._A = self._A[::-1]
+        else:
+            self._A = self._full_res[y0:y1:sy, x0:x1:sx]
+            self._A = cbook.safe_masked_invalid(self._A)
+
+        # We now determine the extent of the subset of the image, by
+        # determining it first in pixel space, and converting it to the
+        # 'world' coordinates.
 
         # See https://github.com/matplotlib/matplotlib/issues/8693 for a
         # demonstration of why origin='upper' and extent=None needs to be
@@ -154,7 +169,8 @@ class ModestImage(mi.AxesImage):
         else:
             xmin, xmax, ymin, ymax = x0 - .5, x1 - .5, y0 - .5, y1 - .5
 
-        xmin, ymin, xmax, ymax = self._pixel2world.transform([(xmin, ymin), (xmax, ymax)]).ravel()
+        xmin, ymin, xmax, ymax = self._pixel2world.transform([(xmin, ymin),
+                                                              (xmax, ymax)]).ravel()
 
         mi.AxesImage.set_extent(self, [xmin, xmax, ymin, ymax])
         # self.set_extent([xmin, xmax, ymin, ymax])
@@ -184,24 +200,20 @@ def main():
     ax = f.add_subplot(111)
 
     # try switching between
-    # artist = ModestImage(ax, data=data)
+    artist = ModestImage(ax, data=data)
 
-    # ax.set_aspect('equal')
-    # artist.norm.vmin = -1
-    # artist.norm.vmax = 1
+    ax.set_aspect('equal')
+    artist.norm.vmin = -1
+    artist.norm.vmax = 1
 
-    # ax.add_artist(artist)
+    ax.add_artist(artist)
 
-    imshow(ax, data)
+    t0 = time()
+    plt.gcf().canvas.draw()
+    t1 = time()
 
-    # breakpoint()
-
-    # t0 = time()
-    # plt.gcf().canvas.draw()
-    # t1 = time()
-
-    # print("Draw time for %s: %0.1f ms" % (artist.__class__.__name__,
-    #                                       (t1 - t0) * 1000))
+    print("Draw time for %s: %0.1f ms" % (artist.__class__.__name__,
+                                          (t1 - t0) * 1000))
 
     plt.show()
 
@@ -214,8 +226,6 @@ def imshow(axes, X, cmap=None, norm=None, aspect=None,
 
     Unlike matplotlib version, must explicitly specify axes
     """
-    # if not axes._hold:
-    #     axes.cla()
     if norm is not None:
         assert(isinstance(norm, mcolors.Normalize))
     if aspect is None:
@@ -271,10 +281,12 @@ def extract_matched_slices(axes=None, shape=None, extent=None,
 
     # Find extent in display pixels (this gives the resolution we need
     # to sample the array to)
-    ext = (axes.transAxes.transform([(1, 1)]) - axes.transAxes.transform([(0, 0)]))[0]
+    ext = (axes.transAxes.transform([(1, 1)]) -
+           axes.transAxes.transform([(0, 0)]))[0]
 
     # Find the extent of the axes in 'world' coordinates
     xlim, ylim = axes.get_xlim(), axes.get_ylim()
+    # breakpoint()
 
     # Transform the limits to pixel coordinates
     ind0 = transform.transform([min(xlim), min(ylim)])
@@ -293,11 +305,39 @@ def extract_matched_slices(axes=None, shape=None, extent=None,
     x1 = _clip(ind1[0] + 5, 1, shape[1])
 
     # Determine the strides that can be used when extracting the array
-    sy = int(max(1, min((y1 - y0) / 5., np.ceil(abs((ind1[1] - ind0[1]) / ext[1])))))
-    sx = int(max(1, min((x1 - x0) / 5., np.ceil(abs((ind1[0] - ind0[0]) / ext[0])))))
+    sy = int(max(1, min((y1 - y0) / 5., np.ceil(abs((ind1[1] - ind0[1]) /
+                                                    ext[1])))))
+    sx = int(max(1, min((x1 - x0) / 5., np.ceil(abs((ind1[0] - ind0[0]) /
+                                                    ext[0])))))
 
     return x0, x1, sx, y0, y1, sy
 
 
+def main2():
+    """main2."""
+    from pygmi.raster.iodefs import get_raster
+    from pygmi.misc import ProgressBarText
+    import matplotlib.pyplot as plt
+    from IPython import get_ipython
+    get_ipython().magic('matplotlib qt5')
+
+
+    ifile = r'E:\Work\Programming\mpl-modest-image-master\test.tif'
+    ifile = r'E:\workdata\testdata.hdr'
+    # ifile = r'E:\Workdata\Richtersveld\Reprocessed\030_0815-1050_ref_rect.hdr'
+
+    pbar = ProgressBarText()
+
+    data = get_raster(ifile, piter=pbar.iter)
+
+    cdat = data[1].data
+    extent = data[1].extent
+
+    f = plt.figure()
+    ax = f.add_subplot(111)
+    imshow(ax, cdat, extent=extent)
+    plt.show()
+
+
 if __name__ == "__main__":
-    main()
+    main2()
