@@ -182,7 +182,7 @@ class Smooth(QtWidgets.QDialog):
 
     def loadproj(self, projdata):
         """
-        Loads project data into class.
+        Load project data into class.
 
         Parameters
         ----------
@@ -195,7 +195,6 @@ class Smooth(QtWidgets.QDialog):
             A check to see if settings was successfully run.
 
         """
-
         if projdata['ftype'] == '2D Mean':
             self.radiobutton_2dmean.setChecked(True)
         else:
@@ -220,7 +219,6 @@ class Smooth(QtWidgets.QDialog):
         """
         Save project data from class.
 
-
         Returns
         -------
         projdata : dictionary
@@ -409,6 +407,7 @@ class Smooth(QtWidgets.QDialog):
         dummy.mask[drr-1:drr-1+rowd, dcc-1:dcc-1+cold] = dat.mask
 
         dummy.data[dummy.mask] = np.nan
+        dat = dat.astype(float)
         dat.data[dat.mask] = np.nan
 
         if itype == '2D Mean':
