@@ -37,10 +37,12 @@ from matplotlib.figure import Figure
 import matplotlib.animation as manimation
 from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg
 from matplotlib.backends.backend_qt5 import NavigationToolbar2QT
+
 # import pygmi.menu_default as menu_default
 from pygmi.raster.datatypes import Data
 from pygmi.misc import frm
 from pygmi.raster.ginterp import histcomp, norm255
+from pygmi.raster.modest_image import imshow
 
 
 class CreateSceneList(QtWidgets.QDialog):
@@ -134,7 +136,6 @@ class CreateSceneList(QtWidgets.QDialog):
             True if successful, False otherwise.
 
         """
-
         if not nodialog:
             tmp = self.exec_()
 
@@ -435,7 +436,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
         self.fig.canvas.mpl_connect('button_release_event', self.onClick)
 
     def capture(self):
-        """ capture """
+        """Capture."""
         self.capture_active = not self.capture_active
 
         if self.capture_active:
@@ -488,6 +489,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
 
         extent = dat[self.bands[0]].extent
 
+        # self.im1 = imshow(self.ax1, dtmp, extent=extent)
         self.im1 = self.ax1.imshow(dtmp, extent=extent)
         self.ax1.plot(points[:, 0], points[:, 1])
         self.cbar = None
@@ -511,7 +513,6 @@ class MyMplCanvas(FigureCanvasQTAgg):
 
         """
         extent = dat[self.bands[0]].extent
-#        breakpoint()
         if self.manip == 'NDWI':
             if self.cbar is None:
                 self.cbar = self.figure.colorbar(self.im1, format=frm)
@@ -588,7 +589,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
 
     def onClick(self, event):
         """
-        onClick event.
+        On click event.
 
         Parameters
         ----------
@@ -621,7 +622,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
 
 
 class SceneViewer(QtWidgets.QDialog):
-    """Application Window."""
+    """Scene Viewer."""
 
     def __init__(self, parent=None):
         super().__init__(parent)
@@ -707,7 +708,6 @@ class SceneViewer(QtWidgets.QDialog):
             True if successful, False otherwise.
 
         """
-
         if 'SceneList' not in self.indata:
             return False
 
@@ -746,7 +746,6 @@ class SceneViewer(QtWidgets.QDialog):
             A check to see if settings was successfully run.
 
         """
-
         return False
 
     def saveproj(self):
@@ -784,7 +783,7 @@ class SceneViewer(QtWidgets.QDialog):
 
     def updateanim(self, event):
         """
-        Update animation file
+        Update animation file.
 
         Parameters
         ----------
@@ -797,7 +796,6 @@ class SceneViewer(QtWidgets.QDialog):
             True if successful, False otherwise.
 
         """
-
         ext = ('Scene List File (*.xlsx)')
 
         filename, _ = QtWidgets.QFileDialog.getSaveFileName(
@@ -811,7 +809,7 @@ class SceneViewer(QtWidgets.QDialog):
 
     def nextscene(self, event):
         """
-        Gets next scene
+        Get next scene.
 
         Parameters
         ----------
@@ -859,7 +857,7 @@ class SceneViewer(QtWidgets.QDialog):
 
     def newdata(self, indx, capture=False):
         """
-        New dataset.
+        Get new dataset.
 
         Parameters
         ----------
@@ -886,8 +884,7 @@ class SceneViewer(QtWidgets.QDialog):
         self.canvas.update_plot(dat, dates)
 
     def capture(self):
-        """ Capture """
-
+        """Capture."""
         self.slider.valueChanged.disconnect()
 
         self.canvas.capture()
@@ -941,7 +938,7 @@ class SceneViewer(QtWidgets.QDialog):
 
     def get_tiff(self, ifile, firstrun=False):
         """
-        Gets tiff images
+        Get TIFF images.
 
         Parameters
         ----------
@@ -956,7 +953,6 @@ class SceneViewer(QtWidgets.QDialog):
             Data images
 
         """
-
         datall = {}
         ifile = str(ifile)
 
@@ -1052,7 +1048,7 @@ class SceneViewer(QtWidgets.QDialog):
 
 def get_shape_coords(sfile, todegrees=False):
     """
-    Gets coords from a shapefile.
+    Get coordinates from a shapefile.
 
     Parameters
     ----------
@@ -1115,13 +1111,13 @@ def get_kml_coords(kml):
 
     Parameters
     ----------
-    kml : TYPE
-        DESCRIPTION.
+    kml : str.
+        kml file name.
 
     Returns
     -------
-    coordinates : TYPE
-        DESCRIPTION.
+    coordinates : numpy array
+        Coordinate in numpy format.
 
     """
     ns = "{http://www.opengis.net/kml/2.2}"
@@ -1143,8 +1139,8 @@ def get_kml_coords(kml):
     return coordinates
 
 
-def testfn():
-    """Main testing routine."""
+def _testfn():
+    """Test routine."""
     import sys
 #    sfile = r'C:\Work\Workdata\change\PlanetaryPolygon.shp'
     sfile = r'C:\Work\Workdata\change\fl35.shp'
@@ -1159,10 +1155,9 @@ def testfn():
     CSL.settings(True)
 
     plt.show()
-    breakpoint()
 
 
-def testanim():
+def _testanim():
     """Test for animation."""
     # import sys
     from matplotlib import rcParams
@@ -1172,7 +1167,6 @@ def testanim():
 
     rcParams['figure.dpi'] = 300
     # rcParams['savefig.dpi'] = 300
-    # breakpoint()
 
     # APP = QtWidgets.QApplication(sys.argv)  # Necessary to test Qt Classes
     fig = plt.figure()
@@ -1209,4 +1203,4 @@ def testanim():
 
 
 if __name__ == "__main__":
-    testanim()
+    _testanim()
