@@ -22,7 +22,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 # -----------------------------------------------------------------------------
-"""Import Data."""
+"""Import remote sensing data."""
 
 import os
 import copy
@@ -37,6 +37,7 @@ import pandas as pd
 import geopandas as gpd
 from geopandas import GeoDataFrame
 from shapely.geometry import Point
+
 import pygmi.menu_default as menu_default
 from pygmi.raster.datatypes import Data
 from pygmi.vector.dataprep import quickgrid
@@ -141,7 +142,7 @@ ESUN = [1848, 1549, 1114, 225.4, 86.63, 81.85, 74.85, 66.49, 59.85]
 
 class ImportData():
     """
-    Import Data - Interfaces with GDAL routines
+    Import Data - Interfaces with GDAL routines.
 
     Attributes
     ----------
@@ -162,7 +163,6 @@ class ImportData():
     def __init__(self, parent=None, extscene=None):
         self.ifile = ''
         self.filt = ''
-        self.pbar = None
         self.parent = parent
         self.indata = {}
         self.outdata = {}
@@ -182,7 +182,6 @@ class ImportData():
             True if successful, False otherwise.
 
         """
-
         piter = self.parent.pbar.iter
 
         if self.extscene is None:
@@ -216,7 +215,7 @@ class ImportData():
 
     def loadproj(self, projdata):
         """
-        Loads project data into class.
+        Load project data into class.
 
         Parameters
         ----------
@@ -241,7 +240,6 @@ class ImportData():
         """
         Save project data from class.
 
-
         Returns
         -------
         projdata : dictionary
@@ -259,28 +257,28 @@ class ImportData():
 
 class ImportBatch():
     """
-    Import Data - Interfaces with GDAL routines
+    Batch Import Data Interface.
+
+    This does not actually import data, but rather defines a list of datasets
+    to be used by other routines.
 
     Attributes
     ----------
-    name : str
-        item name
-    pbar : progressbar
-        reference to a progress bar.
     parent : parent
-        reference to the parent routine
-    outdata : dictionary
-        dictionary of output datasets
+        reference to the parent routine.
+    idir : str
+        Input directory.
     ifile : str
-        input file name. Used in main.py
-    ext : str
-        filename extension
+        Input file.
+    indata : dictionary
+        dictionary of input datasets.
+    outdata : dictionary
+        dictionary of output datasets.
     """
 
     def __init__(self, parent=None):
         self.ifile = ''
         self.idir = ''
-        self.pbar = None
         self.parent = parent
         self.indata = {}
         self.outdata = {}
@@ -305,7 +303,7 @@ class ImportBatch():
         zipdat = glob.glob(self.idir+'//AST*.zip')
         hdfdat = glob.glob(self.idir+'//AST*.hdf')
 #        tifdat = glob.glob(directory+'//AST*.tif')
-        targzdat = glob.glob(self.idir+'//L*.tar.gz')
+        targzdat = glob.glob(self.idir+'//L*.tar*')
         mtldat = glob.glob(self.idir+'//L*MTL.txt')
 
         sendat = []
@@ -343,7 +341,7 @@ class ImportBatch():
 
     def loadproj(self, projdata):
         """
-        Loads project data into class.
+        Load project data into class.
 
         Parameters
         ----------
@@ -366,7 +364,6 @@ class ImportBatch():
         """
         Save project data from class.
 
-
         Returns
         -------
         projdata : dictionary
@@ -407,7 +404,6 @@ class ImportSentinel5P(QtWidgets.QDialog):
         else:
             self.showprocesslog = parent.showprocesslog
 
-        self.pbar = None  # self.parent.pbar
         self.parent = parent
         self.indata = {}
         self.outdata = {}
@@ -477,7 +473,6 @@ class ImportSentinel5P(QtWidgets.QDialog):
             True if successful, False otherwise.
 
         """
-
         if not nodialog:
             ext = ('Sentinel-5P (*.nc)')
 
@@ -529,7 +524,7 @@ class ImportSentinel5P(QtWidgets.QDialog):
 
     def loadproj(self, projdata):
         """
-        Loads project data into class.
+        Load project data into class.
 
         Parameters
         ----------
@@ -553,7 +548,6 @@ class ImportSentinel5P(QtWidgets.QDialog):
         """
         Save project data from class.
 
-
         Returns
         -------
         projdata : dictionary
@@ -577,7 +571,6 @@ class ImportSentinel5P(QtWidgets.QDialog):
             Dictionary containing metadata.
 
         """
-
         dataset = gdal.Open(self.ifile, gdal.GA_ReadOnly)
         if dataset is None:
             self.showprocesslog('Problem! Unable to import')
@@ -613,7 +606,7 @@ class ImportSentinel5P(QtWidgets.QDialog):
 
     def get_5P_data(self, meta):
         """
-        Get data.
+        Get 5P data.
 
         Parameters
         ----------
@@ -626,7 +619,6 @@ class ImportSentinel5P(QtWidgets.QDialog):
             geopandas dataframe.
 
         """
-
         dataset = gdal.Open(meta['latitude'][0], gdal.GA_ReadOnly)
         rtmp = dataset.GetRasterBand(1)
         lats = rtmp.ReadAsArray()
@@ -714,7 +706,6 @@ class ImportShapeData():
     """
 
     def __init__(self, parent=None):
-        self.pbar = None
         self.parent = parent
         self.indata = {}
         self.outdata = {}
@@ -749,7 +740,7 @@ class ImportShapeData():
 
     def loadproj(self, projdata):
         """
-        Loads project data into class.
+        Load project data into class.
 
         Parameters
         ----------
@@ -771,7 +762,6 @@ class ImportShapeData():
         """
         Save project data from class.
 
-
         Returns
         -------
         projdata : dictionary
@@ -786,7 +776,9 @@ class ImportShapeData():
 
 def calculate_toa(dat, showprocesslog=print):
     """
-    Top of atmosphere correction. Includes VNIR, SWIR and TIR bands.
+    Top of atmosphere correction.
+
+    Includes VNIR, SWIR and TIR bands.
 
     Parameters
     ----------
@@ -798,7 +790,6 @@ def calculate_toa(dat, showprocesslog=print):
     out : Data
         PyGMI raster dataset
     """
-
     showprocesslog('Calculating top of atmosphere...')
 
     datanew = {}
@@ -831,15 +822,20 @@ def calculate_toa(dat, showprocesslog=print):
     return out
 
 
-def get_data(ifile, piter=None, showprocesslog=print):
+def get_data(ifile, piter=iter, showprocesslog=print):
     """
-    This function loads a raster dataset off the disk using the GDAL
-    libraries. It returns the data in a PyGMI data object.
+    Load a raster dataset off the disk using the GDAL libraries.
+
+    It returns the data in a PyGMI data object.
 
     Parameters
     ----------
     ifile : str
         filename to import
+    piter : iter, optional
+        Progress bar iterable. Default is iter
+    showprogresslog : print, optional
+        Routine for displaying messages. Default is print
 
     Returns
     -------
@@ -864,17 +860,23 @@ def get_data(ifile, piter=None, showprocesslog=print):
     else:
         dat = None
 
+    if dat is not None:
+        for i in dat:
+            i.dataid = i.dataid.replace(',', ' ')
+
     return dat
 
 
 def get_modis(ifile, showprocesslog=print):
     """
-    Gets MODIS data
+    Get MODIS data.
 
     Parameters
     ----------
     ifile : str
         filename to import
+    showprogresslog : print, optional
+        Routine for displaying messages. Default is print
 
     Returns
     -------
@@ -1005,14 +1007,16 @@ def get_modis(ifile, showprocesslog=print):
     return dat
 
 
-def get_modisv6(ifile, piter=None):
+def get_modisv6(ifile, piter=iter):
     """
-    Gets MODIS v006 data.
+    Get MODIS v006 data.
 
     Parameters
     ----------
     ifile : str
         filename to import
+    piter : iter, optional
+        Progress bar iterable. Default is iter
 
     Returns
     -------
@@ -1022,9 +1026,6 @@ def get_modisv6(ifile, piter=None):
     dat = []
     ifile = ifile[:]
 
-    if piter is None:
-        piter = iter
-
     dataset = gdal.Open(ifile, gdal.GA_ReadOnly)
     # dmeta = dataset.GetMetadata()
 
@@ -1093,14 +1094,18 @@ def get_modisv6(ifile, piter=None):
     return dat
 
 
-def get_landsat(ifilet, piter=None, showprocesslog=print):
+def get_landsat(ifilet, piter=iter, showprocesslog=print):
     """
-    Gets Landsat Data.
+    Get Landsat Data.
 
     Parameters
     ----------
     ifilet : str
         filename to import
+    piter : iter, optional
+        Progress bar iterable. Default is iter
+    showprogresslog : print, optional
+        Routine for displaying messages. Default is print
 
     Returns
     -------
@@ -1108,12 +1113,45 @@ def get_landsat(ifilet, piter=None, showprocesslog=print):
         PyGMI raster dataset
     """
 
-    if piter is None:
-        piter = iter
+    platform = os.path.basename(ifilet)[2: 4]
+    satbands = None
+
+    if platform == '04' or platform == '05':
+        satbands = {'1': [450, 520],
+                    '2': [520, 600],
+                    '3': [630, 690],
+                    '4': [760, 900],
+                    '5': [1550, 1750],
+                    '6': [10400, 12500],
+                    '7': [2080, 2350]}
+
+
+    if platform == '07':
+        satbands = {'1': [450, 520],
+                    '2': [520, 600],
+                    '3': [630, 690],
+                    '4': [770, 900],
+                    '5': [1550, 1750],
+                    '6': [10400, 12500],
+                    '7': [2090, 2350],
+                    '8': [520, 900]}
+
+    if platform == '08':
+        satbands = {'1': [430, 450],
+                    '2': [450, 510],
+                    '3': [530, 590],
+                    '4': [640, 670],
+                    '5': [850, 880],
+                    '6': [1570, 1650],
+                    '7': [2110, 2290],
+                    '8': [500, 680],
+                    '9': [1360, 1380],
+                    '10': [1060, 11190],
+                    '11': [11500, 12510]}
 
     idir = os.path.dirname(ifilet)
 
-    if 'tar.gz' in ifilet:
+    if '.tar' in ifilet:
         with tarfile.open(ifilet) as tar:
             tarnames = tar.getnames()
             ifile = next((i for i in tarnames if '_MTL.txt' in i), None)
@@ -1121,6 +1159,7 @@ def get_landsat(ifilet, piter=None, showprocesslog=print):
                 showprocesslog('Could not find MTL.txt file in tar archive')
                 return None
             showprocesslog('Extracting tar...')
+
             tar.extractall(idir)
             ifile = os.path.join(idir, ifile)
     elif '_MTL.txt' in ifilet:
@@ -1149,7 +1188,6 @@ def get_landsat(ifilet, piter=None, showprocesslog=print):
 
         if dataset is None:
             showprocesslog('Problem with band '+fext)
-            breakpoint()
             continue
 
         rtmp = dataset.GetRasterBand(1)
@@ -1168,37 +1206,43 @@ def get_landsat(ifilet, piter=None, showprocesslog=print):
         dat[-1].wkt = dataset.GetProjectionRef()
         dat[-1].filename = ifile
 
+        bmeta = dat[-1].metadata
+        if satbands is not None:
+            bmeta['WavelengthMin'] = satbands[fext][0]
+            bmeta['WavelengthMax'] = satbands[fext][1]
+
         dataset = None
 
     if dat == []:
         dat = None
 
-    if 'tar.gz' in ifilet:
+    if '.tar' in ifilet:
         showprocesslog('Cleaning Extracted tar files...')
-        for tfile in tarnames:
+        for tfile in piter(tarnames):
+            print(tfile)
             os.remove(os.path.join(os.path.dirname(ifile), tfile))
-
+    print('Import complete')
     return dat
 
 
-def get_sentinel2(ifile, piter=None, showprocesslog=print):
+def get_sentinel2(ifile, piter=iter, showprocesslog=print):
     """
-    Gets Sentinel-2 Data.
+    Get Sentinel-2 Data.
 
     Parameters
     ----------
     ifile : str
         filename to import
+    piter : iter, optional
+        Progress bar iterable. Default is iter
+    showprogresslog : print, optional
+        Routine for displaying messages. Default is print
 
     Returns
     -------
     dat : PyGMI raster Data
         dataset imported
     """
-
-    if piter is None:
-        piter = iter
-
     ifile = ifile[:]
 
     dataset = gdal.Open(ifile, gdal.GA_ReadOnly)
@@ -1218,6 +1262,12 @@ def get_sentinel2(ifile, piter=None, showprocesslog=print):
         for i in piter(range(dataset.RasterCount)):
             rtmp = dataset.GetRasterBand(i+1)
             bname = rtmp.GetDescription()
+            bmeta = rtmp.GetMetadata()
+            if 'WAVELENGTH' in bmeta and 'BANDWIDTH' in bmeta:
+                wlen = float(bmeta['WAVELENGTH'])
+                bwidth = float(bmeta['BANDWIDTH'])
+                bmeta['WavelengthMin'] = wlen - bwidth/2
+                bmeta['WavelengthMax'] = wlen + bwidth/2
             # self.showprocesslog('Importing '+bname)
 
             dat.append(Data())
@@ -1235,6 +1285,11 @@ def get_sentinel2(ifile, piter=None, showprocesslog=print):
             dat[-1].wkt = dataset.GetProjectionRef()
             dat[-1].filename = ifile
             dat[-1].units = 'Reflectance'
+            dat[-1].metadata.update(bmeta)
+
+            if 'SOLAR_IRRADIANCE_UNIT' in bmeta:
+                dat[-1].units = bmeta['SOLAR_IRRADIANCE_UNIT']
+
 
     if dat == []:
         dat = None
@@ -1242,14 +1297,18 @@ def get_sentinel2(ifile, piter=None, showprocesslog=print):
     return dat
 
 
-def get_aster_zip(ifile, piter=None, showprocesslog=print):
+def get_aster_zip(ifile, piter=iter, showprocesslog=print):
     """
-    Gets ASTER Data.
+    Get ASTER zip Data.
 
     Parameters
     ----------
     ifile : str
         filename to import
+    piter : iter, optional
+        Progress bar iterable. Default is iter
+    showprogresslog : print, optional
+        Routine for displaying messages. Default is print
 
     Returns
     -------
@@ -1257,8 +1316,21 @@ def get_aster_zip(ifile, piter=None, showprocesslog=print):
         dataset imported
     """
 
-    if piter is None:
-        piter = iter
+    satbands = {'1': [520, 600],
+                '2': [630, 690],
+                '3N': [780, 860],
+                '3B': [780, 860],
+                '4': [1600, 1700],
+                '5': [2145, 2185],
+                '6': [2185, 2225],
+                '7': [2235, 2285],
+                '8': [2295, 2365],
+                '9': [2360, 2430],
+                '10': [8125, 8475],
+                '11': [8475, 8825],
+                '12': [8925, 9275],
+                '13': [10250, 10950],
+                '14': [10950, 11650]}
 
     if 'AST_07' in ifile:
         scalefactor = 0.001
@@ -1312,6 +1384,12 @@ def get_aster_zip(ifile, piter=None, showprocesslog=print):
         dat[-1].filename = ifile
         dat[-1].units = units
 
+        bmeta = dat[-1].metadata
+        if satbands is not None:
+            fext = dat[-1].dataid[4:]
+            bmeta['WavelengthMin'] = satbands[fext][0]
+            bmeta['WavelengthMax'] = satbands[fext][1]
+
         dataset = None
 
     showprocesslog('Cleaning Extracted zip files...')
@@ -1321,20 +1399,39 @@ def get_aster_zip(ifile, piter=None, showprocesslog=print):
     return dat
 
 
-def get_aster_hdf(ifile, piter=None):
+def get_aster_hdf(ifile, piter=iter):
     """
-    Gets ASTER Data.
+    Get ASTER hdf Data.
 
     Parameters
     ----------
     ifile : str
         filename to import
+    piter : iter, optional
+        Progress bar iterable. Default is iter
 
     Returns
     -------
     dat : PyGMI raster Data
         dataset imported
     """
+
+    satbands = {'1': [520, 600],
+                '2': [630, 690],
+                '3N': [780, 860],
+                '3B': [780, 860],
+                '4': [1600, 1700],
+                '5': [2145, 2185],
+                '6': [2185, 2225],
+                '7': [2235, 2285],
+                '8': [2295, 2365],
+                '9': [2360, 2430],
+                '10': [8125, 8475],
+                '11': [8475, 8825],
+                '12': [8925, 9275],
+                '13': [10250, 10950],
+                '14': [10950, 11650]}
+
     ifile = ifile[:]
 
     if 'AST_07' in ifile:
@@ -1348,9 +1445,6 @@ def get_aster_hdf(ifile, piter=None):
     else:
         return None
 
-    if piter is None:
-        piter = iter
-
     dataset = gdal.Open(ifile, gdal.GA_ReadOnly)
 
     meta = dataset.GetMetadata()
@@ -1373,7 +1467,10 @@ def get_aster_hdf(ifile, piter=None):
 
     solarelev = float(meta['SOLARDIRECTION'].split()[1])
     cdate = meta['CALENDARDATE']
-    fmt = '%Y-%m-%d'
+    if len(cdate) == 8:
+        fmt = '%Y%m%d'
+    else:
+        fmt = '%Y-%m-%d'
     dte = datetime.datetime.strptime(cdate, fmt)
     jdate = dte.timetuple().tm_yday
 
@@ -1398,21 +1495,26 @@ def get_aster_hdf(ifile, piter=None):
 
     dat = []
     nval = 0
+    calctoa = False
     for bfile, bandid in piter(subdata):
         if 'QA' in bfile:
             continue
         if ptype == 'L1T' and 'ImageData3B' in bfile:
             continue
 
-        bandid2 = bandid[bandid.lower().index(' band'):
+        bandid2 = bandid[bandid.lower().index(']')+1:
                          bandid.lower().index('(')].strip()
 
         dataset = gdal.Open(bfile, gdal.GA_ReadOnly)
 
         tmpds = gdal.AutoCreateWarpedVRT(dataset)
 
+        if tmpds is None:
+            continue
         dat.append(Data())
         dat[-1].data = tmpds.ReadAsArray()
+        if ptype == '08':
+            dat[-1].data[dat[-1].data == 2000] = nval
         dat[-1].data = np.ma.masked_invalid(dat[-1].data)*scalefactor
         dat[-1].data.mask = dat[-1].data.mask | (dat[-1].data == nval)
         if dat[-1].data.mask.size == 1:
@@ -1429,13 +1531,20 @@ def get_aster_hdf(ifile, piter=None):
         dat[-1].filename = ifile
         dat[-1].units = units
 
-        if ptype == 'L1T':
+        bmeta = dat[-1].metadata
+        if satbands is not None:
+            fext = dat[-1].dataid[4:].split()[0]
+            bmeta['WavelengthMin'] = satbands[fext][0]
+            bmeta['WavelengthMax'] = satbands[fext][1]
+
+        if ptype == 'L1T' and 'ImageData' in ifile:
             dat[-1].metadata['Gain'] = ucc[ifile[ifile.rindex('ImageData'):]]
+            calctoa = True
 
     if dat == []:
         dat = None
 
-    if ptype == 'L1T':
+    if ptype == 'L1T' and calctoa is True:
         dat = calculate_toa(dat)
 
     return dat
@@ -1443,7 +1552,7 @@ def get_aster_hdf(ifile, piter=None):
 
 def get_aster_ged(ifile):
     """
-    Gets ASTER GED data
+    Get ASTER GED data.
 
     Parameters
     ----------
@@ -1537,7 +1646,7 @@ def get_aster_ged(ifile):
 
 def get_aster_ged_bin(ifile):
     """
-    Get ASTER GED binary format
+    Get ASTER GED binary format.
 
     Emissivity_Mean_Description: Mean Emissivity for each pixel on grid-box
     using all ASTER data from 2000-2010
@@ -1568,7 +1677,6 @@ def get_aster_ged_bin(ifile):
     dat : PyGMI raster Data
         dataset imported
     """
-
     dat = []
     nval = -9999
     bandid = {}
@@ -1639,27 +1747,24 @@ def get_aster_ged_bin(ifile):
     return dat
 
 
-def testfn():
-    """Main testing routine."""
-    # from pprint import pprint
-    # ifile = r'C:\Work\Workdata\ASTER\S2A_MSIL2A_20170813T080011_N0205_R035_T35JKG_20170813T082818.SAFE\MTD_MSIL2A.xml'
-    # dat = get_sentinel2(ifile)
+def _testfn():
+    """Test routine."""
 
-    # ifile = r'C:\Work\Workdata\ASTER\AST_07XT_00309042002082052_20200518021739_29313.zip'
-    # dat = get_aster_zip(ifile)
 
-    # ifile = r'C:\Work\Workdata\ASTER\LC081740432017101901T1-SC20180409064853.tar.gz'
-    # dat = get_landsat(ifile)
 
-    # ifile = r'C:/Work/Workdata/Remote Sensing/Modis/MOD16A2.A2013073.h20v11.006.2017101224330.hdf'
-    ifile = r'C:/Work/Workdata/Remote Sensing/Modis/MOD11A2.A2013073.h20v11.006.2016155170529.hdf'
-    dat = get_modisv6(ifile)
+    ifile = r'D:/Workdata/Remote Sensing/Landsat/LC08_L1TP_176080_20190820_20190903_01_T1.tar.gz'
+    # ifile = r'D:/Workdata/Remote Sensing/Landsat/LE071700782002070201T1-SC20200519113053.tar.gz'
+    # ifile = r'D:/Workdata/Remote Sensing/Landsat/LT051700781997071201T1-SC20200519120230.tar.gz'
 
-    # ifile = r'C:\Work\Workdata\ASTER\AST_05_00305282005083844_20180604061610_15573.hdf'
-    # ofile = r'C:\Work\Workdata\ASTER\hope.tif'
-    # dat = iodefs.get_data(ifile)
-    # export_gdal(ofile, dat, 'GTiff')
+    ifile = r'D:\Workdata\Remote Sensing\ASTER\old\AST_07XT_00305282005083844_20180604061623_15509.hdf'
+    # ifile = r'D:\Workdata\Remote Sensing\ASTER\old\AST_07XT_00309042002082052_20200518021739_29313.zip'
+
+    dat = get_data(ifile)
+
+    # ifile = r'C:/Work/Workdata/Remote Sensing/Modis/MOD11A2.A2013073.h20v11.006.2016155170529.hdf'
+    # dat = get_modisv6(ifile)
+    breakpoint()
 
 
 if __name__ == "__main__":
-    testfn()
+    _testfn()
