@@ -22,7 +22,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 # -----------------------------------------------------------------------------
-"""Import Data."""
+"""Calculate remote sensing ratios."""
 
 import copy
 import os
@@ -31,10 +31,12 @@ import re
 import numexpr as ne
 import numpy as np
 from PyQt5 import QtWidgets, QtCore
+
 import pygmi.menu_default as menu_default
 import pygmi.rsense.iodefs as iodefs
 from pygmi.raster.iodefs import export_gdal
 from pygmi.raster.dataprep import merge
+from pygmi.misc import ProgressBarText
 
 
 class SatRatios(QtWidgets.QDialog):
@@ -55,8 +57,10 @@ class SatRatios(QtWidgets.QDialog):
         super().__init__(parent)
         if parent is None:
             self.showprocesslog = print
+            self.piter = ProgressBarText().iter
         else:
             self.showprocesslog = parent.showprocesslog
+            self.piter = parent.pbar.iter
 
         self.indata = {}
         self.outdata = {}
@@ -153,7 +157,6 @@ class SatRatios(QtWidgets.QDialog):
             A check to see if settings was successfully run.
 
         """
-
         self.combo_sensor.setCurrentText(projdata['sensor'])
         self.setratios()
 
@@ -219,13 +222,16 @@ class SatRatios(QtWidgets.QDialog):
 
         for ifile in flist:
             if isinstance(ifile, str):
-                dat = iodefs.get_data(ifile, showprocesslog=self.showprocesslog)
+                dat = iodefs.get_data(ifile,
+                                      showprocesslog=self.showprocesslog,
+                                      piter=self.piter)
                 ofile = ifile
             elif isinstance(ifile, list) and 'RasterFileList' in self.indata:
                 dat = []
                 for jfile in ifile:
                     dat += iodefs.get_data(jfile,
-                                           showprocesslog=self.showprocesslog)
+                                           showprocesslog=self.showprocesslog,
+                                           piter=self.piter)
                 ofile = ifile[-1]
             else:
                 dat = ifile
@@ -234,7 +240,7 @@ class SatRatios(QtWidgets.QDialog):
             if dat is None:
                 continue
 
-            dat = merge(dat)
+            dat = merge(dat, self.piter, pprint=self.showprocesslog)
 
             datd = {}
             for i in dat:
@@ -247,12 +253,16 @@ class SatRatios(QtWidgets.QDialog):
                     txt = txt.replace('B', 'Band')
                     txt = txt.replace(',', '')
 
+                if 'Band' not in txt and 'B' in txt:
+                    txt = txt.replace('B', 'Band')
+
                 if txt == 'Band3N':
                     txt = 'Band3'
 
                 if txt == 'Band8A':
                     txt = 'Band8'
 
+                self.showprocesslog(i.dataid+' mapped to '+txt)
                 datd[txt] = i.data
 
             datfin = []
@@ -289,8 +299,8 @@ class SatRatios(QtWidgets.QDialog):
             if datfin:
                 self.showprocesslog('Exporting to '+ofile)
                 export_gdal(ofile, datfin, 'GTiff', piter=self.pbar.iter)
+                self.outdata['Raster'] = datfin
 
-        self.outdata['Raster'] = datfin
         return True
 
     def setratios(self):
@@ -507,8 +517,8 @@ def get_sentinel_list(flist):
     return flist2
 
 
-def testfn():
-    """Main testing routine."""
+def _testfn():
+    """Test routine."""
     ifile = r'C:\Work\Workdata\ASTER\AST_05_00302282018211606_20180814024609_27608.hdf'
     dat = iodefs.get_data(ifile)
 
@@ -528,4 +538,4 @@ def testfn():
 
 
 if __name__ == "__main__":
-    testfn()
+    _testfn()
