@@ -22,17 +22,13 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 # -----------------------------------------------------------------------------
-"""This program deletes seisan records."""
+"""Delete SEISAN records."""
 
 import os
 import numpy as np
 from PyQt5 import QtWidgets
 import matplotlib.pyplot as plt
-#from pygmi.misc import PTime
 import pygmi.seis.iodefs as iodefs
-#from sklearn.cluster import DBSCAN
-#import cartopy.crs as ccrs
-#import cartopy.io.img_tiles as cimgt
 
 
 class DeleteRecord():
@@ -73,7 +69,7 @@ class DeleteRecord():
 
     def loadproj(self, projdata):
         """
-        Loads project data into class.
+        Load project data into class.
 
         Parameters
         ----------
@@ -86,14 +82,12 @@ class DeleteRecord():
             A check to see if settings was successfully run.
 
         """
-
         return False
 
     def saveproj(self):
         """
         Save project data from class.
 
-
         Returns
         -------
         projdata : dictionary
@@ -163,7 +157,6 @@ class Quarry():
         self.parent = parent
         self.indata = {}
         self.outdata = {}
-        self.pbar = None
         if parent is None:
             self.showprocesslog = print
         else:
@@ -215,7 +208,7 @@ class Quarry():
 
     def loadproj(self, projdata):
         """
-        Loads project data into class.
+        Load project data into class.
 
         Parameters
         ----------
@@ -228,14 +221,12 @@ class Quarry():
             A check to see if settings was successfully run.
 
         """
-
         return False
 
     def saveproj(self):
         """
         Save project data from class.
 
-
         Returns
         -------
         projdata : dictionary
@@ -672,7 +663,7 @@ def import_for_plots(ifile, dind='R'):
     return datd
 
 
-def main():
+def _testfn():
     """Routine for testing."""
     ifile = r'C:\Work\Workdata\review\seismology\pygmi.out'
     # ifile = r'C:\Work\Workdata\review\seismology\collect.out'
@@ -694,4 +685,4 @@ def main():
 
 
 if __name__ == "__main__":
-    main()
+    _testfn()
