@@ -29,6 +29,7 @@ import re
 from PyQt5 import QtWidgets, QtCore
 import numpy as np
 import pandas as pd
+import geopandas as gpd
 import pygmi.seis.datatypes as sdt
 import pygmi.menu_default as menu_default
 
@@ -129,11 +130,10 @@ def str2int(inp):
 
 
 class ImportSeisan():
-    """Import Seisan Data."""
+    """Import SEISAN Data."""
 
     def __init__(self, parent=None):
         self.ifile = ''
-        self.pbar = None
         self.parent = parent
         self.indata = {}
         self.outdata = {}
@@ -142,6 +142,14 @@ class ImportSeisan():
         else:
             self.showprocesslog = parent.showprocesslog
 
+        idir = os.path.dirname(os.path.realpath(__file__))
+        self.tfile = os.path.join(idir, r'descriptions.txt')
+
+        with open(self.tfile) as inp:
+            self.rnames = inp.read()
+
+        self.rnames = self.rnames.split('\n')
+
     def settings(self, nodialog=False):
         """
         Entry point into item.
@@ -245,6 +253,13 @@ class ImportSeisan():
             elif ltype == '3':
                 if tmp.region != '':
                     event[ltype] = tmp
+                    if tmp.region not in self.rnames:
+                        errs = ['Warning: Possible spelling error on on '
+                                'line: '+str(iii+1)+'. Make sure the region '
+                                'spelling, case and punctuation '
+                                'matches exactly the definitions '
+                                'in '+self.tfile, i]
+                        file_errors.append(errs)
             else:
                 event[ltype] = tmp
 
@@ -311,7 +326,7 @@ class ImportSeisan():
 
     def loadproj(self, projdata):
         """
-        Loads project data into class.
+        Load project data into class.
 
         Parameters
         ----------
@@ -334,7 +349,6 @@ class ImportSeisan():
         """
         Save project data from class.
 
-
         Returns
         -------
         projdata : dictionary
@@ -360,7 +374,7 @@ def read_record_type_1(i):
     Returns
     -------
     tmp : sdt.seisan_1
-        Seisan 1 record.
+        SEISAN 1 record.
 
     """
     tmp = sdt.seisan_1()
@@ -407,7 +421,7 @@ def read_record_type_2(i):
     Returns
     -------
     tmp : sdt.seisan_2
-        Seisan 2 record.
+        SEISAN 2 record.
 
     """
     dat = sdt.seisan_2()
@@ -447,7 +461,7 @@ def read_record_type_3(i):
     Returns
     -------
     tmp : sdt.seisan_4
-        Seisan 4 record.
+        SEISAN 4 record.
 
     """
     dat = sdt.seisan_3()
@@ -470,7 +484,7 @@ def read_record_type_4(i):
     Returns
     -------
     tmp : sdt.seisan_4
-        Seisan 4 record.
+        SEISAN 4 record.
 
     """
     tmp = sdt.seisan_4()
@@ -518,7 +532,7 @@ def read_record_type_5(i):
     Returns
     -------
     tmp : sdt.seisan_5
-        Seisan 5 record.
+        SEISAN 5 record.
 
     """
     tmp = sdt.seisan_5()
@@ -538,7 +552,7 @@ def read_record_type_6(i):
     Returns
     -------
     tmp : sdt.seisan_6
-        Seisan 6 record.
+        SEISAN 6 record.
 
     """
     tmp = sdt.seisan_6()
@@ -559,7 +573,7 @@ def read_record_type_e(i):
     Returns
     -------
     tmp : sdt.seisan_E
-        Seisan E record.
+        SEISAN E record.
 
     """
     tmp = sdt.seisan_E()
@@ -588,7 +602,7 @@ def read_record_type_f(i):
     Returns
     -------
     out : dictionary
-        Dictionary with a Seisan F record.
+        Dictionary with a SEISAN F record.
 
     """
     tmp = sdt.seisan_F()
@@ -610,7 +624,7 @@ def read_record_type_f(i):
     tmp.solution_quality = i[77]
 
     if prg == '':
-        out = {}
+        out = {'OTHER': tmp}
     else:
         out = {prg: tmp}
 
@@ -629,7 +643,7 @@ def read_record_type_h(i):
     Returns
     -------
     tmp : sdt.seisan_H
-        Seisan H record.
+        SEISAN H record.
 
     """
     tmp = sdt.seisan_H()
@@ -660,7 +674,7 @@ def read_record_type_i(i):
     Returns
     -------
     tmp : sdt.seisan_I
-        Seisan I record.
+        SEISAN I record.
 
     """
     tmp = sdt.seisan_I()
@@ -688,7 +702,7 @@ def read_record_type_m(i):
     Returns
     -------
     tmp : sdt.seisan_M
-        Seisan M record.
+        SEISAN M record.
 
     """
     if i[1:3] != 'MT':
@@ -733,14 +747,14 @@ def merge_m(rec1, rec2):
     Parameters
     ----------
     rec1 : sdt.seisan_M
-        Seisan M record.
+        SEISAN M record.
     rec2 : sdt.seisan_M
-        Seisan M record.
+        SEISAN M record.
 
     Returns
     -------
     rec1 : sdt.seisan_M
-        Seisan M record.
+        SEISAN M record.
 
     """
     rec1.mrr_mzz = rec2.mrr_mzz
@@ -771,7 +785,7 @@ def read_record_type_p(i):
     Returns
     -------
     tmp : sdt.seisan_P
-        Seisan P record.
+        SEISAN P record.
 
     """
     tmp = sdt.seisan_P()
@@ -788,7 +802,6 @@ class ImportGenericFPS():
 
     def __init__(self, parent=None):
         self.ifile = ''
-        self.pbar = None
         self.parent = parent
         self.indata = {}
         self.outdata = {}
@@ -871,7 +884,7 @@ class ImportGenericFPS():
 
     def loadproj(self, projdata):
         """
-        Loads project data into class.
+        Load project data into class.
 
         Parameters
         ----------
@@ -894,7 +907,6 @@ class ImportGenericFPS():
         """
         Save project data from class.
 
-
         Returns
         -------
         projdata : dictionary
@@ -909,11 +921,10 @@ class ImportGenericFPS():
 
 
 class ExportSeisan():
-    """Export Seisan Data."""
+    """Export SEISAN Data."""
 
     def __init__(self, parent=None):
         self.ifile = ''
-        self.pbar = None
         self.parent = parent
         self.indata = {}
         self.outdata = {}
@@ -1418,11 +1429,10 @@ class ExportSeisan():
 
 
 class ExportCSV():
-    """Export Seisan Data."""
+    """Export SEISAN Data."""
 
     def __init__(self, parent=None):
         self.ifile = ''
-        self.pbar = None
         self.parent = parent
         self.indata = {}
         self.outdata = {}
@@ -1964,12 +1974,11 @@ class ExportCSV():
         return tmp
 
 
-class ExportSummaryCSV():
-    """Export Seisan Data."""
+class ExportSummary():
+    """Export SEISAN Data."""
 
     def __init__(self, parent=None):
         self.ifile = ''
-        self.pbar = None
         self.parent = parent
         self.indata = {}
         self.outdata = {}
@@ -1995,9 +2004,13 @@ class ExportSummaryCSV():
 
         data = self.indata['Seis']
 
-        filename, _ = QtWidgets.QFileDialog.getSaveFileName(self.parent,
-                                                            'Save File',
-                                                            '.', 'csv (*.csv)')
+        ext = ('csv (*.csv);;'
+               'Excel (*.xlsx);;'
+               'Shapefile (*.shp)')
+
+        filename, filt = QtWidgets.QFileDialog.getSaveFileName(self.parent,
+                                                               'Save File',
+                                                               '.', ext)
         if filename == '':
             return
         os.chdir(os.path.dirname(filename))
@@ -2061,7 +2074,16 @@ class ExportSummaryCSV():
                     dat = idat['3']
                     df.loc[i, 'Description'] = dat.region
 
-        df.to_csv(filename, index=False)
+        if filt == 'csv (*.csv)':
+            df.to_csv(filename, index=False)
+        elif filt == 'Excel (*.xlsx)':
+            df.to_excel(filename, index=False)
+        elif filt == 'Shapefile (*.shp)':
+            geom = gpd.points_from_xy(df.Longitude, df.Latitude)
+            gdf = gpd.GeoDataFrame(df, geometry=geom)
+            gdf = gdf.set_crs("EPSG:4326")
+            # breakpoint()
+            gdf.to_file(filename)
 
 
 def mercalli(mag):
@@ -2129,7 +2151,6 @@ class FilterSeisan(QtWidgets.QDialog):
         self.indata = {}
         self.outdata = {}
         self.parent = parent
-        self.pbar = parent.pbar
 
         self.datlimits = None
 
@@ -2295,7 +2316,7 @@ class FilterSeisan(QtWidgets.QDialog):
 
     def get_limits(self):
         """
-        Get limits for seisan data.
+        Get limits for SEISAN data.
 
         Returns
         -------
