@@ -25,6 +25,7 @@
 """Seis Menu Routines."""
 
 from PyQt5 import QtWidgets
+
 from pygmi.seis import scan_imp
 from pygmi.seis import del_rec
 from pygmi.seis import iodefs
@@ -72,20 +73,12 @@ class MenuWidget():
         self.menu.addAction(self.action_import_genfps)
         self.action_import_genfps.triggered.connect(self.import_genfps)
 
-#        self.action_import_scans = QtWidgets.QAction('Import Scanned Bulletins')
-#        self.menu.addAction(self.action_import_scans)
-#        self.action_import_scans.triggered.connect(self.import_scans)
-
         self.menu.addSeparator()
 
         self.action_beachball = QtWidgets.QAction('Fault Plane Solutions')
         self.menu.addAction(self.action_beachball)
         self.action_beachball.triggered.connect(self.beachball)
 
-#        self.action_delete_recs = QtWidgets.QAction('Delete Records')
-#        self.menu.addAction(self.action_delete_recs)
-#        self.action_delete_recs.triggered.connect(self.delete_recs)
-
         self.action_quarry = QtWidgets.QAction('Remove Quarry Events')
         self.menu.addAction(self.action_quarry)
         self.action_quarry.triggered.connect(self.quarry)
@@ -106,9 +99,10 @@ class MenuWidget():
         context_menu['Seis'].addAction(self.action_export_csv)
         self.action_export_csv.triggered.connect(self.export_csv)
 
-        self.action_sexport_csv = QtWidgets.QAction('Export Summary to CSV')
-        context_menu['Seis'].addAction(self.action_sexport_csv)
-        self.action_sexport_csv.triggered.connect(self.sexport_csv)
+        self.action_sexport = QtWidgets.QAction('Export Summary to CSV, XLSX '
+                                                'or SHP')
+        context_menu['Seis'].addAction(self.action_sexport)
+        self.action_sexport.triggered.connect(self.sexport)
 
     def export_seisan(self):
         """Export Seisan data."""
@@ -118,49 +112,47 @@ class MenuWidget():
         """Export Seisan data to csv."""
         self.parent.launch_context_item(iodefs.ExportCSV)
 
-    def sexport_csv(self):
-        """Export Summary data to csv."""
-        self.parent.launch_context_item(iodefs.ExportSummaryCSV)
+    def sexport(self):
+        """Export Summary data."""
+        self.parent.launch_context_item(iodefs.ExportSummary)
 
     def beachball(self):
         """Create Beachballs from Fault Plane Solutions."""
-        fnc = beachball.BeachBall(self.parent)
-        self.parent.item_insert('Step', 'Fault Plane Solutions', fnc)
+        self.parent.item_insert('Step', 'Fault Plane Solutions',
+                                beachball.BeachBall)
 
     def import_scans(self):
         """Import scanned records."""
-        fnc = scan_imp.SIMP(self.parent)
-        self.parent.item_insert('Io', 'Import Scanned Bulletins', fnc)
+        self.parent.item_insert('Io', 'Import Scanned Bulletins',
+                                scan_imp.SIMP)
 
     def import_seisan(self):
         """Import Seisan."""
-        fnc = iodefs.ImportSeisan(self.parent)
-        self.parent.item_insert('Io', 'Import SEISAN Data', fnc)
+        self.parent.item_insert('Io', 'Import SEISAN Data',
+                                iodefs.ImportSeisan)
 
     def correct_desc(self):
         """Correct Seisan descriptions."""
-        fnc = utils.CorrectDescriptions(self.parent)
-        self.parent.item_insert('Step', 'Correct SEISAN Descriptions', fnc)
+        self.parent.item_insert('Step', 'Correct SEISAN Descriptions',
+                                utils.CorrectDescriptions)
 
     def filter_seisan(self):
         """Filter Seisan."""
-        fnc = iodefs.FilterSeisan(self.parent)
-        self.parent.item_insert('Step', 'Filter SEISAN Data', fnc)
+        self.parent.item_insert('Step', 'Filter SEISAN Data',
+                                iodefs.FilterSeisan)
 
     def import_genfps(self):
         """Import Generic Fault Plane Solution."""
-        fnc = iodefs.ImportGenericFPS(self.parent)
-        self.parent.item_insert('Io', 'Import Generic FPS', fnc)
+        self.parent.item_insert('Io', 'Import Generic FPS',
+                                iodefs.ImportGenericFPS)
 
     def delete_recs(self):
         """Delete Records."""
-        fnc = del_rec.DeleteRecord(self.parent)
-        self.parent.item_insert('Io', 'Delete Records', fnc)
+        self.parent.item_insert('Io', 'Delete Records', del_rec.DeleteRecord)
 
     def quarry(self):
         """Remove quarry events."""
-        fnc = del_rec.Quarry(self.parent)
-        self.parent.item_insert('Step', 'Remove Quarry Events', fnc)
+        self.parent.item_insert('Step', 'Remove Quarry Events', del_rec.Quarry)
 
     def show_QC_plots(self):
         """Show QC plots."""
