@@ -75,7 +75,6 @@ class SIMP():
     def __init__(self, parent=None):
         # PyGMI variables
         self.ifile = ''
-        self.pbar = None
         self.parent = parent
         self.indata = {}
         self.outdata = {}
@@ -189,7 +188,7 @@ class SIMP():
                 self.minute = self.datamins[0]
                 self.sec = self.datasecs[0]
 
-# Put data into seisan structures
+# Put data into SEISAN structures
             self.event = {}
             self.get_record_type_1()
             self.get_record_type_e()
@@ -214,7 +213,7 @@ class SIMP():
 
     def loadproj(self, projdata):
         """
-        Loads project data into class.
+        Load project data into class.
 
         Parameters
         ----------
@@ -227,14 +226,12 @@ class SIMP():
             A check to see if settings was successfully run.
 
         """
-
         return False
 
     def saveproj(self):
         """
         Save project data from class.
 
-
         Returns
         -------
         projdata : dictionary
@@ -990,7 +987,7 @@ class SIMP():
         Parameters
         ----------
         eline : str
-            String containging error.
+            String containing error.
 
         Returns
         -------
@@ -1016,7 +1013,7 @@ class SIMP():
         Returns
         -------
         mrecs : list
-            List of relevent records.
+            List of relevant records.
         monconv : dictionary
             Dictionary to convert string months to numbers.
 
