@@ -31,6 +31,7 @@ import sys
 from PyQt5 import QtWidgets, QtCore
 import numpy as np
 import pytest
+
 from pygmi.raster.datatypes import Data
 from pygmi.mag import dataprep
 from pygmi.mag import igrf, tiltdepth
@@ -61,7 +62,7 @@ def test_tilt1():
 
 
 def test_rtp():
-    """test rtp."""
+    """Test RTP."""
     datin = Data()
     datin.data = np.ma.array([[1, 2], [1, 2]])
     dat2 = [[0.7212671143002998, 1.9651600796627182],
