@@ -1,5 +1,5 @@
 # -----------------------------------------------------------------------------
-# Name:        iodefs.py (part of PyGMI)
+# Name:        dataprep.py (part of PyGMI)
 #
 # Author:      Patrick Cole
 # E-Mail:      pcole@geoscience.org.za
@@ -22,7 +22,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 # -----------------------------------------------------------------------------
-"""Import Data."""
+"""Data Preparation for Vector Data."""
 
 import os
 import copy
@@ -30,6 +30,7 @@ from PyQt5 import QtWidgets, QtCore, QtGui
 import numpy as np
 import matplotlib.path as mplPath
 from osgeo import osr, ogr
+
 import pygmi.menu_default as menu_default
 from pygmi.raster.dataprep import GroupProj
 from pygmi.raster.datatypes import Data
@@ -46,12 +47,6 @@ class PointCut():
     ----------
     ifile : str
         input file name.
-    name : str
-        item name
-    ext : str
-        file name extension.
-    pbar : progressbar
-        reference to a progress bar.
     parent : parent
         reference to the parent routine
     indata : dictionary
@@ -115,7 +110,7 @@ class PointCut():
 
     def loadproj(self, projdata):
         """
-        Loads project data into class.
+        Load project data into class.
 
         Parameters
         ----------
@@ -137,7 +132,6 @@ class PointCut():
         """
         Save project data from class.
 
-
         Returns
         -------
         projdata : dictionary
@@ -177,8 +171,6 @@ class DataGrid(QtWidgets.QDialog):
         self.indata = {}
         self.outdata = {}
         self.parent = parent
-        if parent is not None:
-            self.pbar = parent.pbar
         self.dxy = None
         self.dataid_text = None
 
@@ -320,7 +312,7 @@ class DataGrid(QtWidgets.QDialog):
 
     def loadproj(self, projdata):
         """
-        Loads project data into class.
+        Load project data into class.
 
         Parameters
         ----------
@@ -347,7 +339,6 @@ class DataGrid(QtWidgets.QDialog):
         """
         Save project data from class.
 
-
         Returns
         -------
         projdata : dictionary
@@ -444,7 +435,6 @@ class DataReproj(QtWidgets.QDialog):
         self.indata = {}
         self.outdata = {}
         self.parent = parent
-        self.pbar = self.parent.pbar
         self.orig_wkt = None
         self.targ_wkt = None
 
@@ -524,6 +514,13 @@ class DataReproj(QtWidgets.QDialog):
         dd = np.transpose([data.pygmiX, data.pygmiY])
         xy = ctrans.TransformPoints(dd)
         xy = np.array(xy)
+
+        if np.inf in xy:
+            self.showprocesslog('Note: inf values in reprojected results. '
+                                'Please check your input and output '
+                                'projections or input x and y data for '
+                                'mistakes.')
+
         data = data.assign(Xnew=xy[:, 0])
         data = data.assign(Ynew=xy[:, 1])
         data.pygmiX = xy[:, 0]
@@ -541,10 +538,14 @@ class DataReproj(QtWidgets.QDialog):
             True if successful, False otherwise.
 
         """
-        if 'Line' not in self.indata:
-            self.showprocesslog('No line data.')
+        if 'Line' not in self.indata and 'Vector' not in self.indata:
+            self.showprocesslog('No vector data.')
             return False
 
+        if 'Vector' in self.indata:
+            firstkey = next(iter(self.indata['Vector'].keys()))
+            self.orig_wkt = self.indata['Vector'][firstkey].crs.to_wkt()
+
         if self.orig_wkt is None:
             indx = self.in_proj.combobox.findText(r'WGS 84 / '
                                                   r'Geodetic Geographic')
@@ -572,13 +573,20 @@ class DataReproj(QtWidgets.QDialog):
             if tmp != 1:
                 return False
 
-        self.acceptall()
+        if 'Vector' in self.indata:
+            self.outdata['Vector'] = {}
+            for i in self.indata['Vector']:
+                ivec = self.indata['Vector'][i]
+                ivec.set_crs(self.in_proj.wkt)
+                self.outdata['Vector'][i] = ivec.to_crs(self.out_proj.wkt)
+        else:
+            self.acceptall()
 
         return True
 
     def loadproj(self, projdata):
         """
-        Loads project data into class.
+        Load project data into class.
 
         Parameters
         ----------
@@ -600,7 +608,6 @@ class DataReproj(QtWidgets.QDialog):
         """
         Save project data from class.
 
-
         Returns
         -------
         projdata : dictionary
@@ -689,13 +696,14 @@ def quickgrid(x, y, z, dxy, numits=4, showprocesslog=print):
     numits : int
         number of iterations. By default its 4. If this is negative, a maximum
         numits will be calculated and used.
+    showprogresslog : print, optional
+        Routine for displaying messages. Default is print
 
     Returns
     -------
     newz : numpy array
         M x N array of z values
     """
-
     showprocesslog('Creating Grid')
     x = x.flatten()
     y = y.flatten()
@@ -754,38 +762,33 @@ def quickgrid(x, y, z, dxy, numits=4, showprocesslog=print):
     return newz
 
 
-def testfn():
-    """Main testing routine."""
+def _testfn():
+    """Test routine."""
     import sys
     import matplotlib.pyplot as plt
-    from pygmi.vector.iodefs import ImportLineData
+    from pygmi.vector.iodefs import ImportLineData, ImportShapeData
+
     APP = QtWidgets.QApplication(sys.argv)  # Necessary to test Qt Classes
 
-    ifile = r'C:\Work\Workdata\Mpumi\MSc_L3870_cutmag_coords.csv'
+    ifile = r'D:\Workdata\vector\linecut\test2.csv'
+    sfile = r'D:\Workdata\vector\linecut\test2_cut_outline.shp'
 
     IO = ImportLineData()
-
     IO.ifile = ifile
     IO.filt = 'Comma Delimited (*.csv)'
     IO.settings(True)
 
     line = list(IO.outdata['Line'].values())
-    plt.plot(line[0].magmicrolevel)
+    plt.plot(line[0].x, line[0].y)
     plt.show()
 
-    GR = DataGrid()
 
-    GR.indata = IO.outdata
-    GR.dataid_text = 'magmicrolevel'
-    GR.settings(True)
-
-    grd = GR.outdata['Raster'][0]
-
-    plt.plot(grd.data.data.T[0])
-    plt.show()
+    DR = DataReproj()
+    DR.indata = IO.outdata
+    DR.settings(True)
 
     breakpoint()
 
 
 if __name__ == "__main__":
-    testfn()
+    _testfn()
