@@ -34,6 +34,7 @@ from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg
 from matplotlib.figure import Figure
 from matplotlib.backends.backend_qt5 import NavigationToolbar2QT
 from pandas.api.types import is_numeric_dtype
+
 from pygmi.misc import frm
 
 
@@ -199,7 +200,6 @@ class MyMplCanvas(FigureCanvasQTAgg):
         None.
 
         """
-
         r, data = self.line.get_data()
         self.update_lines(r, data)
 
@@ -305,7 +305,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
         ival : dictionary key
             dictionary key representing the line data channel to be plotted.
         scale: float
-            scale of exxageration for the profile data on the map.
+            scale of exaggeration for the profile data on the map.
         uselabels: bool
             boolean choice whether to use labels or not.
 
@@ -390,7 +390,7 @@ class MyMplCanvas(FigureCanvasQTAgg):
 
     def update_vector(self, data, col):
         """
-        Update the plot from vactor data.
+        Update the plot from vector data.
 
         Parameters
         ----------
@@ -433,18 +433,21 @@ class MyMplCanvas(FigureCanvasQTAgg):
             self.axes.axis('equal')
 
         elif 'Point' in data:
-            self.axes.scatter(data['Point'].geometry.x,
-                              data['Point'].geometry.y,
-                              c=data['Point'][col])
-            # self.axes.plot(data['Point'].geometry.x,
-            #                data['Point'].geometry.y, 'go')
+            if col != '':
+                self.axes.scatter(data['Point'].geometry.x,
+                                  data['Point'].geometry.y,
+                                  c=data['Point'][col])
+            else:
+                self.axes.scatter(data['Point'].geometry.x,
+                                  data['Point'].geometry.y)
 
         self.axes.xaxis.set_major_formatter(frm)
         self.axes.yaxis.set_major_formatter(frm)
 
+        self.figure.tight_layout()
         self.figure.canvas.draw()
 
-    def update_rose(self, data, rtype, nbins=8):
+    def update_rose(self, data, rtype, nbins=8, equal=False):
         """
         Update the rose diagram plot using vector data.
 
@@ -476,6 +479,8 @@ class MyMplCanvas(FigureCanvasQTAgg):
         ax2.ticklabel_format(useOffset=False, style='plain')
         ax2.tick_params(axis='x', rotation=90)
         ax2.tick_params(axis='y', rotation=0)
+        ax2.xaxis.set_major_formatter(frm)
+        ax2.yaxis.set_major_formatter(frm)
 
         fangle = []
         fcnt = []
@@ -515,6 +520,10 @@ class MyMplCanvas(FigureCanvasQTAgg):
 
             radii, theta = np.histogram(fangle, bins=np.arange(0, np.pi+bwidth,
                                                                bwidth))
+
+            if equal is True:
+                radii = .01*radii.max()*np.sqrt(100*radii/radii.max())
+
             xtheta = theta[:-1]  # +(theta[1]-theta[0])/2
             bcols2 = bcols[(xtheta/bwidth).astype(int)]
             ax1.bar(xtheta, radii, width=bwidth, color=bcols2)
@@ -529,6 +538,9 @@ class MyMplCanvas(FigureCanvasQTAgg):
             # Draw rose diagram base on one angle per linear segment, normed
             radii, theta = histogram(fcnt, y=flen, xmin=0., xmax=np.pi,
                                      bins=nbins)
+            if equal is True:
+                radii = .01*radii.max()*np.sqrt(100*radii/radii.max())
+
             xtheta = theta[:-1]
             bcols2 = bcols[(xtheta/bwidth).astype(int)]
             ax1.bar(xtheta, radii, width=bwidth, color=bcols2)
@@ -539,11 +551,12 @@ class MyMplCanvas(FigureCanvasQTAgg):
             ax2.add_collection(lcol)
             ax2.autoscale(enable=True, tight=True)
 
+        self.figure.tight_layout()
         self.figure.canvas.draw()
 
 
 class PlotPoints(GraphWindow):
-    """Plot Points2 Class."""
+    """Plot Points Class."""
 
     def __init__(self, parent=None):
         super().__init__(parent)
@@ -697,7 +710,7 @@ class PlotLines(GraphWindow):
 
 
 class PlotLineMap(GraphWindow):
-    """Plot Lines2 Class."""
+    """Plot Lines Map Class."""
 
     def __init__(self, parent=None):
         super().__init__(parent)
@@ -776,6 +789,8 @@ class PlotRose(GraphWindow):
         self.spinbox.setValue(8)
         self.spinbox.setMinimum(2)
         self.spinbox.setMaximum(360)
+        self.checkbox.show()
+
         self.setWindowTitle('Rose Diagram')
         if parent is None:
             self.showprocesslog = print
@@ -795,8 +810,9 @@ class PlotRose(GraphWindow):
             return
         data = self.indata['Vector']
         i = self.combobox1.currentIndex()
+        equal = self.checkbox.isChecked()
         if 'LineString' in data:
-            self.mmc.update_rose(data, i, self.spinbox.value())
+            self.mmc.update_rose(data, i, self.spinbox.value(), equal)
         else:
             self.showprocesslog('No line type data.')
             return
@@ -813,6 +829,7 @@ class PlotRose(GraphWindow):
         self.show()
         self.combobox1.addItem('Average Angle per Feature')
         self.combobox1.addItem('Angle per segment in Feature')
+        self.checkbox.setText('Equal Area Rose Diagram')
         self.label1.setText('Rose Diagram Type:')
         self.combobox1.setCurrentIndex(0)
 
@@ -857,7 +874,6 @@ class PlotVector(GraphWindow):
         None.
 
         """
-
         data = self.indata['Vector']
         key = list(data.keys())[0]
         data = data[key]
