@@ -25,6 +25,7 @@
 """Vector Menu Routines."""
 
 from PyQt5 import QtWidgets
+
 from pygmi.vector import iodefs
 from pygmi.vector import graphs
 from pygmi.vector import dataprep
@@ -69,7 +70,7 @@ class MenuWidget():
         self.menufile.addAction(self.action_cut_data)
         self.action_cut_data.triggered.connect(self.cut_data)
 
-        self.action_reproject = QtWidgets.QAction('Reproject Line Data')
+        self.action_reproject = QtWidgets.QAction('Reproject Vector Data')
         self.menufile.addAction(self.action_reproject)
         self.action_reproject.triggered.connect(self.reproject)
 
@@ -116,18 +117,16 @@ class MenuWidget():
 
     def grid(self):
         """Grid datasets."""
-        fnc = dataprep.DataGrid(self.parent)
-        self.parent.item_insert('Step', 'Grid Point Data', fnc)
+        self.parent.item_insert('Step', 'Grid Point Data', dataprep.DataGrid)
 
     def cut_data(self):
         """Cut point data."""
-        fnc = dataprep.PointCut(self.parent)
-        self.parent.item_insert('Step', 'Cut Points', fnc)
+        self.parent.item_insert('Step', 'Cut Points', dataprep.PointCut)
 
     def reproject(self):
         """Reproject point data."""
-        fnc = dataprep.DataReproj(self.parent)
-        self.parent.item_insert('Step', 'Reproject Line Data', fnc)
+        self.parent.item_insert('Step', 'Reproject Vector Data',
+                                dataprep.DataReproj)
 
     def export_line(self):
         """Export line data."""
@@ -139,13 +138,13 @@ class MenuWidget():
 
     def import_line_data(self):
         """Import line data."""
-        fnc = iodefs.ImportLineData(self.parent)
-        self.parent.item_insert('Io', 'Import Line Data', fnc)
+        self.parent.item_insert('Io', 'Import Line Data',
+                                iodefs.ImportLineData)
 
     def import_shape_data(self):
         """Import shape data."""
-        fnc = iodefs.ImportShapeData(self.parent)
-        self.parent.item_insert('Io', 'Import Shapefile Data', fnc)
+        self.parent.item_insert('Io', 'Import Shapefile Data',
+                                iodefs.ImportShapeData)
 
     def show_point_map(self):
         """Show point data."""
